/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008-2012 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                               version 6.0                *
*********************************************************************************
* Id: fxmoviemanager.cpp,                            2008/01/01                 *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/
#include "config.h"

#include <signal.h>

#include <xincs.h>
#include <fx.h>
#include <fxkeys.h>
#include <FXJPGImage.h>

#ifdef HAVE_LIBFOX_1_6
 #include "FXPNGIcon.h"
 #include "FXJPGIcon.h"
#endif

#include "fxmoviemanager.h"
#include "icons.h"
#include "OperationsDialog.h"
#include "FileSearchDialog.h"
#include "FileInputDialog.h"
#include "PropertiesDialog.h"
#include "MovieInfoDialog.h"
#include "MimeTypeDialog.h"
#include "PlayerDialog.h"

#ifndef WIN32
#include <unistd.h>
#endif

#include <iostream>
#include <stdexcept>
#include <stdlib.h>

#ifdef HAVE_LIBFFMPEGTHUMBNAILER_VIDEOTHUMBNAILER_H
 #include "libffmpegthumbnailer/videothumbnailer.h"
#endif
#ifdef HAVE_LIBFFMPEGTHUMBNAILER_FILMSTRIPFILTER_H
 #include "libffmpegthumbnailer/filmstripfilter.h"
#endif

#ifdef HAVE_LIBFOX_1_7
 #define VALUE_TO_STRING FXString::value
#elif HAVE_LIBFOX_1_6
 #define VALUE_TO_STRING FXStringVal
#endif

#define CLOCKTIMER      1000000000

using namespace FX;
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
using namespace std;
using namespace ffmpegthumbnailer;
#endif

// list of video files extensions
static const FXchar moviefiles[]=
	"All Files (*)"
	"\nmpeg (*.mpeg,*.MPEG,*.mpg,*.MPG,*.mpe,*.MPE)"
	"\nwindows (*.wmv,*.WMV,*.wmx,*.WMX,*.asf,*.ASF,*.asx,*.ASX)"
	"\navi (*.avi,*.AVI)"
	"\nquicktime (*.mov,*.MOV,*.qt,*.QT,*.mp4,*.MP4,*.f4v,*.F4V)"
	"\ndivx (*.divx, *.DIVX, *.xvid, *.XVID)"
	"\nmobile (*.3gp,*.3GP,*.3gp2,*.3GP2)"
	"\nmkv (*.mkv,*.MKV)"
	"\nogg (*.ogv,*.OGV,*.ogm,*.OGM,*.ogg,*.OGG)"
	"\nvob (*.vob,*.VOB)"
	"\nflash (*.flv,*.FLV)"
	"\nfli (*.fli,*.FLI)"
	"\ndv (*.dif,*.DIF,*.dv,*.DV,)"
	"\ngl (*.gl,*.GL)"
	"\ndl (*.dl,*.DL)"
	"\nmovie (*.movie,*.MOVIE)";

// list of audio files extensions
static const FXchar audiofiles[]=
	"All Files (*)"
	"\nbasic (*.au,*.AU,*.snd,*.SND)"
	"\nmp (*.mp2,*.MP2,*.mp3,*.MP3,*.mpga,*.MPGA,*.mpega,*.MPEGA)"
	"\nreal (*.ra,*.RA,*.rm,*.RM,,*.ram,*.RAM)"
	"\nwav (*.wav,*.WAV)"
	"\nwma (*.wma,*.WMA,*.wax,*.WAX)"
	"\nmod (*.mod,*.MOD)"
	"\nmidi (*.mid,*.MID,*.midi,*.MIDI)";


FXDEFMAP(FXMovieManager) FXMovieManagerMap[] = {
	//________Message_Type_____________________________ID___________________________Message_Handler__________
	// clipboard
	FXMAPFUNC(SEL_CLIPBOARD_LOST,						0,					FXMovieManager::onClipboardLost),
	FXMAPFUNC(SEL_CLIPBOARD_REQUEST,					0,					FXMovieManager::onClipboardRequest),
	FXMAPFUNC(SEL_COMMAND,		   	FXMovieManager::ID_CLIPBOARD_COPY_LP,	FXMovieManager::onCmdCopyCut_lp),
	FXMAPFUNC(SEL_COMMAND,		   	FXMovieManager::ID_CLIPBOARD_CUT_LP,	FXMovieManager::onCmdCopyCut_lp),
	FXMAPFUNC(SEL_COMMAND,		   	FXMovieManager::ID_CLIPBOARD_PASTE_LP,	FXMovieManager::onCmdPaste_lp),
	FXMAPFUNC(SEL_UPDATE,		   	FXMovieManager::ID_CLIPBOARD_PASTE_LP,	FXMovieManager::onUpdPaste),
	FXMAPFUNC(SEL_COMMAND,		   	FXMovieManager::ID_CLIPBOARD_COPY_RP,	FXMovieManager::onCmdCopyCut_rp),
	FXMAPFUNC(SEL_COMMAND,		   	FXMovieManager::ID_CLIPBOARD_CUT_RP,	FXMovieManager::onCmdCopyCut_rp),
	FXMAPFUNC(SEL_COMMAND,		   	FXMovieManager::ID_CLIPBOARD_PASTE_RP,	FXMovieManager::onCmdPaste_rp),
	FXMAPFUNC(SEL_UPDATE,		   	FXMovieManager::ID_CLIPBOARD_PASTE_RP,	FXMovieManager::onUpdPaste),

  	FXMAPFUNC(SEL_TIMEOUT,          FXMovieManager::ID_CLOCKTIME,   	FXMovieManager::onClock),

	// buttons
	FXMAPFUNC(SEL_COMMAND,      	FXMovieManager::ID_QUIT,       		FXMovieManager::onCmdQuit),
	FXMAPFUNC(SEL_SIGNAL,        	FXMovieManager::ID_QUIT,       		FXMovieManager::onCmdQuit),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_FILE,       		FXMovieManager::onCmdFile),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_LOOP,       		FXMovieManager::onCmdLoop),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_FULL,       		FXMovieManager::onCmdFull),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_VOLUME,       	FXMovieManager::onCmdVolume),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_SPEED,       	FXMovieManager::onCmdSpeed),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_AUDIO,			FXMovieManager::onCmdAudio),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_DROP,       		FXMovieManager::onCmdDrop),

	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_PLAY,       		FXMovieManager::onCmdPlay),
	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_PLAY,			FXMovieManager::onUpdSelectedTable),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_PAUSE,      		FXMovieManager::onCmdPause),
	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_PAUSE,			FXMovieManager::onUpdSelectedTable),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_STOP,       		FXMovieManager::onCmdStop),
	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_STOP,			FXMovieManager::onUpdSelectedTable),

	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_AUDIODELAY, 		FXMovieManager::onCmdAudiodelay),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_BRIGHTNESS, 		FXMovieManager::onCmdBrightness),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_CONTRAST, 		FXMovieManager::onCmdContrast),
//	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_GAMMA, 			FXMovieManager::onCmdGamma),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_HUE, 			FXMovieManager::onCmdHue),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_SATURATION, 		FXMovieManager::onCmdSaturation),

  	FXMAPFUNCS(SEL_UPDATE,          FXMovieManager::ID_SIZE_0,     		FXMovieManager::ID_SIZE_25, 	FXMovieManager::onUpdSizeSwitch),
  	FXMAPFUNCS(SEL_COMMAND,         FXMovieManager::ID_SIZE_0,     		FXMovieManager::ID_SIZE_25, 	FXMovieManager::onCmdSizeSwitch),
  	FXMAPFUNCS(SEL_UPDATE,          FXMovieManager::ID_VIDEO_0,    		FXMovieManager::ID_VIDEO_9, 	FXMovieManager::onUpdVideoSwitch),
  	FXMAPFUNCS(SEL_COMMAND,         FXMovieManager::ID_VIDEO_0,    		FXMovieManager::ID_VIDEO_9, 	FXMovieManager::onCmdVideoSwitch),

	// hide
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_MAINWINDOW,  	FXMovieManager::onCmdPutBack),

 	// table list
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_MOVESELUP,     	FXMovieManager::onCmdMoveSelUp),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_MOVESELDOWN,   	FXMovieManager::onCmdMoveSelDown),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_APPEND,     		FXMovieManager::onCmdAppend),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_INSERT,     		FXMovieManager::onCmdInsert),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_SELECTALL,  		FXMovieManager::onCmdSelectAll),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_DELETE,     		FXMovieManager::onCmdDelete),
	FXMAPFUNC(SEL_COMMAND,       	FXMovieManager::ID_CLEAR,      		FXMovieManager::onCmdClear),
	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_SAVELIST,		FXMovieManager::onCmdSavePlaylist),
	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_OPENLIST,		FXMovieManager::onCmdOpenPlaylist),
	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,	FXMovieManager::ID_TABLE,   	FXMovieManager::onListRightMouse),


	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_SHOW_FULL_LP,	FXMovieManager::onCmdShowPanel_lp),
	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_SHOW_DIR_LP,		FXMovieManager::onCmdShowPanel_lp),
	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_SHOW_FILE_LP,	FXMovieManager::onCmdShowPanel_lp),
	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_SHOW_FULL_RP,	FXMovieManager::onCmdShowPanel_rp),
	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_SHOW_DIR_RP,		FXMovieManager::onCmdShowPanel_rp),
	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_SHOW_FILE_RP,	FXMovieManager::onCmdShowPanel_rp),


	// left panel directory list
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_DIRECTORYLIST_LP,	FXMovieManager::onCmdDirectory_lp),
	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,	FXMovieManager::ID_DIRECTORYLIST_LP,	FXMovieManager::onDirListPopup_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_NEWDIR_LP,		FXMovieManager::onCmdNewDir_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_NEWDIR_LP,		FXMovieManager::onUpdNewDir_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_DIRDELETE_LP,	FXMovieManager::onCmdDirDelete_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_DIRDELETE_LP,	FXMovieManager::onUpdNewDir_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_DIRRENAME_LP,	FXMovieManager::onCmdDirRename_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_DIRRENAME_LP,	FXMovieManager::onUpdNewDir_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_UPDIRECTORY_LP,	FXMovieManager::onCmdUpDirectory_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_UPDIRECTORY_LP,	FXMovieManager::onUpdNewDir_lp),
	// right panel directory list
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_DIRECTORYLIST_RP,	FXMovieManager::onCmdDirectory_rp),
	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,	FXMovieManager::ID_DIRECTORYLIST_RP,	FXMovieManager::onDirListPopup_rp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_NEWDIR_RP,		FXMovieManager::onCmdNewDir_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_NEWDIR_RP,		FXMovieManager::onUpdNewDir_rp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_DIRDELETE_RP,	FXMovieManager::onCmdDirDelete_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_DIRDELETE_RP,	FXMovieManager::onUpdNewDir_rp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_DIRRENAME_RP,	FXMovieManager::onCmdDirRename_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_DIRRENAME_RP,	FXMovieManager::onUpdNewDir_rp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_UPDIRECTORY_RP,	FXMovieManager::onCmdUpDirectory_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_UPDIRECTORY_RP,	FXMovieManager::onUpdNewDir_rp),
	// mapping commands
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_MAPHOST_LP,		FXMovieManager::onCmdMapHost_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_UNMAPHOST_LP,	FXMovieManager::onCmdUnmapHost_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_MAPHOST_RP,		FXMovieManager::onCmdMapHost_rp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_UNMAPHOST_RP,	FXMovieManager::onCmdUnmapHost_rp),

	// left file list
	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,	FXMovieManager::ID_FILELIST_LP,		FXMovieManager::onFileListPopup_lp),
	FXMAPFUNC(SEL_DOUBLECLICKED, 	FXMovieManager::ID_FILELIST_LP,   	FXMovieManager::onCmdFileListDC_lp),
	FXMAPFUNC(SEL_CLICKED, 			FXMovieManager::ID_FILELIST_LP,   	FXMovieManager::onCmdFileListC_lp),

  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILESEARCH_LP,	FXMovieManager::onCmdFileSearch_lp),

  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILECOPY_LP,		FXMovieManager::onCmdFileCopy_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILECOPY_LP,		FXMovieManager::onUpdSelected_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILESYMLINK_LP,	FXMovieManager::onCmdFileSymlink_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILESYMLINK_LP,	FXMovieManager::onUpdSelected_lp),
   	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILERENAME_LP,	FXMovieManager::onCmdFileRename_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILERENAME_LP,	FXMovieManager::onUpdSelected_lp),
   	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEMOVE_LP,		FXMovieManager::onCmdFileMove_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEMOVE_LP,		FXMovieManager::onUpdSelected_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEDELETE_LP,	FXMovieManager::onCmdFileDelete_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEDELETE_LP,	FXMovieManager::onUpdSelected_lp),
	// right file list
	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,	FXMovieManager::ID_FILELIST_RP,		FXMovieManager::onFileListPopup_rp),
	FXMAPFUNC(SEL_DOUBLECLICKED, 	FXMovieManager::ID_FILELIST_RP,   	FXMovieManager::onCmdFileListDC_rp),
	FXMAPFUNC(SEL_CLICKED, 			FXMovieManager::ID_FILELIST_RP,   	FXMovieManager::onCmdFileListC_rp),

  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILESEARCH_RP,	FXMovieManager::onCmdFileSearch_rp),

  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILECOPY_RP,		FXMovieManager::onCmdFileCopy_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILECOPY_RP,		FXMovieManager::onUpdSelected_rp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILESYMLINK_RP,	FXMovieManager::onCmdFileSymlink_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILESYMLINK_RP,	FXMovieManager::onUpdSelected_rp),
   	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILERENAME_RP,	FXMovieManager::onCmdFileRename_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILERENAME_RP,	FXMovieManager::onUpdSelected_rp),
   	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEMOVE_RP,		FXMovieManager::onCmdFileMove_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEMOVE_RP,		FXMovieManager::onUpdSelected_rp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEDELETE_RP,	FXMovieManager::onCmdFileDelete_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEDELETE_RP,	FXMovieManager::onUpdSelected_rp),

	// left filelist player
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_IFILEPLAY_LP,	FXMovieManager::onCmdImagePlay_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_IFILEPLAY_LP,	FXMovieManager::onUpdSelectedImageFile_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEPLAY_LP,		FXMovieManager::onCmdFilePlay_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEPLAY_LP,		FXMovieManager::onUpdSelectedVideoAudioFile_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEPAUSE_LP,	FXMovieManager::onCmdFilePause_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEPAUSE_LP,	FXMovieManager::onUpdSelectedVideoAudioImageFile_lp),
	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILESTOP_LP,   	FXMovieManager::onCmdFileStop_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILESTOP_LP,		FXMovieManager::onUpdSelectedVideoAudioImageFile_lp),
	// right filelist player
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_IFILEPLAY_RP,	FXMovieManager::onCmdImagePlay_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_IFILEPLAY_RP,	FXMovieManager::onUpdSelectedImageFile_rp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEPLAY_RP,		FXMovieManager::onCmdFilePlay_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEPLAY_RP,		FXMovieManager::onUpdSelectedVideoAudioFile_rp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEPAUSE_RP,	FXMovieManager::onCmdFilePause_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEPAUSE_RP,	FXMovieManager::onUpdSelectedVideoAudioImageFile_rp),
	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILESTOP_RP,   	FXMovieManager::onCmdFileStop_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILESTOP_RP,		FXMovieManager::onUpdSelectedVideoAudioImageFile_rp),

	// filelist command buttons
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEPREVIEW_LP,	FXMovieManager::onCmdFilePreview_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEPREVIEW_LP, 	FXMovieManager::onUpdSelectedVideoFile_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FILEPREVIEW_RP,	FXMovieManager::onCmdFilePreview_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILEPREVIEW_RP, 	FXMovieManager::onUpdSelectedVideoFile_rp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FORCEFILEPREVIEW_LP,	FXMovieManager::onCmdForceFilePreview_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FORCEFILEPREVIEW_LP,	FXMovieManager::onUpdSelectedVideoFile_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_FORCEFILEPREVIEW_RP,	FXMovieManager::onCmdForceFilePreview_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FORCEFILEPREVIEW_RP,	FXMovieManager::onUpdSelectedVideoFile_rp),

  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_WIDESCREEN,		FXMovieManager::onCmdWideScreen),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_SEEKINCREMENT,	FXMovieManager::onUpdSeekIncrement),

  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_INCFILEPREVIEW_LP,	FXMovieManager::onCmdIncFilePreview_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_INCFILEPREVIEW_LP,	FXMovieManager::onUpdSelectedVideoFile_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_INCFILEPREVIEW_RP,	FXMovieManager::onCmdIncFilePreview_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_INCFILEPREVIEW_RP,	FXMovieManager::onUpdSelectedVideoFile_rp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_DECFILEPREVIEW_LP,	FXMovieManager::onCmdDecFilePreview_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_DECFILEPREVIEW_LP,	FXMovieManager::onUpdSelectedVideoFile_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_DECFILEPREVIEW_RP,	FXMovieManager::onCmdDecFilePreview_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_DECFILEPREVIEW_RP,	FXMovieManager::onUpdSelectedVideoFile_rp),

  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_CLEARPREVIEW_LP,	FXMovieManager::onCmdClearPreview_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_CLEARPREVIEW_RP,	FXMovieManager::onCmdClearPreview_rp),

  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_TERMINAL_LP,		FXMovieManager::onCmdTerminal_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_TERMINAL_RP,		FXMovieManager::onCmdTerminal_rp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_COMMAND_LP,		FXMovieManager::onCmdCommand_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_COMMAND_RP,		FXMovieManager::onCmdCommand_rp),

	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_SCANVIRUS_LP,	FXMovieManager::onCmdScanVirus_lp),
	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_SCANVIRUS_RP,	FXMovieManager::onCmdScanVirus_rp),
	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_ARCHIVE_LP,		FXMovieManager::onCmdArchive_lp),
	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_ARCHIVE_RP,		FXMovieManager::onCmdArchive_rp),

	// file properties 
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_PROPERTIES_LP,	FXMovieManager::onCmdProperties_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_VIDEO_ASPECT_LP,	FXMovieManager::onUpdMovieAspect_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_AUDIO_FORMAT_LP,	FXMovieManager::onUpdAudioFormat_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_CREATED_LP,	FXMovieManager::onUpdCreatedTime_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_MODIFIED_LP,FXMovieManager::onUpdModifiedTime_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_TYPE_LP,	FXMovieManager::onUpdFileType_lp),
	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_MIMETYPE_LP,FXMovieManager::onUpdFileMimeType_lp),
	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_COMMAND_LP,	FXMovieManager::onUpdFileCommand_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_LOCATION_LP,FXMovieManager::onUpdFileLocation_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_SIZE_LP,	FXMovieManager::onUpdFileSize_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_DESC_LP,	FXMovieManager::onUpdFileDesc_lp),

  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_PROPERTIES_RP,	FXMovieManager::onCmdProperties_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_VIDEO_ASPECT_RP,	FXMovieManager::onUpdMovieAspect_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_AUDIO_FORMAT_RP,	FXMovieManager::onUpdAudioFormat_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_CREATED_RP,	FXMovieManager::onUpdCreatedTime_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_MODIFIED_RP,FXMovieManager::onUpdModifiedTime_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_TYPE_RP,	FXMovieManager::onUpdFileType_rp),
	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_MIMETYPE_RP,FXMovieManager::onUpdFileMimeType_rp),
	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_COMMAND_RP,	FXMovieManager::onUpdFileCommand_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_LOCATION_RP,FXMovieManager::onUpdFileLocation_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_SIZE_RP,	FXMovieManager::onUpdFileSize_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_FILE_DESC_RP,	FXMovieManager::onUpdFileDesc_rp),

	// movie info
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_MOVIEINFO_LP,	FXMovieManager::onCmdMovieInfo_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_MOVIEINFO_RP,	FXMovieManager::onCmdMovieInfo_rp),

  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_OWNER_LP,		FXMovieManager::onUpdOwner_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_OWNER_RP,		FXMovieManager::onUpdOwner_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_GROUP_LP,		FXMovieManager::onUpdGroup_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_GROUP_RP,		FXMovieManager::onUpdGroup_rp),

  	FXMAPFUNCS(SEL_COMMAND,			FXMovieManager::ID_READOWNER_LP,	FXMovieManager::ID_STICKY_LP,		FXMovieManager::onCmdFilemode_lp),
  	FXMAPFUNCS(SEL_UPDATE,			FXMovieManager::ID_READOWNER_LP,	FXMovieManager::ID_STICKY_LP,		FXMovieManager::onUpdFilemode_lp),
  	FXMAPFUNCS(SEL_COMMAND,			FXMovieManager::ID_READOWNER_RP,	FXMovieManager::ID_STICKY_RP,		FXMovieManager::onCmdFilemode_rp),
  	FXMAPFUNCS(SEL_UPDATE,			FXMovieManager::ID_READOWNER_RP,	FXMovieManager::ID_STICKY_RP,		FXMovieManager::onUpdFilemode_rp),

	// extensions association 
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_MIMETYPE,		FXMovieManager::onCmdMimeType),

  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_OPEN_LP,			FXMovieManager::onUpdItemFound_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_OPEN_LP,			FXMovieManager::onCmdOpen_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_OPEN_RP,			FXMovieManager::onUpdItemFound_rp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_OPEN_RP,			FXMovieManager::onCmdOpen_rp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_OPENWITH_LP,		FXMovieManager::onUpdItemFound_lp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_OPENWITH_LP,		FXMovieManager::onCmdOpenWith_lp),
  	FXMAPFUNC(SEL_UPDATE,			FXMovieManager::ID_OPENWITH_RP,		FXMovieManager::onUpdItemFound_rp),
  	FXMAPFUNC(SEL_COMMAND,			FXMovieManager::ID_OPENWITH_RP,		FXMovieManager::onCmdOpenWith_rp),
};

FXIMPLEMENT(FXMovieManager, FXMainWindow, FXMovieManagerMap, ARRAYNUMBER(FXMovieManagerMap))

FXMovieManager::FXMovieManager(FXApp *a)
	:FXMainWindow(a, "FXMovieManager", NULL, NULL, DECOR_TITLE|DECOR_MINIMIZE|DECOR_MAXIMIZE|DECOR_CLOSE|DECOR_BORDER|DECOR_SHRINKABLE|DECOR_STRETCHABLE|DECOR_MENU, 0, 0, 800, 42) {

	// set icons for the window manager
	logoicon=new FXPNGIcon(getApp(),fxmm64);
	logomedicon=new FXPNGIcon(getApp(),fxmm32);
	logominiicon=new FXPNGIcon(getApp(),fxmm16);
	splashicon=new FXPNGIcon(getApp(),fxmmsplash);
	setIcon(logoicon);
	setMiniIcon(logominiicon);

	setTarget(this);
	setSelector(ID_MAINWINDOW);
#ifdef HAVE_LIBFOX_1_7
	FXSplashWindow *splash=new FXSplashWindow(a,splashicon,SPLASH_OWNS_ICON|SPLASH_DESTROY,1500000000);
#elif HAVE_LIBFOX_1_6
	FXSplashWindow *splash=new FXSplashWindow(a,splashicon,SPLASH_OWNS_ICON|SPLASH_DESTROY,1500);
#endif
	FXuint place = splash->getDefaultWidth();
	splash->show(place);

	if(!themeSelection()){
		printf("Unable to load THEME!\n");
	}
	if(!languageSelection()){
		printf("Unable to load LANGUAGE!\n");
	}

    // table popup list menu icons
    m_upicon=new FXGIFIcon(getApp(),m_up);
    m_downicon=new FXGIFIcon(getApp(),m_down);
    m_appendicon=new FXGIFIcon(getApp(),m_append);
    m_inserticon=new FXGIFIcon(getApp(),m_insert);
    m_editicon=new FXGIFIcon(getApp(),m_edit);
    m_cancelicon=new FXGIFIcon(getApp(),m_cancel);
    m_accepticon=new FXGIFIcon(getApp(),m_accept);
    // filelist popup file menu icons
    m_propicon=new FXGIFIcon(getApp(),m_properties);
    m_infoicon=new FXGIFIcon(getApp(),m_info);
    m_cuticon=new FXGIFIcon(getApp(),m_cut);  
    m_copyicon=new FXGIFIcon(getApp(),m_copy);
    m_pasteicon=new FXGIFIcon(getApp(),m_paste);
    m_linkicon=new FXGIFIcon(getApp(),m_link);
    m_moveicon=new FXGIFIcon(getApp(),m_move);
    m_renameicon=new FXGIFIcon(getApp(),m_rename);
    m_deleteicon=new FXGIFIcon(getApp(),m_delete);
    m_consoleicon=new FXGIFIcon(getApp(),m_console);
    m_terminalicon=new FXGIFIcon(getApp(),m_terminal);
    m_refreshicon=new FXGIFIcon(getApp(),m_refresh);
    m_renamediricon=new FXGIFIcon(getApp(),m_renamedir);
    m_showhiddenicon=new FXGIFIcon(getApp(),m_showhidden);
    m_bugicon=new FXGIFIcon(getApp(),m_bug);
    m_archiveicon=new FXGIFIcon(getApp(),mime_archive1_small);
    m_searchicon=new FXGIFIcon(getApp(),m_find);
    m_mapicon=new FXBMPIcon(getApp(),m_maphost,0,IMAGE_ALPHAGUESS);
    m_unmapicon=new FXBMPIcon(getApp(),m_unmaphost,0,IMAGE_ALPHAGUESS);
    // filelist header icons
    m_usricon=new FXGIFIcon(getApp(),m_usr);
    m_grpicon=new FXGIFIcon(getApp(),m_grp);
    m_prmicon=new FXGIFIcon(getApp(),m_prm);
    m_dimicon=new FXGIFIcon(getApp(),m_dim);
    m_daticon=new FXGIFIcon(getApp(),m_dat);
    m_diricon=new FXGIFIcon(getApp(),m_dir);

	// menubar
	menubar = new FXMenuBar(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
	quitbutton = new FXButton(menubar,quitbuttontext,quiticon,this,ID_QUIT,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	openbutton = new FXButton(menubar,openbuttontext,openicon,this,ID_FILE,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	audiobutton = new FXToggleButton(menubar,audiobuttontext1,audiobuttontext2,audioicon,audioicon,this,ID_AUDIO,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	dropbutton = new FXToggleButton(menubar,dropbuttontext1,dropbuttontext2,dropicon,dropicon,this,ID_DROP,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	stopbutton = new FXButton(menubar,stopbuttontext,stopicon,this,ID_STOP,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	pausebutton = new FXButton(menubar,pausebuttontext,pauseicon,this,ID_PAUSE,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	playbutton = new FXButton(menubar,playbuttontext,playicon,this,ID_PLAY,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	loopbutton = new FXToggleButton(menubar,loopbuttontext1,loopbuttontext2,loopicon,loopicon,this,ID_LOOP,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);
	zoombutton = new FXToggleButton(menubar,zoombuttontext1,zoombuttontext2,videozoomicon,videozoomicon,this,ID_FULL,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT);

	videosizemenu1 = new FXMenuPane(this);
   	videosizebutton1 = new FXMenuButton(menubar,sizebuttontext,videosizeicon,videosizemenu1,BUTTON_TOOLBAR|MENUBUTTON_DOWN|MENUBUTTON_ATTACH_LEFT|FRAME_RAISED);
#ifdef HAVE_LIBFOX_1_7
	videosizebutton1->showMenu(FALSE);
#endif
	menu_vs01 = new FXMenuRadio(videosizemenu1,"1920x1080",this,ID_SIZE_0);
	menu_vs02 = new FXMenuRadio(videosizemenu1,"1365x768",this,ID_SIZE_1);
	menu_vs03 = new FXMenuRadio(videosizemenu1,"1280x752",this,ID_SIZE_2);
	menu_vs04 = new FXMenuRadio(videosizemenu1,"1280x720",this,ID_SIZE_3);
   	menu_vs05 = new FXMenuRadio(videosizemenu1,"1080x720",this,ID_SIZE_4);
  	menu_vs06 = new FXMenuRadio(videosizemenu1,"1080x576",this,ID_SIZE_5);
	menu_vs07 = new FXMenuRadio(videosizemenu1,"960x540",this,ID_SIZE_6);
  	menu_vs08 = new FXMenuRadio(videosizemenu1,"720x576",this,ID_SIZE_7);
  	menu_vs09 = new FXMenuRadio(videosizemenu1,"640x480",this,ID_SIZE_8);
  	menu_vs10 = new FXMenuRadio(videosizemenu1,"640x384",this,ID_SIZE_9);
  	menu_vs11 = new FXMenuRadio(videosizemenu1,"540x360",this,ID_SIZE_10);
  	menu_vs12 = new FXMenuRadio(videosizemenu1,"480x576",this,ID_SIZE_11);
  	menu_vs13 = new FXMenuRadio(videosizemenu1,"480x480",this,ID_SIZE_12);

	videosizemenu2 = new FXMenuPane(this);
   	videosizebutton2 = new FXMenuButton(menubar,sizebuttontext,videosizeicon,videosizemenu2,BUTTON_TOOLBAR|MENUBUTTON_DOWN|MENUBUTTON_ATTACH_LEFT|FRAME_RAISED);
#ifdef HAVE_LIBFOX_1_7
	videosizebutton2->showMenu(FALSE);
#endif
  	menu_vs14 = new FXMenuRadio(videosizemenu2,"x 3.4",this,ID_SIZE_13);
  	menu_vs15 = new FXMenuRadio(videosizemenu2,"x 3.1",this,ID_SIZE_14);
  	menu_vs16 = new FXMenuRadio(videosizemenu2,"x 2.8",this,ID_SIZE_15);
  	menu_vs17 = new FXMenuRadio(videosizemenu2,"x 2.5",this,ID_SIZE_16);
  	menu_vs18 = new FXMenuRadio(videosizemenu2,"x 2.2",this,ID_SIZE_17);
  	menu_vs19 = new FXMenuRadio(videosizemenu2,"x 1.9",this,ID_SIZE_18);
  	menu_vs20 = new FXMenuRadio(videosizemenu2,"x 1.6",this,ID_SIZE_19);
  	menu_vs21 = new FXMenuRadio(videosizemenu2,"x 1.3",this,ID_SIZE_20);
  	menu_vs22 = new FXMenuRadio(videosizemenu2,"FILESET",this,ID_SIZE_21);
  	menu_vs23 = new FXMenuRadio(videosizemenu2,"x 0.9",this,ID_SIZE_22);
  	menu_vs24 = new FXMenuRadio(videosizemenu2,"x 0.8",this,ID_SIZE_23);
  	menu_vs25 = new FXMenuRadio(videosizemenu2,"x 0.6",this,ID_SIZE_24);
  	menu_vs26 = new FXMenuRadio(videosizemenu2,"CUSTOM",this,ID_SIZE_25);

	videooutmenu = new FXMenuPane(this);
	videooutbutton = new FXMenuButton(menubar,outputbuttontext,videoouticon,videooutmenu,BUTTON_TOOLBAR|MENUBUTTON_DOWN|MENUBUTTON_ATTACH_LEFT|FRAME_RAISED);
#ifdef HAVE_LIBFOX_1_7
	videooutbutton->showMenu(FALSE);
#endif
   	menu_vo01 = new FXMenuRadio(videooutmenu,"X11 ",this,ID_VIDEO_0);
  	menu_vo02 = new FXMenuRadio(videooutmenu,"XV  ",this,ID_VIDEO_1);
  	menu_vo03 = new FXMenuRadio(videooutmenu,"GL  ",this,ID_VIDEO_2);
  	menu_vo04 = new FXMenuRadio(videooutmenu,"GL2 ",this,ID_VIDEO_3);
  	menu_vo05 = new FXMenuRadio(videooutmenu,"SDL ",this,ID_VIDEO_4);
  	menu_vo06 = new FXMenuRadio(videooutmenu,"DGA ",this,ID_VIDEO_5);
  	menu_vo07 = new FXMenuRadio(videooutmenu,"XVID",this,ID_VIDEO_6);
  	menu_vo08 = new FXMenuRadio(videooutmenu,"JPEG",this,ID_VIDEO_7);
  	menu_vo09 = new FXMenuRadio(videooutmenu,"PNG ",this,ID_VIDEO_8);
  	menu_vo10 = new FXMenuRadio(videooutmenu,"NULL",this,ID_VIDEO_9);

    spe_knob = new FXKnob(menubar,this,ID_SPEED,KNOB_NORMAL|LAYOUT_CENTER_Y|LAYOUT_CENTER_X);
  	spe_knob->setRange(0,200);
	spe_knob->setValue(100);
	spe_knob->setIncrement(10);
	spe_knob->setTipText("Speed");
	spe_knob->setHelpText("Speed control");

    vol_knob = new FXKnob(menubar,this,ID_VOLUME,KNOB_NORMAL|LAYOUT_CENTER_Y|LAYOUT_CENTER_X);
  	vol_knob->setRange(0,100);
	vol_knob->setValue(50);
	vol_knob->setIncrement(5);
	vol_knob->setTipText("Volume");
	vol_knob->setHelpText("Volume control");

	// audio delay 
	delayspinner=new FXRealSpinner(menubar,4,this,ID_AUDIODELAY,REALSPIN_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_Y);
	delayspinner->setRange(-100,100);
   	delayspinner->setValue(0);
	delayspinner->setIncrement(0.10);
	delayspinner->setTipText("Audio Delay");
	delayspinner->setHelpText("Audio Delay");

	// brightness
	bri_knob=new FXKnob(menubar,this,ID_BRIGHTNESS,KNOB_NEEDLE|LAYOUT_CENTER_Y|LAYOUT_CENTER_X);
	bri_knob->setRange(-100,100);
   	bri_knob->setValue(0);
	bri_knob->setIncrement(1);
	bri_knob->setTipText("Brightness");
	bri_knob->setHelpText("Brightness");

	// contrast
	con_knob=new FXKnob(menubar,this,ID_CONTRAST,KNOB_NEEDLE|LAYOUT_CENTER_Y|LAYOUT_CENTER_X);
	con_knob->setRange(-100,100);
   	con_knob->setValue(0);
	con_knob->setIncrement(1);
	con_knob->setTipText("Contrast");
	con_knob->setHelpText("Contrast");

	// gamma
/*
	gam_knob=new FXKnob(menubar,this,ID_GAMMA,KNOB_NEEDLE|LAYOUT_CENTER_Y|LAYOUT_CENTER_X);
	gam_knob->setRange(-100,100);
   	gam_knob->setValue(0);
	gam_knob->setIncrement(1);
	gam_knob->setTipText("Gamma");
	gam_knob->setHelpText("Gamma");
*/
	// hue
	hue_knob=new FXKnob(menubar,this,ID_HUE,KNOB_NEEDLE|LAYOUT_CENTER_Y|LAYOUT_CENTER_X);
	hue_knob->setRange(-100,100);
   	hue_knob->setValue(0);
	hue_knob->setIncrement(1);
	hue_knob->setTipText("Hue");
	hue_knob->setHelpText("Hue");

	// saturation
	sat_knob=new FXKnob(menubar,this,ID_SATURATION,KNOB_NEEDLE|LAYOUT_CENTER_Y|LAYOUT_CENTER_X);
	sat_knob->setRange(-100,100);
   	sat_knob->setValue(0);
	sat_knob->setIncrement(1);
	sat_knob->setTipText("Saturation");
	sat_knob->setHelpText("Saturation");

	// Splitter
	splitter1=new FXSplitter(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING|SPLITTER_VERTICAL|SPLITTER_REVERSED);

	// Make tablelist container
	listframe=new FXHorizontalFrame(splitter1,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);

#ifdef HAVE_LIBFOX_1_7
	table=new FXTable(listframe,this,ID_TABLE,TABLE_COL_SIZABLE|TABLE_NO_COLSELECT|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 2,2,2,2);
    table->setRowRenumbering(FXHeader::decimalNumbering);
#elif HAVE_LIBFOX_1_6
	table=new FXTable(listframe,this,ID_TABLE,TABLE_COL_SIZABLE|TABLE_NO_COLSELECT|TABLE_NO_ROWSELECT|TABLE_ROW_RENUMBER|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 2,2,2,2);
  	table->setRowRenumbering(true);
	table->setColumnRenumbering(false);
#endif
  	table->setHelpText("Play List Table");
  	table->setVisibleColumns(9);
	table->setVisibleRows(100);
  	table->setTableSize(100,9);

	FXint c, r;
	for (c=1; c<9; c++){
	  table->setColumnWidth(c,40);
	}
	for (r=0; r<100; r++){
	  table->setRowHeight(r,68);
	}
	resetTable();

	// Initialize column headers
	table->setColumnText(0,"movie name");
	table->setColumnText(1,"hour>");
	table->setColumnText(2,"min>");
	table->setColumnText(3,"sec>");
	table->setColumnText(4,"cent>");
	table->setColumnText(5,"<hour");
	table->setColumnText(6,"<min");
	table->setColumnText(7,"<sec");
	table->setColumnText(8,"<cen");

#ifdef HAVE_LIBFOX_1_7
	// Initialize column tip text
	table->setColumnTipText(0,"full path and movie name");
	table->setColumnTipText(1,"start time in hours");
	table->setColumnTipText(2,"start time in minutes");
	table->setColumnTipText(3,"start time in seconds");
	table->setColumnTipText(4,"start time in cents");
	table->setColumnTipText(5,"duration time in hour");
	table->setColumnTipText(6,"duration time in minutes");
	table->setColumnTipText(7,"duration time in seconds");
	table->setColumnTipText(8,"duration time in cents");
#endif
  	table->dropEnable();

	new FXButton(menubar,confbuttontext,logomedicon,this,ID_MIMETYPE,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT|LAYOUT_RIGHT);
	// new FXButton(menubar,"FileList",listicon,listframe,FXWindow::ID_TOGGLESHOWN,BUTTON_TOOLBAR|FRAME_RAISED|ICON_AFTER_TEXT);
	hidebutton = new FXToggleButton(menubar,hidebuttontext1,hidebuttontext2,hideicon,hideicon,this,ID_MAINWINDOW,BUTTON_TOOLBAR|FRAME_RAISED|ICON_UNDER_TEXT|LAYOUT_RIGHT);

	// right table buttons
	listbuttonframe=new FXVerticalFrame(listframe,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0, 0,0);
	new FXButton(listbuttonframe,upbuttontext,upicon,this,FXMovieManager::ID_MOVESELUP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(listbuttonframe,downbuttontext,downicon,this,FXMovieManager::ID_MOVESELDOWN,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(listbuttonframe,allbuttontext1,showicon,this,FXMovieManager::ID_SELECTALL,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(listbuttonframe,clearbuttontext,deleteicon,this,FXMovieManager::ID_CLEAR,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(listbuttonframe,slistbuttontext,openicon,this,FXMovieManager::ID_SAVELIST,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(listbuttonframe,olistbuttontext,openicon,this,FXMovieManager::ID_OPENLIST,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);


	// Right mouse popup
	popupmenu = new FXMenuPane(this);
	playlistlabel = new FXLabel(popupmenu,"Play List");
	playlistlabel->setTextColor(FXRGB(150,0,0));
	pop_up=new FXMenuCommand(popupmenu,menu_up,m_upicon,this,FXMovieManager::ID_MOVESELUP);
	pop_do=new FXMenuCommand(popupmenu,menu_do,m_downicon,this,FXMovieManager::ID_MOVESELDOWN);
	new FXMenuSeparator(popupmenu);
	pop_al=new FXMenuCommand(popupmenu,menu_al,m_accepticon,this,FXMovieManager::ID_SELECTALL);
	pop_da=new FXMenuCommand(popupmenu,menu_da,m_cancelicon,this,FXMovieManager::ID_CLEAR);
	new FXMenuSeparator(popupmenu);
	pop_ap=new FXMenuCommand(popupmenu,menu_ap,m_appendicon,this,FXMovieManager::ID_APPEND);
	pop_in=new FXMenuCommand(popupmenu,menu_in,m_inserticon,this,FXMovieManager::ID_INSERT);
	pop_ed=new FXMenuCommand(popupmenu,menu_ed,m_editicon,table,FXTable::ID_START_INPUT);
	pop_di=new FXMenuCommand(popupmenu,menu_di,m_cancelicon,this,FXMovieManager::ID_DELETE);

	// Make file associations object; shared between FXFileList and FXDirList
	associations=new FXFileDict(getApp());

	// File box
  	splitter2=new FXSplitter(splitter1,LAYOUT_SIDE_TOP|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING|SPLITTER_HORIZONTAL);

  	filesbuttonframe_lp=new FXHorizontalFrame(splitter2,LAYOUT_FILL_X|LAYOUT_FILL_Y, 0,0,0,0, 0,0,0,0,0,0);
  	filesbuttonframe_rp=new FXHorizontalFrame(splitter2,LAYOUT_FILL_X|LAYOUT_FILL_Y, 0,0,0,0, 0,0,0,0,0,0);

	vbuttonframe_lp=new FXVerticalFrame(filesbuttonframe_lp,LAYOUT_FILL_Y|LAYOUT_SIDE_LEFT,0,0,0,0, 0,0,0,0, 0,0);
  	filesframe_lp=new FXVerticalFrame(filesbuttonframe_lp,LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_THICK|FRAME_SUNKEN|LAYOUT_SIDE_RIGHT, 0,0,180,0, 0,0,0,0,0,0);

  	filesframe_rp=new FXVerticalFrame(filesbuttonframe_rp,LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_THICK|FRAME_SUNKEN|LAYOUT_SIDE_LEFT, 0,0,180,0, 0,0,0,0,0,0);
	vbuttonframe_rp=new FXVerticalFrame(filesbuttonframe_rp,LAYOUT_FILL_Y|LAYOUT_SIDE_RIGHT,0,0,0,0, 0,0,0,0, 0,0);



	paneltoolbar_lp=new FXToolBar(filesframe_lp,LAYOUT_FILL_X);
	new FXButton(paneltoolbar_lp,"&Dir",NULL,this,FXMovieManager::ID_SHOW_DIR_LP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(paneltoolbar_lp,"&File",NULL,this,FXMovieManager::ID_SHOW_FILE_LP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(paneltoolbar_lp,"&GAll",NULL,this,FXMovieManager::ID_SHOW_FULL_LP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);

  	panelframe_lp=new FXHorizontalFrame(filesframe_lp,FRAME_THICK|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y);

	// left Splitter
    splitter_lp=new FXSplitter(panelframe_lp,LAYOUT_SIDE_LEFT|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING|SPLITTER_HORIZONTAL|SPLITTER_REVERSED);
  	// Directory List
  	dirlist_lp=new FXDirList(splitter_lp,this,ID_DIRECTORYLIST_LP,LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_TOP|LAYOUT_RIGHT|TREELIST_SHOWS_LINES|TREELIST_SHOWS_BOXES|TREELIST_BROWSESELECT|DIRLIST_NO_OWN_ASSOC);
  	dirlist_lp->setAssociations(associations);
  	dirlist_lp->dropEnable();
	// Filelist_lp
	filelist_lp=new FXFileList(splitter_lp,this,ID_FILELIST_LP,LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_BIG_ICONS|ICONLIST_AUTOSIZE|FILELIST_NO_OWN_ASSOC);
	filelist_lp->setAssociations(associations);
#ifdef HAVE_LIBFOX_1_7
	filelist_lp->setDraggableFiles(true);
#endif
  	filelist_lp->dropEnable();



	paneltoolbar_rp=new FXToolBar(filesframe_rp,LAYOUT_FILL_X);
	new FXButton(paneltoolbar_rp,"&HDir",NULL,this,FXMovieManager::ID_SHOW_DIR_RP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(paneltoolbar_rp,"&JFile",NULL,this,FXMovieManager::ID_SHOW_FILE_RP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(paneltoolbar_rp,"&KAll",NULL,this,FXMovieManager::ID_SHOW_FULL_RP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);

  	panelframe_rp=new FXHorizontalFrame(filesframe_rp,FRAME_THICK|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y);

	// right Splitter
    splitter_rp=new FXSplitter(panelframe_rp,LAYOUT_SIDE_LEFT|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING|SPLITTER_HORIZONTAL|SPLITTER_REVERSED);
  	// Directory List
  	dirlist_rp=new FXDirList(splitter_rp,this,ID_DIRECTORYLIST_RP,LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_TOP|LAYOUT_RIGHT|TREELIST_SHOWS_LINES|TREELIST_SHOWS_BOXES|TREELIST_BROWSESELECT|DIRLIST_NO_OWN_ASSOC);
  	dirlist_rp->setAssociations(associations);
  	dirlist_rp->dropEnable();
	// Filelist_rp
	filelist_rp=new FXFileList(splitter_rp,this,ID_FILELIST_RP,LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_BIG_ICONS|ICONLIST_AUTOSIZE|FILELIST_NO_OWN_ASSOC);
	filelist_rp->setAssociations(associations);
#ifdef HAVE_LIBFOX_1_7
	filelist_rp->setDraggableFiles(true);
#endif
  	filelist_rp->dropEnable();


  	// MimeType
  	mimetype=new MimeTypeDialog(this);
  	// Properties
  	properties_lp=new PropertiesDialog_lp(this);
  	properties_rp=new PropertiesDialog_rp(this);
	// Player
  	playerdialog=new PlayerDialog(this);
	// File Search
  	filesearchdialog=new FileSearchDialog(this);
    inputdialog=new FileInputDialog(this);

  	// Status bar
  	statusbar=new FXHorizontalFrame(filesframe_lp,LAYOUT_SIDE_BOTTOM|FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_X);
  	statusline=new FXStatusLine(statusbar,this,LAYOUT_FILL_X|LAYOUT_FILL_Y);

  	// Clock on status bar with same colour
  	clock=new FXTextField(statusbar,8,NULL,0,FRAME_SUNKEN|JUSTIFY_RIGHT|LAYOUT_RIGHT|LAYOUT_FILL_Y|TEXTFIELD_READONLY,0,0,0,0,2,2,1,1);
  	clock->setBackColor(statusbar->getBackColor());


	// left filelist buttons *************************************************
	new FXButton(vbuttonframe_lp,upbuttontext,upicon,this,ID_UPDIRECTORY_LP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);

  	selectbutton=new FXToggleButton(vbuttonframe_lp,allbuttontext1,allbuttontext2,showicon,hiddenicon,filelist_lp,FXFileList::ID_SELECT_INVERSE,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe_lp,createbuttontext,createicon,this,ID_FILEPREVIEW_LP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe_lp,recreatebuttontext,recreateicon,this,ID_FORCEFILEPREVIEW_LP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe_lp,deletebuttontext,deletehiddenicon,this,ID_CLEARPREVIEW_LP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);

	sizeframe=new FXHorizontalFrame(vbuttonframe_lp,LAYOUT_FILL_X,0,0,0,0, 0,0,0,0, 0,0);
	new FXButton(sizeframe,increasebuttontext,increaseicon,this,ID_INCFILEPREVIEW_LP,BUTTON_TOOLBAR|LAYOUT_LEFT);
	new FXButton(sizeframe,decreasebuttontext,decreaseicon,this,ID_DECFILEPREVIEW_LP,BUTTON_TOOLBAR|LAYOUT_RIGHT);

    readPreConfig();
    if(widescreen==FALSE){
  	  widebutton=new FXToggleButton(vbuttonframe_lp,widebuttontext1,widebuttontext2,videoicon,videoicon,this,ID_WIDESCREEN,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
    }else if(widescreen==TRUE){
  	  widebutton=new FXToggleButton(vbuttonframe_lp,widebuttontext2,widebuttontext1,videoicon,videoicon,this,ID_WIDESCREEN,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
    }else{
      widescreen==FALSE;
  	  widebutton=new FXToggleButton(vbuttonframe_lp,widebuttontext1,widebuttontext2,videoicon,videoicon,this,ID_WIDESCREEN,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
    }

//	new FXMenuSeparator(vbuttonframe_lp);
	new FXButton(vbuttonframe_lp,stopbuttontext,stopicon,this,ID_FILESTOP_LP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe_lp,pausebuttontext,pauseicon,this,ID_FILEPAUSE_LP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe_lp,playbuttontext,playicon,this,ID_FILEPLAY_LP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
//	new FXMenuSeparator(vbuttonframe_lp);
	new FXButton(vbuttonframe_lp,jplaybuttontext,playicon,this,ID_IFILEPLAY_LP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
//	new FXMenuSeparator(vbuttonframe_lp);

	switchframe=new FXHorizontalFrame(vbuttonframe_lp,LAYOUT_FILL_X|LAYOUT_BOTTOM,0,0,0,0, 0,0,0,0, 0,0);
	new FXButton(switchframe,detlisttext,detlisticon,filelist_lp,FXFileList::ID_SHOW_DETAILS,BUTTON_TOOLBAR|LAYOUT_LEFT);
	new FXButton(switchframe,icnlisttext,icnlisticon,filelist_lp,FXFileList::ID_SHOW_BIG_ICONS,BUTTON_TOOLBAR|LAYOUT_RIGHT);

  	new FXToggleButton(vbuttonframe_lp,imgbuttontext2,imgbuttontext1,imgpreview2icon,imgpreview1icon,filelist_lp,FXFileList::ID_TOGGLE_IMAGES,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_BOTTOM);


	// right filelist buttons **********************************************
	new FXButton(vbuttonframe_rp,upbuttontext,upicon,this,ID_UPDIRECTORY_RP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);

  	selectbutton=new FXToggleButton(vbuttonframe_rp,allbuttontext1,allbuttontext2,showicon,hiddenicon,filelist_rp,FXFileList::ID_SELECT_INVERSE,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe_rp,createbuttontext,createicon,this,ID_FILEPREVIEW_RP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe_rp,recreatebuttontext,recreateicon,this,ID_FORCEFILEPREVIEW_RP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);

	new FXButton(vbuttonframe_rp,deletebuttontext,deletehiddenicon,this,ID_CLEARPREVIEW_RP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);

	sizeframe=new FXHorizontalFrame(vbuttonframe_rp,LAYOUT_FILL_X,0,0,0,0, 0,0,0,0, 0,0);
	new FXButton(sizeframe,increasebuttontext,increaseicon,this,ID_INCFILEPREVIEW_RP,BUTTON_TOOLBAR|LAYOUT_LEFT);
	new FXButton(sizeframe,decreasebuttontext,decreaseicon,this,ID_DECFILEPREVIEW_RP,BUTTON_TOOLBAR|LAYOUT_RIGHT);

//	new FXMenuSeparator(vbuttonframe_rp);

	// relative value for incrementing the seekspinner
	relatspinner=new FXRealSpinner(vbuttonframe_rp,2,NULL,0,REALSPIN_CYCLIC|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
	relatspinner->setRange(0,100);
	relatspinner->setValue(0);
	relatspinner->setIncrement(1);
#else
	relatspinner->setRange(0.0,9.1);
	relatspinner->setValue(0.0);
	relatspinner->setIncrement(0.1);
#endif

	// seek value for movie preview
	seekspinner=new FXRealSpinner(vbuttonframe_rp,2,this,ID_SEEKINCREMENT,REALSPIN_CYCLIC|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
	seekspinner->setRange(0,100);
	seekspinner->setValue(1);
	seekspinner->setIncrement(1);
#else
	seekspinner->setRange(0.0,9.1);
	seekspinner->setValue(0.1);
	seekspinner->setIncrement(0.1);
#endif

//	new FXMenuSeparator(vbuttonframe_rp);
	new FXButton(vbuttonframe_rp,stopbuttontext,stopicon,this,ID_FILESTOP_RP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe_rp,pausebuttontext,pauseicon,this,ID_FILEPAUSE_RP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
	new FXButton(vbuttonframe_rp,playbuttontext,playicon,this,ID_FILEPLAY_RP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
//	new FXMenuSeparator(vbuttonframe_rp);
	new FXButton(vbuttonframe_rp,jplaybuttontext,playicon,this,ID_IFILEPLAY_RP,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X);
//	new FXMenuSeparator(vbuttonframe_rp);

	switchframe=new FXHorizontalFrame(vbuttonframe_rp,LAYOUT_FILL_X|LAYOUT_BOTTOM,0,0,0,0, 0,0,0,0, 0,0);
	new FXButton(switchframe,detlisttext,detlisticon,filelist_rp,FXFileList::ID_SHOW_DETAILS,BUTTON_TOOLBAR|LAYOUT_LEFT);
	new FXButton(switchframe,icnlisttext,icnlisticon,filelist_rp,FXFileList::ID_SHOW_BIG_ICONS,BUTTON_TOOLBAR|LAYOUT_RIGHT);

  	new FXToggleButton(vbuttonframe_rp,imgbuttontext2,imgbuttontext1,imgpreview2icon,imgpreview1icon,filelist_rp,FXFileList::ID_TOGGLE_IMAGES,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_BOTTOM);

	// *************************************************************************************************
  	// Add accelerators into the table
	//		 addAccel(	 FXHotKey	  target	(FXSelector seldn, FXSelector selup)

  	getAccelTable()->addAccel(MKUINT(KEY_F1,0),this,FXSEL(SEL_COMMAND,ID_MIMETYPE));

	// CONTROLMASK --> Left Panel
  	getAccelTable()->addAccel(MKUINT(KEY_BackSpace,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_UPDIRECTORY_LP));	
  	getAccelTable()->addAccel(MKUINT(KEY_Delete,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILEDELETE_LP));
  	getAccelTable()->addAccel(MKUINT(KEY_F2,CONTROLMASK),filelist_lp,FXSEL(SEL_COMMAND,FXFileList::ID_SELECT_INVERSE));
  	getAccelTable()->addAccel(MKUINT(KEY_F3,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILEPREVIEW_LP));
  	getAccelTable()->addAccel(MKUINT(KEY_F4,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FORCEFILEPREVIEW_LP));
  	getAccelTable()->addAccel(MKUINT(KEY_F5,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_INCFILEPREVIEW_LP));
  	getAccelTable()->addAccel(MKUINT(KEY_F6,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_DECFILEPREVIEW_LP));
  	getAccelTable()->addAccel(MKUINT(KEY_F7,CONTROLMASK),filelist_lp,FXSEL(SEL_COMMAND,FXFileList::ID_SHOW_BIG_ICONS));
  	getAccelTable()->addAccel(MKUINT(KEY_F8,CONTROLMASK),filelist_lp,FXSEL(SEL_COMMAND,FXFileList::ID_SHOW_DETAILS));
 	// OPERATIONS DIALOG
	getAccelTable()->addAccel(MKUINT(KEY_p,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILERENAME_LP));
	getAccelTable()->addAccel(MKUINT(KEY_P,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILERENAME_LP));

  	getAccelTable()->addAccel(MKUINT(KEY_c,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILECOPY_LP));
  	getAccelTable()->addAccel(MKUINT(KEY_C,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILECOPY_LP));
	getAccelTable()->addAccel(MKUINT(KEY_m,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILEMOVE_LP));
	getAccelTable()->addAccel(MKUINT(KEY_M,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILEMOVE_LP));
	getAccelTable()->addAccel(MKUINT(KEY_s,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILESYMLINK_LP));
	getAccelTable()->addAccel(MKUINT(KEY_S,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILESYMLINK_LP));
	// PLAYER
	getAccelTable()->addAccel(MKUINT(KEY_z,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILEPLAY_LP));
	getAccelTable()->addAccel(MKUINT(KEY_Z,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILEPLAY_LP));
  	getAccelTable()->addAccel(MKUINT(KEY_a,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILEPAUSE_LP));	
  	getAccelTable()->addAccel(MKUINT(KEY_A,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILEPAUSE_LP));
   	getAccelTable()->addAccel(MKUINT(KEY_q,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILESTOP_LP));	
	getAccelTable()->addAccel(MKUINT(KEY_Q,CONTROLMASK),this,FXSEL(SEL_COMMAND,ID_FILESTOP_LP));


	// NONE     --> Right Panel 
  	getAccelTable()->addAccel(MKUINT(KEY_BackSpace,0),this,FXSEL(SEL_COMMAND,ID_UPDIRECTORY_RP));
	getAccelTable()->addAccel(MKUINT(KEY_Delete,0),this,FXSEL(SEL_COMMAND,ID_FILEDELETE_RP));
  	getAccelTable()->addAccel(MKUINT(KEY_F2,0),filelist_rp,FXSEL(SEL_COMMAND,FXFileList::ID_SELECT_INVERSE));
  	getAccelTable()->addAccel(MKUINT(KEY_F3,0),this,FXSEL(SEL_COMMAND,ID_FILEPREVIEW_RP));
  	getAccelTable()->addAccel(MKUINT(KEY_F4,0),this,FXSEL(SEL_COMMAND,ID_FORCEFILEPREVIEW_RP));
  	getAccelTable()->addAccel(MKUINT(KEY_F5,0),this,FXSEL(SEL_COMMAND,ID_INCFILEPREVIEW_RP));
  	getAccelTable()->addAccel(MKUINT(KEY_F6,0),this,FXSEL(SEL_COMMAND,ID_DECFILEPREVIEW_RP));
  	getAccelTable()->addAccel(MKUINT(KEY_F7,0),filelist_rp,FXSEL(SEL_COMMAND,FXFileList::ID_SHOW_BIG_ICONS));
  	getAccelTable()->addAccel(MKUINT(KEY_F8,0),filelist_rp,FXSEL(SEL_COMMAND,FXFileList::ID_SHOW_DETAILS));
 	// OPERATIONS DIALOG
	getAccelTable()->addAccel(MKUINT(KEY_p,ALTMASK),this,FXSEL(SEL_COMMAND,ID_FILERENAME_RP));
	getAccelTable()->addAccel(MKUINT(KEY_P,ALTMASK),this,FXSEL(SEL_COMMAND,ID_FILERENAME_RP));

  	getAccelTable()->addAccel(MKUINT(KEY_c,ALTMASK),this,FXSEL(SEL_COMMAND,ID_FILECOPY_RP));
  	getAccelTable()->addAccel(MKUINT(KEY_C,ALTMASK),this,FXSEL(SEL_COMMAND,ID_FILECOPY_RP));
	getAccelTable()->addAccel(MKUINT(KEY_m,ALTMASK),this,FXSEL(SEL_COMMAND,ID_FILEMOVE_RP));
	getAccelTable()->addAccel(MKUINT(KEY_M,ALTMASK),this,FXSEL(SEL_COMMAND,ID_FILEMOVE_RP));
	getAccelTable()->addAccel(MKUINT(KEY_s,ALTMASK),this,FXSEL(SEL_COMMAND,ID_FILESYMLINK_RP));
	getAccelTable()->addAccel(MKUINT(KEY_S,ALTMASK),this,FXSEL(SEL_COMMAND,ID_FILESYMLINK_RP));
	// PLAYER
	getAccelTable()->addAccel(MKUINT(KEY_z,ALTMASK),this,FXSEL(SEL_COMMAND,ID_FILEPLAY_RP));
	getAccelTable()->addAccel(MKUINT(KEY_Z,ALTMASK),this,FXSEL(SEL_COMMAND,ID_FILEPLAY_RP));
  	getAccelTable()->addAccel(MKUINT(KEY_a,ALTMASK),this,FXSEL(SEL_COMMAND,ID_FILEPAUSE_RP));	
  	getAccelTable()->addAccel(MKUINT(KEY_A,ALTMASK),this,FXSEL(SEL_COMMAND,ID_FILEPAUSE_RP));
   	getAccelTable()->addAccel(MKUINT(KEY_q,ALTMASK),this,FXSEL(SEL_COMMAND,ID_FILESTOP_RP));	
	getAccelTable()->addAccel(MKUINT(KEY_Q,ALTMASK),this,FXSEL(SEL_COMMAND,ID_FILESTOP_RP));


	// Progress bar
  	progressframe=new FXHorizontalFrame(filesframe_rp,LAYOUT_FILL_X|FRAME_THICK|FRAME_SUNKEN, 0,0,0,0, 0,0,0,0,0,0);
	progressbar=new FXProgressBar(progressframe,NULL,0,PROGRESSBAR_HORIZONTAL|PROGRESSBAR_PERCENTAGE|PROGRESSBAR_NORMAL|LAYOUT_FILL_X);


  	// Make a tool tip
  	tooltip=new FXToolTip(getApp(),0);

	// inithialize some parameters
	FXString currentUser = FXSystem::currentUserName();
	printf("the Current User is: %s\n", currentUser.text());
	FXString currentTemp = FXSystem::getTempDirectory();
	printf("the Temp Directory is: %s\n", currentTemp.text());
	FXString createTempDir="test -d "+currentTemp+"/.fxmm-"+currentUser+" || mkdir "+currentTemp+"/.fxmm-"+currentUser;
	system (createTempDir.text());

	currentInfo_lp=currentTemp+"/.fxmm-"+currentUser+"/infol.txt";
	currentInfo_rp=currentTemp+"/.fxmm-"+currentUser+"/infor.txt";
	currentFifo=currentTemp+"/.fxmm-"+currentUser+"/fifo";
	removeTempFifo="test -p "+currentFifo+" && rm "+currentFifo;
	createTempFifo="test -p "+currentFifo+" || mkfifo "+currentFifo;
	system (createTempFifo.text());

	language = "en";
	isrunning = FALSE;
	time_a = delayspinner->getValue();

}

FXMovieManager::~FXMovieManager() {
	// button icons
	delete audioicon;
	delete createicon; 
	delete decreaseicon; 
	delete deleteicon; 
	delete deletehiddenicon; 
	delete downicon;
	delete dropicon; 
	delete hiddenicon;
	delete hideicon; 
	delete increaseicon; 
	delete loopicon;
	delete openicon; 
	delete pauseicon;
	delete playicon;
	delete quiticon;
	delete recreateicon; 
	delete showicon; 
	delete stopicon;
	delete upicon;
	delete videoicon;
	delete videozoomicon;
	delete videosizeicon;
	delete videoouticon;
	delete icnlisticon;
	delete detlisticon;
	// pop-up menu icons
	delete m_bugicon;
	delete m_upicon;
	delete m_downicon;
	delete m_appendicon;
	delete m_inserticon;
	delete m_editicon;
	delete m_accepticon;
	delete m_cancelicon;
	delete m_archiveicon;
	delete m_searchicon;
	delete m_mapicon;
	delete m_unmapicon;
	delete m_cuticon;
	delete m_copyicon;
	delete m_pasteicon;
	delete m_linkicon;
	delete m_moveicon;
	delete m_renameicon;
	delete m_deleteicon;
	delete m_propicon;
	delete m_infoicon;
	delete m_consoleicon;
	delete m_terminalicon;
    delete m_refreshicon;
    delete m_renamediricon;
    delete m_showhiddenicon;
	// filelist header icons
    delete m_usricon;
    delete m_grpicon;
    delete m_prmicon;
    delete m_dimicon;
    delete m_daticon;
    delete m_diricon;

  	getApp()->removeTimeout(this,ID_CLOCKTIME);

}

// playlist-filemanager hide command
long FXMovieManager::onCmdPutBack(FXObject *,FXSelector,void *) {
	//printf("show command\n");
	if(listshow == FALSE){
			FXMainWindow::setHeight(600);
			FXMainWindow::repaint();
       		FXMainWindow::show(PLACEMENT_SCREEN);
			hidebutton->setState(FALSE);
			listshow = TRUE;
			printf("now show is true\n");
	}
	else if(listshow == TRUE){
			FXMainWindow::setHeight(42);
			FXMainWindow::repaint();
        	FXMainWindow::show(PLACEMENT_SCREEN);
			hidebutton->setState(TRUE);
			listshow = FALSE;
			printf("now show is false\n");
	}
	else {
			listshow = FALSE;
			printf("default show is false\n");
	}	
	return 1;
}


long FXMovieManager::onCmdShowPanel_lp(FXObject* sender,FXSelector sel,void* ptr){

	FXint shown_width=filesframe_lp->getWidth();

    switch(FXSELID(sel))
    {
    case ID_SHOW_FULL_LP:
		//panel_view_lp=FULL_PANEL;
		filelist_lp->setWidth((FXint)round(shown_width/2));
		if (!dirlist_lp->shown())
    		dirlist_lp->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);
		if (!filelist_lp->shown())
			filelist_lp->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);	
        break;

	case ID_SHOW_DIR_LP:
		//panel_view_lp=DIR_PANEL;
		if (filelist_lp->shown())
			filelist_lp->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);	
		if (!dirlist_lp->shown())
    		dirlist_lp->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);
        break;

	case ID_SHOW_FILE_LP:
		//panel_view_lp=FILE_PANEL;
		if (dirlist_lp->shown())
    		dirlist_lp->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);
		if (!filelist_lp->shown())
			filelist_lp->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);	
        break;
	}
}

long FXMovieManager::onCmdShowPanel_rp(FXObject* sender,FXSelector sel,void* ptr){

	FXint shown_width=filesframe_rp->getWidth();

    switch(FXSELID(sel))
    {
    case ID_SHOW_FULL_RP:
		//panel_view_rp=FULL_PANEL;
		filelist_rp->setWidth((FXint)round(shown_width/2));
		if (!dirlist_rp->shown())
    		dirlist_rp->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);
		if (!filelist_rp->shown())
			filelist_rp->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);	
        break;

	case ID_SHOW_DIR_RP:
		//panel_view_rp=DIR_PANEL;
		if (filelist_rp->shown())
			filelist_rp->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);	
		if (!dirlist_rp->shown())
    		dirlist_rp->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);
        break;

	case ID_SHOW_FILE_RP:
		//panel_view_rp=FILE_PANEL;
		if (dirlist_rp->shown())
    		dirlist_rp->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);
		if (!filelist_rp->shown())
			filelist_rp->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);	
        break;
	}
}


void FXMovieManager::synchronize_lp(FXString& synchdir){

  if(!synchdir.empty()){
    //printf("left dir is: %s\n", synchdir.text());
    dirlist_lp->setDirectory(synchdir);
    filelist_lp->setDirectory(synchdir);
  }

}

void FXMovieManager::synchronize_rp(FXString& synchdir){

  if(!synchdir.empty()){
    //printf("right dir is: %s\n", synchdir.text());
    dirlist_rp->setDirectory(synchdir);
    filelist_rp->setDirectory(synchdir);
  }

}


/********************** FILE SEARCH ENGINE *************************/

long FXMovieManager::onCmdFileSearch_lp(FXObject*,FXSelector,void*){

  if(!cmdFileSearch(filelist_lp)) 
    FXMessageBox::warning(this,MBOX_OK,"SORRY","Search interrupted!");
  else
    prnReport(filelist_lp);
  return 1;
}


long FXMovieManager::onCmdFileSearch_rp(FXObject*,FXSelector,void*){

  if(!cmdFileSearch(filelist_rp))
    FXMessageBox::warning(this,MBOX_OK,"SORRY","Search interrupted!");
  else
    prnReport(filelist_rp);
  return 1;
}


FXbool FXMovieManager::cmdFileSearch(FXFileList* panel){

  filesearchdialog->clearItems();
  FXString filename, ffilename, dirname, filetoscan;
  FXuint opt;
  // get and store the directory where to search for
  cursearchdir=FXPath::enquote(panel->getDirectory());
  // select the directory in the filelist and desynchronize with dirlist 
  panel->setCurrentFile(cursearchdir);
  // advise if searching in the top directory
  if(cursearchdir==PATHSEPSTRING){
    if(FXMessageBox::information(this,MBOX_OK,"THE TOP DIRECTORY IS SELECTED", "Searching in the top directory is NOT allowed")){
      // resynchronize dirlist with filelist 
      if(panel==filelist_lp) synchronize_lp(cursearchdir);
      else if (panel==filelist_rp) synchronize_rp(cursearchdir);
	  return FALSE;
    } 
  } 

  // get the name of the file to search for
  if(inputdialog->getString(filetoscan,opt,this)){
    printf("search option is: %i\n", opt);
	// recursively update list of files
    for(FXint i=1; i<panel->getNumItems(); i++){
        // on the main directory scan only selected files
    	if(panel->isItemSelected(i)){
			if(panel->isItemDirectory(i)){
       			dirname=panel->getItemPathname(i);
				recursiveScan(filetoscan, dirname, opt);
			}
			else
			if(panel->isItemFile(i)){
				filename=panel->getItemFilename(i);
				if(matchFileContainingName(filename,filetoscan,opt)==true){
					ffilename=FXPath::absolute(panel->getDirectory(),filename);
					updReport(ffilename);
				}
			}
		}	
	}
    return TRUE;
  }
  if(panel==filelist_lp) synchronize_lp(cursearchdir);
  else if (panel==filelist_rp) synchronize_rp(cursearchdir);

  return FALSE;
}


inline void FXMovieManager::recursiveScan(const FXString& filetoscan, const FXString& dirname, FXuint opt){

    FXSplitter *splitternew=new FXSplitter(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING|SPLITTER_VERTICAL|SPLITTER_REVERSED);
	FXFileList *panel=new FXFileList(splitternew,this,0,LAYOUT_FILL_X|ICONLIST_MINI_ICONS|ICONLIST_AUTOSIZE|FILELIST_NO_OWN_ASSOC);
  	FXString searchpath=FXPath::absolute(dirname);
  	panel->setDirectory(searchpath);
	FXString nextdir, filename, ffilename;
    // start from 0 means go upper level
    for(FXint i=1; i<panel->getNumItems(); i++){
		if(panel->isItemDirectory(i)){
   			nextdir=panel->getItemPathname(i);
			recursiveScan(filetoscan, nextdir, opt); // recursion
		}
		else
		if(panel->isItemFile(i)){
			filename=panel->getItemFilename(i);
				if(matchFileContainingName(filename,filetoscan,opt)==true){
				ffilename=FXPath::absolute(panel->getDirectory(),filename);
				updReport(ffilename);
			}
		}
	}
	return;
}


FXbool FXMovieManager::matchFileContainingName(const FXString& filename, const FXString& name, FXuint opt){
	FXString lfilename, lname;
	switch(opt)
    {
    case 0:
		if(compare(filename,name)==0)
			return true;
		break;
    case 1:
		if(comparecase(filename,name)==0)
			return true;
		break;
	case 2:
		if(filename.contains(name))
			return true;
		break;
	case 3:
		lfilename=filename;
		lname=name;
		lfilename.lower();
		lname.lower();
		if(lfilename.contains(lname))
			return true;
		break;
	}
	return false;
}


void FXMovieManager::updReport(const FXString& filename){

  filesearchdialog->appendItem(filename);
  return;
}


void FXMovieManager::prnReport(FXFileList* panel){

  if(filesearchdialog->execute()){
    searchfile = filesearchdialog->getCurrentItem();
	FXuint answer=FXMessageBox::information(this,MBOX_OK_CANCEL,"SELECTING FILENAME","SELECT THE FILE? %s\n",searchfile.text());
  	if(answer==MBOX_CLICKED_CANCEL){
      // restore current directory and resynchronize dirlist with filelist 
	  if(panel==filelist_lp) synchronize_lp(cursearchdir);
	  else if (panel==filelist_rp) synchronize_rp(cursearchdir);
	  return;
	} 
	else if(answer==MBOX_CLICKED_OK){
      // select the wanted file
      panel->setCurrentFile(searchfile);
      FXString curdir=panel->getDirectory();
      // resynchronize dirlist with filelist 
	  if(panel==filelist_lp) synchronize_lp(curdir);
	  else if (panel==filelist_rp) synchronize_rp(curdir);
    }
  }
  else{
    // getApp()->beep();
    // restore current directory and resynchronize dirlist with filelist 
	if(panel==filelist_lp) synchronize_lp(cursearchdir);
    else if (panel==filelist_rp) synchronize_rp(cursearchdir);
  }
  return;
}


/*********************** UPDATE CLOCK **************************/

// Update clock
long FXMovieManager::onClock(FXObject*,FXSelector,void*){
#ifdef HAVE_LIBFOX_1_7
  FXTime now=FXThread::time();
  // show time
  clock->setText(FXSystem::localTime(tr("%H:%M:%S"),now));
  // tooltip date
  clock->setTipText(FXSystem::localTime(tr("%A %d %B %Y"),now));
  getApp()->addTimeout(this,ID_CLOCKTIME,CLOCKTIMER);
#endif
  return 0;
  }


/*********************** ROUTINES ******************************/

// Auto Show Thumbnails option
void FXMovieManager::showFilelistThumbnails_lp() {
    showThumbnails(filelist_lp);
    return;
}

void FXMovieManager::showFilelistThumbnails_rp() {
    showThumbnails(filelist_rp);
    return;
}

void FXMovieManager::showThumbnails(FXFileList* panel) {
    FXString file,filetoplay;
    for(FXint i=0; i<panel->getNumItems(); i++){

       	file=panel->getItemFilename(i);
        if(file=="..") continue;
		if(panel->isItemDirectory(i)) continue;
    	if(loadfilevideo(file)==FALSE) continue;
		if(autoThumbnailShow==TRUE){
			FXString rootname,imagename;
        	rootname="."+FXPath::stripExtension(file);
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
        	imagename=(panel->getDirectory()+"/"+rootname+"_thumbnail.jpg");
#else
        	imagename=FXPath::enquote(panel->getDirectory())+"/"+rootname+"00000001/00000001.jpg";
#endif
    		FXFile truefile;
			FXbool istruefile = truefile.open(imagename);
			if(autoThumbnailCreate==TRUE){
				if(!istruefile){
        			filetoplay=FXPath::absolute(panel->getDirectory(),file);
					if(!createImageMovie(filetoplay,rootname)){
						FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Creation Failure","Error on creating thumbnail: %s",imagename.text());
  	    				if(answer==MBOX_CLICKED_CANCEL){
	      					return;
	    				}
					}
					if(!previewMovie(panel, imagename, i, imgw, imgh)){
						FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Loading Failure","Error on loading thumbnail: %s",imagename.text());
  	    				if(answer==MBOX_CLICKED_CANCEL){
	      					return;
	    				}
					}
				}
			}
			if(istruefile){
				if(!previewMovie(panel, imagename, i, imgw, imgh)){
					FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Loading Failure","Error on loading thumbnail: %s",imagename.text());
  	    			if(answer==MBOX_CLICKED_CANCEL){
	      				return;
	    			}
				}
			}
			else{
				continue;
			}
    	}
    }
    return;
}


// Load video files if extension match
FXbool FXMovieManager::loadfileimage(const FXString& filename){
	FXString ext=FXPath::extension(filename);

	if(comparecase(ext,"jpg")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"JPG")==0){
		return TRUE;
	}
	else if(comparecase(ext,"jpeg")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"JPEG")==0){
		return TRUE;
	}

	else {
		return FALSE;
	}
	return FALSE;
}




// Load video files if extension match
FXbool FXMovieManager::loadfilevideo(const FXString& filename){
	FXString ext=FXPath::extension(filename);

	if(comparecase(ext,"mpeg")==0){
		return TRUE;
	}
	else if(comparecase(ext,"MPEG")==0){
		return TRUE;
	}
	else if(comparecase(ext,"mpg")==0){
		return TRUE;
	}
	else if(comparecase(ext,"MPG")==0){
		return TRUE;
	}
	else if(comparecase(ext,"mpe")==0){
		return TRUE;
	}
	else if(comparecase(ext,"MPE")==0){
		return TRUE;
	}

	else if(comparecase(ext,"wmv")==0){
		return TRUE;
	}
	else if(comparecase(ext,"WMV")==0){
		return TRUE;
	}
	else if(comparecase(ext,"wmx")==0){
		return TRUE;
	}
	else if(comparecase(ext,"WMX")==0){
		return TRUE;
	}
	else if(comparecase(ext,"asf")==0){
		return TRUE;
	}
	else if(comparecase(ext,"ASF")==0){
		return TRUE;
	}
	else if(comparecase(ext,"asx")==0){
		return TRUE;
	}
	else if(comparecase(ext,"ASX")==0){
		return TRUE;
	}

	else if(comparecase(ext,"avi")==0){
		return TRUE;
	}
	else if(comparecase(ext,"AVI")==0){
		return TRUE;
	}

	else if(comparecase(ext,"mp4")==0){
		return TRUE;
	}
	else if(comparecase(ext,"MP4")==0){
		return TRUE;
	}
	else if(comparecase(ext,"mov")==0){
		return TRUE;
	}
	else if(comparecase(ext,"MOV")==0){
		return TRUE;
	}
	else if(comparecase(ext,"mod")==0){
		return TRUE;
	}
	else if(comparecase(ext,"MOD")==0){
		return TRUE;
	}
	else if(comparecase(ext,"qt")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"QT")==0){
		return TRUE;
	}
	else if(comparecase(ext,"f4v")==0){
		return TRUE;
	}
	else if(comparecase(ext,"F4V")==0){
		return TRUE;
	}

	else if(comparecase(ext,"divx")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"DIVX")==0){
		return TRUE;
	}
	else if(comparecase(ext,"xvid")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"XVID")==0){
		return TRUE;
	}

	else if(comparecase(ext,"3gp")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"3GP")==0){
		return TRUE;
	}
	else if(comparecase(ext,"3gp2")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"3GP2")==0){
		return TRUE;
	}

	else if(comparecase(ext,"mkv")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"MKV")==0){
		return TRUE;
	}

	else if(comparecase(ext,"ogv")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"OGV")==0){
		return TRUE;
	}
	else if(comparecase(ext,"ogm")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"OGM")==0){
		return TRUE;
	}
	else if(comparecase(ext,"ogg")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"OGG")==0){
		return TRUE;
	}

	else if(comparecase(ext,"vob")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"VOB")==0){
		return TRUE;
	}

	else if(comparecase(ext,"flv")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"FLV")==0){
		return TRUE;
	}
	else if(comparecase(ext,"fli")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"FLI")==0){
		return TRUE;
	}

	else if(comparecase(ext,"gl")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"GL")==0){
		return TRUE;
	}
	else if(comparecase(ext,"dl")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"DL")==0){
		return TRUE;
	}

	else if(comparecase(ext,"dif")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"DIF")==0){
		return TRUE;
	}
	else if(comparecase(ext,"dv")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"DV")==0){
		return TRUE;
	}

	else if(comparecase(ext,"rm")==0){
		return TRUE;
	}
	else if(comparecase(ext,"RM")==0){
		return TRUE;
	}

	else if(comparecase(ext,"movie")==0){ 
		return TRUE;
	}
	else if(comparecase(ext,"MOVIE")==0){
		return TRUE;
	}

	else if(comparecase(ext,unkextension0)==0){ 
		return TRUE;
	}
	else if(comparecase(ext,unkextension1)==0){
		return TRUE;
	}
	else if(comparecase(ext,unkextension2)==0){ 
		return TRUE;
	}
	else if(comparecase(ext,unkextension3)==0){
		return TRUE;
	}
	else if(comparecase(ext,unkextension4)==0){ 
		return TRUE;
	}
	else if(comparecase(ext,unkextension5)==0){
		return TRUE;
	}
	else if(comparecase(ext,unkextension6)==0){ 
		return TRUE;
	}
	else if(comparecase(ext,unkextension7)==0){
		return TRUE;
	}

	else {
		return FALSE;
	}
	return FALSE;
}


// Load audio files if extension match
FXbool FXMovieManager::loadfileaudio(const FXString& filename){
	FXString ext=FXPath::extension(filename);

	if(comparecase(ext,"au")==0){
		return TRUE;
	}
	else if(comparecase(ext,"AU")==0){
		return TRUE;
	}
	else if(comparecase(ext,"snd")==0){
		return TRUE;
	}
	else if(comparecase(ext,"SND")==0){
		return TRUE;
	}

	else if(comparecase(ext,"mp2")==0){
		return TRUE;
	}
	else if(comparecase(ext,"MP2")==0){
		return TRUE;
	}
	else if(comparecase(ext,"mp3")==0){
		return TRUE;
	}
	else if(comparecase(ext,"MP3")==0){
		return TRUE;
	}
	else if(comparecase(ext,"mpga")==0){
		return TRUE;
	}
	else if(comparecase(ext,"MPGA")==0){
		return TRUE;
	}
	else if(comparecase(ext,"mpega")==0){
		return TRUE;
	}
	else if(comparecase(ext,"MPEGA3")==0){
		return TRUE;
	}

	else if(comparecase(ext,"ra")==0){
		return TRUE;
	}
	else if(comparecase(ext,"RA")==0){
		return TRUE;
	}
	else if(comparecase(ext,"ram")==0){
		return TRUE;
	}
	else if(comparecase(ext,"RAM")==0){
		return TRUE;
	}

	else if(comparecase(ext,"wav")==0){
		return TRUE;
	}
	else if(comparecase(ext,"WAV")==0){
		return TRUE;
	}

	else if(comparecase(ext,"wma")==0){
		return TRUE;
	}
	else if(comparecase(ext,"WMA")==0){
		return TRUE;
	}
	else if(comparecase(ext,"wax")==0){
		return TRUE;
	}
	else if(comparecase(ext,"WAX")==0){
		return TRUE;
	}

	else if(comparecase(ext,"mod")==0){
		return TRUE;
	}
	else if(comparecase(ext,"MOD")==0){
		return TRUE;
	}

	else if(comparecase(ext,"mid")==0){
		return TRUE;
	}
	else if(comparecase(ext,"MID")==0){
		return TRUE;
	}
	else if(comparecase(ext,"midi")==0){
		return TRUE;
	}
	else if(comparecase(ext,"MIDI")==0){
		return TRUE;
	}

	else {
		return FALSE;
	}
	return FALSE;
}


// Load imagemovie in the play-TABLE list for preview
FXbool FXMovieManager::previewListMovie(const FXString& filename, FXint i){
    FXString imagename;
    imagename.append(filename);
    //printf("the current filename is: %s\n", imagename.text());
    FXJPGIcon *tempicon=NULL;
    tempicon=new FXJPGIcon(getApp(),NULL,IMAGE_OPAQUE|IMAGE_KEEP|IMAGE_OWNED);
    FXIcon *oldicon=NULL;
    if (tempicon){
   		FXFileStream stream;
   		if (stream.open(imagename,FXStreamLoad)){
			getApp()->beginWaitCursor();
			tempicon->loadPixels(stream);
			stream.close();
			tempicon->scale(80,64,75); 
			// create new icon
			tempicon->create();
			// delete old icon
			oldicon=table->getRowIcon(i);
			table->setRowIcon(i,NULL);
  			if(oldicon != NULL){
				oldicon->release();  
				oldicon=NULL;
			}
			// load new icon
			table->setRowIcon(i,tempicon);
			getApp()->endWaitCursor();
			imagename.clear();
			return TRUE;
		}
    }
    return FALSE;
}


// open filedialog and select multiple files
long FXMovieManager::onCmdFile(FXObject *,FXSelector,void *) {
	resetTable();
	appendFiledialogSelection();
	selectAll();
	return 1;
}


// INSERT selected movies from the Filedialog into the TABLE
void FXMovieManager::insertFiledialogSelection(){
	FXint r,c;
	FXString rootname, imagename;
	currentdir_lp = dirlist_lp->getDirectory();

	FXString* files=FXFileDialog::getOpenFilenames(this,"Select the Movies to Append",currentdir_lp,moviefiles,1);
	if(files){
		for(int i=0; !files[i].empty(); i++){
			filename = files[i];
			FXString ext=FXPath::extension(filename);
			
			if(loadfilevideo(filename)==TRUE){
				numtableitems=numtableitems+1;

				// Return current row index, if any
				r = table->getCurrentRow();
				if(r >= 0){
					table->insertRows(r);
  					table->setRowHeight(r,68);

					table->setItemText(r,0,filename);
					for (c=1; c<9; c++){
	    				table->setItemText(r,c,"00");
					}
  					table->setItemText(r,5,"10");

  					table->removeRows(100);
				}
				else if(r<0){
					FXMessageBox::error(this,MBOX_OK,"Error inserting Movie","The playlist is empty\nuse append item instead");
					continue;
				}

  				rootname="."+FXPath::name(FXPath::stripExtension(filename));
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
        		//imagename=FXPath::enquote(FXPath::directory(filename)+"/"+rootname+"_thumbnail.jpg");
        		imagename=FXPath::directory(filename)+"/"+rootname+"_thumbnail.jpg";
#else
        		imagename=FXPath::enquote(FXPath::directory(filename)+"/"+rootname+"00000001/00000001.jpg");
#endif
				/* 
    				printf("the rootname is: %s\n", rootname.text());
    				printf("the imagename is: %s\n", imagename.text());
        			printf("the itemnumber is: %d\n", numtableitems-1);
				*/
  				if(!previewListMovie(imagename, r)){
					FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Loading Failure","Error on loading thumbnail: %s",imagename.text());
  	    			if(answer==MBOX_CLICKED_CANCEL){
	      				return;
	    			}
				}
			}
			else if(loadfilevideo(filename)==FALSE){
				FXMessageBox::error(this,MBOX_OK,"Error on loading Movie","Unsupported Type: %s",ext.text());
			}
		}
		// clean up files
		delete [] files;
	}
	return;
}


// APPEND selected movies from the Filedialog to the TABLE
void FXMovieManager::appendFiledialogSelection(){
	FXString rootname, imagename;
	currentdir_lp = dirlist_lp->getDirectory();

	FXString* files=FXFileDialog::getOpenFilenames(this,"Select the Movies to Append",currentdir_lp,moviefiles,1);
	if(files){
		for(int i=0; !files[i].empty(); i++){
			filename = files[i];
			FXString ext=FXPath::extension(filename);

			if(loadfilevideo(filename)==TRUE){
				numtableitems=numtableitems+1;
				table->setItemText(numtableitems-1,0,filename);

  				rootname="."+FXPath::name(FXPath::stripExtension(filename));
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
        			//imagename=FXPath::enquote(FXPath::directory(filename)+"/"+rootname+"_thumbnail.jpg");
        			imagename=FXPath::directory(filename)+"/"+rootname+"_thumbnail.jpg";
#else
        			imagename=FXPath::enquote(FXPath::directory(filename)+"/"+rootname+"00000001/00000001.jpg");
#endif
				/* 
    				printf("the rootname is: %s\n", rootname.text());
    				printf("the imagename is: %s\n", imagename.text());
        			printf("the itemnumber is: %d\n", numtableitems-1);
				*/
  				if(!previewListMovie(imagename, numtableitems-1)){
					FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Loading Failure","Error on loading thumbnail: %s",imagename.text());
  	    			if(answer==MBOX_CLICKED_CANCEL){
	      				return;
	    			}
				}
			}
			else if(loadfilevideo(filename)==FALSE){
				FXMessageBox::error(this,MBOX_OK,"Error on loading Movie","Unsupported Type: %s",ext.text());
			}
		}
		// clean up files
		delete [] files;
	}
	return;
}


// get selected movies from filelist_lp
void FXMovieManager::getFilelistSelection_lp() {
  // load one file at a time
  FXString ffile,rootname,imagename;
  for(FXint i=0; i<filelist_lp->getNumItems(); i++){
    	if(filelist_lp->isItemSelected(i)){
        	ffile=filelist_lp->getItemFilename(i);
        	if(ffile=="..") continue;

  			rootname="."+FXPath::stripExtension(ffile);
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
        	//imagename=FXPath::enquote(filelist_lp->getDirectory()+"/"+rootname+"_thumbnail.jpg");
        	imagename=filelist_lp->getDirectory()+"/"+rootname+"_thumbnail.jpg";
#else
        	imagename=FXPath::enquote(filelist_lp->getDirectory())+"/"+rootname+"00000001/00000001.jpg";
#endif
    		//printf("the imagename is: %s\n", imagename.text());
			if(!previewListMovie(imagename, numtableitems-1)){
					FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Loading Failure","Error on loading thumbnail: %s",imagename.text());
  	    			if(answer==MBOX_CLICKED_CANCEL){
	      				return;
	    			}
			}
		//printf("the numitems is: %d\n", numtableitems-1);
	}
  }
  return;	
}


// get selected movies from filelist_rp
void FXMovieManager::getFilelistSelection_rp() {
  // load one file at a time
  FXString ffile,rootname,imagename;
  for(FXint i=0; i<filelist_rp->getNumItems(); i++){
    	if(filelist_rp->isItemSelected(i)){
        	ffile=filelist_rp->getItemFilename(i);
        	if(ffile=="..") continue;

  			rootname="."+FXPath::stripExtension(ffile);
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
        	//imagename=FXPath::enquote(filelist_rp->getDirectory()+"/"+rootname+"_thumbnail.jpg");
        	imagename=filelist_rp->getDirectory()+"/"+rootname+"_thumbnail.jpg";
#else
        	imagename=FXPath::enquote(filelist_rp->getDirectory())+"/"+rootname+"00000001/00000001.jpg";
#endif
    		//printf("the imagename is: %s\n", imagename.text());
			if(!previewListMovie(imagename, numtableitems-1)){
					FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Loading Failure","Error on loading thumbnail: %s",imagename.text());
  	    			if(answer==MBOX_CLICKED_CANCEL){
	      				return;
	    			}
			}
			//printf("the numitems is: %d\n", numtableitems-1);
		}
  }
  return;	
}


// reset Table to default values
void FXMovieManager::resetTable() {
	table->killSelection();
	numtableitems=0;
	FXint c, r;
	for (r=0; r<100; r++){
	  table->setRowIcon(r,NULL);
	  table->setItemText(r,0,"");
	  for (c=1; c<9; c++){
	    table->setItemText(r,c,"00");
	  }
	  table->setItemText(r,5,"10");
	}
	return;
}


// load theme 
FXbool FXMovieManager::themeSelection() {
  theme=getApp()->reg().readStringEntry("SETTINGS","theme");

	if(! (theme.length()>0)) { theme="dark";}
  	if(! (theme_fxmmfore=getApp()->reg().readColorEntry("SETTINGS","fxmmforecolor"))) { theme_fxmmfore   = FXRGB(180,180,180);}
  	if(! (theme_fxmmback=getApp()->reg().readColorEntry("SETTINGS","fxmmbackcolor"))) { theme_fxmmback   = FXRGB( 20, 20, 20);}
  	if(! (theme_fxmmbase=getApp()->reg().readColorEntry("SETTINGS","fxmmbasecolor"))) { theme_fxmmbase   = FXRGB( 60, 60, 60);}
  	if(! (theme_fxmmborder=getApp()->reg().readColorEntry("SETTINGS","fxmmbordercolor"))) { theme_fxmmborder = FXRGB(  0,  0,  0);}
  	if(! (theme_fxmmmenufore=getApp()->reg().readColorEntry("SETTINGS","fxmmmenuforecolor"))) { theme_fxmmmenufore  = FXRGB(240,240,240);}
  	if(! (theme_fxmmmenuback=getApp()->reg().readColorEntry("SETTINGS","fxmmmenubackcolor"))) { theme_fxmmmenuback  = FXRGB( 10, 10, 10);}
  	if(! (theme_fxmmselfore=getApp()->reg().readColorEntry("SETTINGS","fxmmselforecolor"))) { theme_fxmmselfore   = FXRGB(  0,  0,  0);}
  	if(! (theme_fxmmselback=getApp()->reg().readColorEntry("SETTINGS","fxmmselbackcolor"))) { theme_fxmmselback   = FXRGB(140,140,140);}
  	if(! (theme_fxmmtipfore=getApp()->reg().readColorEntry("SETTINGS","fxmmtipforecolor"))) { theme_fxmmtipfore  = FXRGB(220,220,220);}
  	if(! (theme_fxmmtipback=getApp()->reg().readColorEntry("SETTINGS","fxmmtipbackcolor"))) { theme_fxmmtipback  = FXRGB( 20, 20, 20);}
  	if(! (theme_fxmmhilite=getApp()->reg().readColorEntry("SETTINGS","fxmmhilitecolor"))) { theme_fxmmhilite  = FXRGB(100,100,100);}
  	if(! (theme_fxmmshadow=getApp()->reg().readColorEntry("SETTINGS","fxmmshadowcolor"))) { theme_fxmmshadow  = FXRGB( 10, 10, 10);}


  	getApp()->setForeColor(theme_fxmmfore);
  	getApp()->setBaseColor(theme_fxmmbase);
  	getApp()->setBackColor(theme_fxmmback);
  	getApp()->setBorderColor(theme_fxmmborder);
  	getApp()->setSelMenuTextColor(theme_fxmmmenufore);
  	getApp()->setSelMenuBackColor(theme_fxmmmenuback);
  	getApp()->setSelforeColor(theme_fxmmselfore);
  	getApp()->setSelbackColor(theme_fxmmselback);
  	getApp()->setTipforeColor(theme_fxmmtipfore);
  	getApp()->setTipbackColor(theme_fxmmtipback);
	getApp()->setHiliteColor(theme_fxmmhilite);
	getApp()->setShadowColor(theme_fxmmshadow);


  if(theme=="dark"||theme=="gentle"||theme=="storm"){
	themeDG();
  	return TRUE;
  }else if(theme=="shine"||theme=="fog"||theme=="snow"){
	themeSF();
  	return TRUE;
  }else if(theme=="classic"||theme=="moon"||theme=="sun"){
	themeCM();
  	return TRUE;
  }else if(theme=="pink"||theme=="blood"||theme=="red"){
	themePB();
  	return TRUE;
  }else if(theme=="sea"||theme=="blue"||theme=="sky"){
	themeSS();
  	return TRUE;
  }else{
	theme="dark";
	themeDG();
  	return TRUE;
  } 
  return FALSE;
}


void FXMovieManager::themeDG() {
	audioicon=new FXGIFIcon(getApp(),audio_32x32);
	createicon=new FXGIFIcon(getApp(),create_32x32); 
	deleteicon=new FXGIFIcon(getApp(),delete_32x32); 
	deletehiddenicon=new FXGIFIcon(getApp(),deletehidden_32x32); 
	downicon=new FXGIFIcon(getApp(),down_32x32);
	dropicon=new FXGIFIcon(getApp(),drop_32x32); 
	hiddenicon=new FXGIFIcon(getApp(),hidden_32x32);
	hideicon=new FXGIFIcon(getApp(),hide_32x32); 
	loopicon=new FXGIFIcon(getApp(),loop_32x32);
	openicon=new FXGIFIcon(getApp(),open_32x32); 
	pauseicon=new FXGIFIcon(getApp(),pause_32x32);
	playicon=new FXGIFIcon(getApp(),play_32x32);
	quiticon=new FXGIFIcon(getApp(),quit_32x32);
	recreateicon=new FXGIFIcon(getApp(),recreate_32x32); 
	showicon=new FXGIFIcon(getApp(),show_32x32); 
	stopicon=new FXGIFIcon(getApp(),stop_32x32);
	upicon=new FXGIFIcon(getApp(),up_32x32);
	videoicon=new FXGIFIcon(getApp(),video_32x32);
	videoouticon=new FXGIFIcon(getApp(),videoout_32x32);
	videosizeicon=new FXGIFIcon(getApp(),videosize_32x32);
	videozoomicon=new FXGIFIcon(getApp(),videozoom_32x32);
	imgpreview1icon=new FXGIFIcon(getApp(),imgtrue_32x32);
	imgpreview2icon=new FXGIFIcon(getApp(),imgfalse_32x32);
	decreaseicon=new FXGIFIcon(getApp(),decrease_16x32); 
	increaseicon=new FXGIFIcon(getApp(),increase_16x32); 
	icnlisticon=new FXGIFIcon(getApp(),icnlist_16x32);
	detlisticon=new FXGIFIcon(getApp(),detlist_16x32);
	return;
}

void FXMovieManager::themeSF() {
	audioicon=new FXGIFIcon(getApp(),raudio_32x32);
	createicon=new FXGIFIcon(getApp(),rcreate_32x32); 
	deleteicon=new FXGIFIcon(getApp(),rdelete_32x32); 
	deletehiddenicon=new FXGIFIcon(getApp(),rdeletehidden_32x32); 
	downicon=new FXGIFIcon(getApp(),rdown_32x32);
	dropicon=new FXGIFIcon(getApp(),rdrop_32x32); 
	hiddenicon=new FXGIFIcon(getApp(),rhidden_32x32);
	hideicon=new FXGIFIcon(getApp(),rhide_32x32); 
	loopicon=new FXGIFIcon(getApp(),rloop_32x32);
	openicon=new FXGIFIcon(getApp(),ropen_32x32); 
	pauseicon=new FXGIFIcon(getApp(),rpause_32x32);
	playicon=new FXGIFIcon(getApp(),rplay_32x32);
	quiticon=new FXGIFIcon(getApp(),rquit_32x32);
	recreateicon=new FXGIFIcon(getApp(),rrecreate_32x32); 
	showicon=new FXGIFIcon(getApp(),rshow_32x32); 
	stopicon=new FXGIFIcon(getApp(),rstop_32x32);
	upicon=new FXGIFIcon(getApp(),rup_32x32);
	videoicon=new FXGIFIcon(getApp(),rvideo_32x32);
	videoouticon=new FXGIFIcon(getApp(),rvideoout_32x32);
	videosizeicon=new FXGIFIcon(getApp(),rvideosize_32x32);
	videozoomicon=new FXGIFIcon(getApp(),rvideozoom_32x32);
	imgpreview1icon=new FXGIFIcon(getApp(),rimgtrue_32x32);
	imgpreview2icon=new FXGIFIcon(getApp(),rimgfalse_32x32);
	decreaseicon=new FXGIFIcon(getApp(),rdecrease_16x32); 
	increaseicon=new FXGIFIcon(getApp(),rincrease_16x32); 
	icnlisticon=new FXGIFIcon(getApp(),ricnlist_16x32);
	detlisticon=new FXGIFIcon(getApp(),rdetlist_16x32);
	return;
}

void FXMovieManager::themePB() {
	audioicon=new FXGIFIcon(getApp(),naudio_32x32);
	createicon=new FXGIFIcon(getApp(),ncreate_32x32); 
	deleteicon=new FXGIFIcon(getApp(),ndelete_32x32); 
	deletehiddenicon=new FXGIFIcon(getApp(),ndeletehidden_32x32); 
	downicon=new FXGIFIcon(getApp(),ndown_32x32);
	dropicon=new FXGIFIcon(getApp(),ndrop_32x32); 
	hiddenicon=new FXGIFIcon(getApp(),nhidden_32x32);
	hideicon=new FXGIFIcon(getApp(),nhide_32x32); 
	loopicon=new FXGIFIcon(getApp(),nloop_32x32);
	openicon=new FXGIFIcon(getApp(),nopen_32x32); 
	pauseicon=new FXGIFIcon(getApp(),npause_32x32);
	playicon=new FXGIFIcon(getApp(),nplay_32x32);
	quiticon=new FXGIFIcon(getApp(),nquit_32x32);
	recreateicon=new FXGIFIcon(getApp(),nrecreate_32x32); 
	showicon=new FXGIFIcon(getApp(),nshow_32x32); 
	stopicon=new FXGIFIcon(getApp(),nstop_32x32);
	upicon=new FXGIFIcon(getApp(),nup_32x32);
	videoicon=new FXGIFIcon(getApp(),nvideo_32x32);
	videoouticon=new FXGIFIcon(getApp(),nvideoout_32x32);
	videosizeicon=new FXGIFIcon(getApp(),nvideosize_32x32);
	videozoomicon=new FXGIFIcon(getApp(),nvideozoom_32x32);
	imgpreview1icon=new FXGIFIcon(getApp(),nimgtrue_32x32);
	imgpreview2icon=new FXGIFIcon(getApp(),nimgfalse_32x32);
	decreaseicon=new FXGIFIcon(getApp(),ndecrease_16x32); 
	increaseicon=new FXGIFIcon(getApp(),nincrease_16x32); 
	icnlisticon=new FXGIFIcon(getApp(),nicnlist_16x32);
	detlisticon=new FXGIFIcon(getApp(),ndetlist_16x32);
	return;
}

void FXMovieManager::themeSS() {
	audioicon=new FXGIFIcon(getApp(),baudio_32x32);
	createicon=new FXGIFIcon(getApp(),bcreate_32x32); 
	deleteicon=new FXGIFIcon(getApp(),bdelete_32x32); 
	deletehiddenicon=new FXGIFIcon(getApp(),bdeletehidden_32x32); 
	downicon=new FXGIFIcon(getApp(),bdown_32x32);
	dropicon=new FXGIFIcon(getApp(),bdrop_32x32); 
	hiddenicon=new FXGIFIcon(getApp(),bhidden_32x32);
	hideicon=new FXGIFIcon(getApp(),bhide_32x32); 
	loopicon=new FXGIFIcon(getApp(),bloop_32x32);
	openicon=new FXGIFIcon(getApp(),bopen_32x32); 
	pauseicon=new FXGIFIcon(getApp(),bpause_32x32);
	playicon=new FXGIFIcon(getApp(),bplay_32x32);
	quiticon=new FXGIFIcon(getApp(),bquit_32x32);
	recreateicon=new FXGIFIcon(getApp(),brecreate_32x32); 
	showicon=new FXGIFIcon(getApp(),bshow_32x32); 
	stopicon=new FXGIFIcon(getApp(),bstop_32x32);
	upicon=new FXGIFIcon(getApp(),bup_32x32);
	videoicon=new FXGIFIcon(getApp(),bvideo_32x32);
	videoouticon=new FXGIFIcon(getApp(),bvideoout_32x32);
	videosizeicon=new FXGIFIcon(getApp(),bvideosize_32x32);
	videozoomicon=new FXGIFIcon(getApp(),bvideozoom_32x32);
	imgpreview1icon=new FXGIFIcon(getApp(),bimgtrue_32x32);
	imgpreview2icon=new FXGIFIcon(getApp(),bimgfalse_32x32);
	icnlisticon=new FXGIFIcon(getApp(),bicnlist_16x32);
	detlisticon=new FXGIFIcon(getApp(),bdetlist_16x32);
	increaseicon=new FXGIFIcon(getApp(),bincrease_16x32);
	decreaseicon=new FXGIFIcon(getApp(),bdecrease_16x32);
  	return;
}

void FXMovieManager::themeCM() {
	audioicon=new FXGIFIcon(getApp(),b_audio);
	createicon=new FXGIFIcon(getApp(),b_previd);
	decreaseicon=new FXGIFIcon(getApp(),b_decvid);
	deleteicon=new FXGIFIcon(getApp(),b_trash);
	deletehiddenicon=new FXGIFIcon(getApp(),b_delvid);
	downicon=new FXGIFIcon(getApp(),b_down);
	dropicon=new FXGIFIcon(getApp(),b_conf);
	hiddenicon=new FXGIFIcon(getApp(),b_hidden);
	hideicon=new FXGIFIcon(getApp(),b_hide);
	increaseicon=new FXGIFIcon(getApp(),b_incvid);
	loopicon=new FXGIFIcon(getApp(),b_loop);
	openicon=new FXGIFIcon(getApp(),b_file);
	pauseicon=new FXGIFIcon(getApp(),b_pause);
	playicon=new FXGIFIcon(getApp(),b_play);
	quiticon=new FXGIFIcon(getApp(),b_quit);
	recreateicon=new FXGIFIcon(getApp(),b_frevid);
	showicon=new FXGIFIcon(getApp(),b_all);
	stopicon=new FXGIFIcon(getApp(),b_stop);
	upicon=new FXGIFIcon(getApp(),b_up);
	videoicon=new FXGIFIcon(getApp(),b_video);
	videoouticon=new FXGIFIcon(getApp(),b_videoout);
	videosizeicon=new FXGIFIcon(getApp(),b_videosize);
	videozoomicon=new FXGIFIcon(getApp(),b_videozoom);
	imgpreview1icon=new FXGIFIcon(getApp(),b_imgtrue);
	imgpreview2icon=new FXGIFIcon(getApp(),b_imgfalse);
	decreaseicon=new FXGIFIcon(getApp(),b_decvid); 
	increaseicon=new FXGIFIcon(getApp(),b_incvid); 
	icnlisticon=new FXGIFIcon(getApp(),b_icnlist);
	detlisticon=new FXGIFIcon(getApp(),b_detlist);
	return;
}


// load localization 
FXbool FXMovieManager::languageSelection() {
  language=getApp()->reg().readStringEntry("SETTINGS","language");
  if(language== "en" || language== "it" || language== "fr" || language== "de" || language== "es" || language== "ru" || language== "cn" || language== "jp" ){
  // Read language
  audiobuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","audiobuttontext1");
  audiobuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","audiobuttontext2");
  dropbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","dropbuttontext1");
  dropbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","dropbuttontext2");
  zoombuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","zoombuttontext1");
  zoombuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","zoombuttontext2");
  loopbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","loopbuttontext1");
  loopbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","loopbuttontext2");
  hidebuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","hidebuttontext1");
  hidebuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","hidebuttontext2");
  allbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","allbuttontext1");
  allbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","allbuttontext2");
  widebuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","widebuttontext1");
  widebuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","widebuttontext2");
  imgbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON","imgbuttontext1");
  imgbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON","imgbuttontext2");
  quitbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","quitbuttontext");
  openbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","openbuttontext");
  stopbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","stopbuttontext");
  pausebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","pausebuttontext");
  playbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","playbuttontext");
  jplaybuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","jplaybuttontext");
  outputbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","outputbuttontext");
  sizebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","sizebuttontext");
  confbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","confbuttontext");
  upbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","upbuttontext");
  downbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","downbuttontext");
  slistbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","slistbuttontext");
  olistbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","olistbuttontext");
  createbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","createbuttontext");
  recreatebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","recreatebuttontext");
  deletebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","deletebuttontext");
  clearbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","clearbuttontext");
  increasebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","increasebuttontext");
  decreasebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON","decreasebuttontext");
  icnlisttext=getApp()->reg().readStringEntry("LANG_BUTTON","icnlisttext");
  detlisttext=getApp()->reg().readStringEntry("LANG_BUTTON","detlisttext");

  file_n=getApp()->reg().readStringEntry("LANG_MENU","file_n");
  file_t=getApp()->reg().readStringEntry("LANG_MENU","file_t");
  file_s=getApp()->reg().readStringEntry("LANG_MENU","file_s");
  file_m=getApp()->reg().readStringEntry("LANG_MENU","file_m");
  file_u=getApp()->reg().readStringEntry("LANG_MENU","file_u");
  file_g=getApp()->reg().readStringEntry("LANG_MENU","file_g");
  file_a=getApp()->reg().readStringEntry("LANG_MENU","file_a");
  file_l=getApp()->reg().readStringEntry("LANG_MENU","file_l");

  menu_op=getApp()->reg().readStringEntry("LANG_MENU","menu_op");
  menu_ow=getApp()->reg().readStringEntry("LANG_MENU","menu_ow");
  menu_pr=getApp()->reg().readStringEntry("LANG_MENU","menu_pr");
  menu_mi=getApp()->reg().readStringEntry("LANG_MENU","menu_mi");
  menu_re=getApp()->reg().readStringEntry("LANG_MENU","menu_re");
  menu_mo=getApp()->reg().readStringEntry("LANG_MENU","menu_mo");
  menu_sy=getApp()->reg().readStringEntry("LANG_MENU","menu_sy");
  menu_cu=getApp()->reg().readStringEntry("LANG_MENU","menu_cu");
  menu_co=getApp()->reg().readStringEntry("LANG_MENU","menu_co");
  menu_pa=getApp()->reg().readStringEntry("LANG_MENU","menu_pa");
  menu_de=getApp()->reg().readStringEntry("LANG_MENU","menu_de");

  menu_te=getApp()->reg().readStringEntry("LANG_MENU","menu_te");
  menu_he=getApp()->reg().readStringEntry("LANG_MENU","menu_he");
  menu_vi=getApp()->reg().readStringEntry("LANG_MENU","menu_vi");
  menu_ar=getApp()->reg().readStringEntry("LANG_MENU","menu_ar");
  menu_sr=getApp()->reg().readStringEntry("LANG_MENU","menu_sr");
  menu_sh=getApp()->reg().readStringEntry("LANG_MENU","menu_sh");
  menu_nd=getApp()->reg().readStringEntry("LANG_MENU","menu_nd");
  menu_rd=getApp()->reg().readStringEntry("LANG_MENU","menu_rd");
  menu_dd=getApp()->reg().readStringEntry("LANG_MENU","menu_dd");
  menu_rf=getApp()->reg().readStringEntry("LANG_MENU","menu_rf");
  menu_ma=getApp()->reg().readStringEntry("LANG_MENU","menu_ma");
  menu_um=getApp()->reg().readStringEntry("LANG_MENU","menu_um");

  menu_up=getApp()->reg().readStringEntry("LANG_MENU","menu_up");
  menu_do=getApp()->reg().readStringEntry("LANG_MENU","menu_do");
  menu_al=getApp()->reg().readStringEntry("LANG_MENU","menu_al");
  menu_da=getApp()->reg().readStringEntry("LANG_MENU","menu_da");
  menu_ap=getApp()->reg().readStringEntry("LANG_MENU","menu_ap");
  menu_in=getApp()->reg().readStringEntry("LANG_MENU","menu_in");
  menu_di=getApp()->reg().readStringEntry("LANG_MENU","menu_di");
  menu_ed=getApp()->reg().readStringEntry("LANG_MENU","menu_ed");

  return TRUE;

  } else if(language=="cu"){
  // Read custom language
  audiobuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","audiobuttontext1");
  audiobuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","audiobuttontext2");
  dropbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","dropbuttontext1");
  dropbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","dropbuttontext2");
  zoombuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","zoombuttontext1");
  zoombuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","zoombuttontext2");
  loopbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","loopbuttontext1");
  loopbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","loopbuttontext2");
  hidebuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","hidebuttontext1");
  hidebuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","hidebuttontext2");
  allbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","allbuttontext1");
  allbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","allbuttontext2");
  widebuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","widebuttontext1");
  widebuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","widebuttontext2");
  imgbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","imgbuttontext1");
  imgbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","imgbuttontext2");
  quitbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","quitbuttontext");
  openbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","openbuttontext");
  stopbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","stopbuttontext");
  pausebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","pausebuttontext");
  playbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","playbuttontext");
  jplaybuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","jplaybuttontext");
  outputbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","outputbuttontext");
  sizebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","sizebuttontext");
  confbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","confbuttontext");
  upbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","upbuttontext");
  downbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","downbuttontext");
  slistbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","slistbuttontext");
  olistbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","olistbuttontext");
  createbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","createbuttontext");
  recreatebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","recreatebuttontext");
  deletebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","deletebuttontext");
  clearbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","clearbuttontext");
  increasebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","increasebuttontext");
  decreasebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","decreasebuttontext");
  icnlisttext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","icnlisttext");
  detlisttext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","detlisttext");

  file_n=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_n");
  file_t=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_t");
  file_s=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_s");
  file_m=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_m");
  file_u=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_u");
  file_g=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_g");
  file_a=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_a");
  file_l=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_l");

  menu_op=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_op");
  menu_ow=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ow");
  menu_pr=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_pr");
  menu_mi=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_mi");
  menu_re=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_re");
  menu_mo=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_mo");
  menu_sy=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_sy");
  menu_cu=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_cu");
  menu_co=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_co");
  menu_pa=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_pa");
  menu_de=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_de");

  menu_te=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_te");
  menu_he=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_he");
  menu_vi=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_vi");
  menu_ar=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ar");
  menu_sr=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_sr");
  menu_sh=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_sh");
  menu_nd=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_nd");
  menu_rd=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_rd");
  menu_dd=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_dd");
  menu_rf=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_rf");
  menu_ma=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ma");
  menu_um=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_um");

  menu_up=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_up");
  menu_do=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_do");
  menu_al=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_al");
  menu_da=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_da");
  menu_ap=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ap");
  menu_in=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_in");
  menu_di=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_di");
  menu_ed=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ed");

  return TRUE;
 }

 return FALSE;
}


// load pre-configuration
FXbool FXMovieManager::readPreConfig() {
  if(!getApp()->reg().read()){
	return FALSE;
  }

  widescreen = getApp()->reg().readBoolEntry("SETTINGS","widescreen",FALSE);

  if(widescreen == FALSE){
	imgw=80; imgh=64;
	dlgw=480; dlgh=384;
  } else
  if(widescreen == TRUE){
	imgw=100; imgh=64;
	dlgw=600; dlgh=384;
  } else {
    widescreen = FALSE;
	imgw=80; imgh=64;
	dlgw=480; dlgh=384;
  }

  // Read registry settings
  if(getApp()->reg().read()){
    return TRUE;
  }
}

// load configuration
FXbool FXMovieManager::readConfig() {
  if(!getApp()->reg().read()){
	return FALSE;
  }
FXint width,height,xpos,ypos,firstcolwidth;
  // Get size and position
  xpos=getApp()->reg().readIntEntry("WINDOW","xpos",40);
  ypos=getApp()->reg().readIntEntry("WINDOW","ypos",40);
  width=getApp()->reg().readIntEntry("WINDOW","width",840);
  height=getApp()->reg().readIntEntry("WINDOW","height",42);
  // Reposition window
  setX(xpos);
  setY(ypos);
  setWidth(width);
  setHeight(height);

  firstcolwidth=getApp()->reg().readIntEntry("SETTINGS","firstcolwidth",400);
  table->setColumnWidth(0,firstcolwidth);

  // Read menu options
  s_full=getApp()->reg().readStringEntry("MENU","s_full");
  s_loop=getApp()->reg().readStringEntry("MENU","s_loop");
  s_frame=getApp()->reg().readStringEntry("MENU","s_frame");
  s_audio=getApp()->reg().readStringEntry("MENU","s_audio");
  s_xsize=getApp()->reg().readStringEntry("MENU","s_xsize","800");
  s_ysize=getApp()->reg().readStringEntry("MENU","s_ysize","460");

  i_video=getApp()->reg().readIntEntry("MENU","i_video",i_video);
  i_size=getApp()->reg().readIntEntry("MENU","i_size",i_size);

  currentdir_lp=getApp()->reg().readStringEntry("FileList","currentdir_lp");
  currentdir_rp=getApp()->reg().readStringEntry("FileList","currentdir_rp");

  splitter2->setSplit(0,getApp()->reg().readIntEntry("FileList","dirwidth",260));
  splitter1->setSplit(1,getApp()->reg().readIntEntry("FileList","dirheigth",380));

  listshow = getApp()->reg().readBoolEntry("SETTINGS","listshow",FALSE);

  fxmmwheellines=getApp()->reg().readIntEntry("SETTINGS","fxmmwheellines",4);
  terminal=getApp()->reg().readStringEntry("SETTINGS","terminal");
  defaultplayer=getApp()->reg().readStringEntry("SETTINGS","defaultplayer");

  unkextension0=getApp()->reg().readStringEntry("SETTINGS","unkextension0");
  unkextension1=getApp()->reg().readStringEntry("SETTINGS","unkextension1");
  unkextension2=getApp()->reg().readStringEntry("SETTINGS","unkextension2");
  unkextension3=getApp()->reg().readStringEntry("SETTINGS","unkextension3");
  unkextension4=getApp()->reg().readStringEntry("SETTINGS","unkextension4");
  unkextension5=getApp()->reg().readStringEntry("SETTINGS","unkextension5");
  unkextension6=getApp()->reg().readStringEntry("SETTINGS","unkextension6");
  unkextension7=getApp()->reg().readStringEntry("SETTINGS","unkextension7");


  fontspec=getApp()->reg().readStringEntry("SETTINGS","bodyfont","");
  if(!fontspec.empty()){
	bodyfont=new FXFont(getApp(),fontspec);

	filelist_lp->setFont(bodyfont);
	dirlist_lp->setFont(bodyfont);
	filelist_rp->setFont(bodyfont);
	dirlist_rp->setFont(bodyfont);

	table->setFont(bodyfont);
  }

  fontspec2=getApp()->reg().readStringEntry("SETTINGS","menufont","");
  if(!fontspec2.empty()){
	menufont=new FXFont(getApp(),fontspec2);

	getApp()->setNormalFont(menufont);
	tooltip->setFont(menufont); // not required
	statusline->setFont(menufont); // not required
	playlistlabel->setFont(menufont);

	table->setColumnHeaderFont(menufont);
	table->setRowHeaderFont(menufont);

	menu_vs01->setFont(menufont);
	menu_vs02->setFont(menufont);
	menu_vs03->setFont(menufont);
	menu_vs04->setFont(menufont);
	menu_vs05->setFont(menufont);
	menu_vs06->setFont(menufont);
	menu_vs07->setFont(menufont);
	menu_vs08->setFont(menufont);
	menu_vs09->setFont(menufont);
	menu_vs10->setFont(menufont);
	menu_vs11->setFont(menufont);
	menu_vs12->setFont(menufont);
	menu_vs13->setFont(menufont);
	menu_vs14->setFont(menufont);
	menu_vs15->setFont(menufont);
	menu_vs16->setFont(menufont);
	menu_vs17->setFont(menufont);
	menu_vs18->setFont(menufont);
	menu_vs19->setFont(menufont);
	menu_vs20->setFont(menufont);
	menu_vs21->setFont(menufont);
	menu_vs22->setFont(menufont);
	menu_vs23->setFont(menufont);
	menu_vs24->setFont(menufont);
	menu_vs25->setFont(menufont);
	menu_vs26->setFont(menufont);

	menu_vo01->setFont(menufont);
	menu_vo02->setFont(menufont);
	menu_vo03->setFont(menufont);
	menu_vo04->setFont(menufont);
	menu_vo05->setFont(menufont);
	menu_vo06->setFont(menufont);
	menu_vo07->setFont(menufont);
	menu_vo08->setFont(menufont);
	menu_vo09->setFont(menufont);
	menu_vo10->setFont(menufont);

    pop_up->setFont(menufont);
    pop_do->setFont(menufont);
    pop_al->setFont(menufont);
    pop_da->setFont(menufont);
    pop_ap->setFont(menufont);
    pop_in->setFont(menufont);
    pop_di->setFont(menufont);
    pop_ed->setFont(menufont);
    }

    filelist_rp->setHeaderIcon(0,m_renamediricon);
    filelist_rp->setHeaderIcon(1,m_diricon);
    filelist_rp->setHeaderIcon(2,m_dimicon);
    filelist_rp->setHeaderIcon(3,m_daticon);
    filelist_rp->setHeaderIcon(4,m_usricon);
    filelist_rp->setHeaderIcon(5,m_grpicon);
    filelist_rp->setHeaderIcon(6,m_prmicon);
    filelist_rp->setHeaderIcon(7,m_consoleicon);

    filelist_lp->setHeaderIcon(0,m_renamediricon);
    filelist_lp->setHeaderIcon(1,m_diricon);
    filelist_lp->setHeaderIcon(2,m_dimicon);
    filelist_lp->setHeaderIcon(3,m_daticon);
    filelist_lp->setHeaderIcon(4,m_usricon);
    filelist_lp->setHeaderIcon(5,m_grpicon);
    filelist_lp->setHeaderIcon(6,m_prmicon);
    filelist_lp->setHeaderIcon(7,m_consoleicon);


    filelist_rp->setHeaderText(0,file_n);
    filelist_rp->setHeaderText(1,file_t);
    filelist_rp->setHeaderText(2,file_s);
    filelist_rp->setHeaderText(3,file_m);
    filelist_rp->setHeaderText(4,file_u);
    filelist_rp->setHeaderText(5,file_g);
    filelist_rp->setHeaderText(6,file_a);
    filelist_rp->setHeaderText(7,file_l);

    filelist_lp->setHeaderText(0,file_n);
    filelist_lp->setHeaderText(1,file_t);
    filelist_lp->setHeaderText(2,file_s);
    filelist_lp->setHeaderText(3,file_m);
    filelist_lp->setHeaderText(4,file_u);
    filelist_lp->setHeaderText(5,file_g);
    filelist_lp->setHeaderText(6,file_a);
    filelist_lp->setHeaderText(7,file_l);


#ifdef HAVE_LIBFFMPEGTHUMBNAILER
  // get thumbnailer options
  thumbnailSize = getApp()->reg().readIntEntry("THUMBNAILER","thumbnailSize",128);
  imageQuality = getApp()->reg().readIntEntry("THUMBNAILER","imageQuality",8);
  filmStripOverlay = getApp()->reg().readBoolEntry("THUMBNAILER","filmStripOverlay",FALSE);
  workaroundIssues = getApp()->reg().readBoolEntry("THUMBNAILER","workaroundIssues",FALSE);
  maintainAspectRatio = getApp()->reg().readBoolEntry("THUMBNAILER","maintainAspectRatio",TRUE);
  smartFrameSelection = getApp()->reg().readBoolEntry("THUMBNAILER","smartFrameSelection",FALSE);
#endif
  autoThumbnailShow = getApp()->reg().readBoolEntry("THUMBNAILER","autoThumbnailShow",TRUE);
  autoThumbnailCreate = getApp()->reg().readBoolEntry("THUMBNAILER","autoThumbnailCreate",FALSE);
  autoThumbnailUpdate = getApp()->reg().readBoolEntry("THUMBNAILER","autoThumbnailUpdate",FALSE);

  imagethumbnailSize = getApp()->reg().readIntEntry("THUMBNAILER","imagethumbnailSize",128);

  // Read registry settings
  if(getApp()->reg().read()){
    return TRUE;
  }
}

// create application
void FXMovieManager::create() {

  if(!readConfig()){
	printf("Configuration not loaded!");
  }

  getApp()->setWheelLines(fxmmwheellines);

  synchronize_lp(currentdir_lp);
  synchronize_rp(currentdir_rp);

  if(listshow==FALSE) hidebutton->setState(TRUE);
  else if(listshow==TRUE) hidebutton->setState(FALSE);

  if(s_full==""){ zoombutton->setState(FALSE); full = 0; } 
  else if(s_full=="-fs "){ zoombutton->setState(TRUE); full = 1; }

  if(s_loop==""){ loopbutton->setState(FALSE); loop = 0; } 
  else if(s_loop=="-loop 0 "){ loopbutton->setState(TRUE); loop = 1; }

  if(s_audio==""){ audiobutton->setState(FALSE); f_audio = ""; disable_audio = 0;} 
  else if(s_audio=="-nosound "){ audiobutton->setState(TRUE);  f_audio = "-an "; disable_audio = 1;}

  if(s_frame==""){ dropbutton->setState(FALSE); drop = 0;} 
  else if(s_frame=="-framedrop "){ dropbutton->setState(TRUE); drop = 1;} 


  if(defaultplayer=="mplayer"){	
	// mplayer related commands
	s_command = "mplayer -slave -idle -quiet -ontop -input file="+currentFifo+" ";
	j1_command = s_command+"mf://";
	j3_command = " -mf ";
	j5_command = ":type=jpg ";

  	FXString init_command="mplayer -vo help";
  	system (init_command.text());  // initialize lazy MPlayer
 
  	switch(i_video){
	case 0:
		s_video="-vo x11 -fixed-vo ";
		break;
	case 1:
		s_video="-vo xv -fixed-vo ";
		break;
	case 2:
		s_video="-vo gl -fixed-vo ";
		break;
	case 3:
		s_video="-vo gl2 -fixed-vo ";
		break;
	case 4:
		s_video="-vo sdl -fixed-vo ";
		break;
	case 5:
		s_video="-vo dga -fixed-vo ";
		break;
	case 6:
		s_video="-vo xvidix -fixed-vo ";
		break;
	case 7:
		s_video="-vo jpeg ";
		break;
	case 8:
		s_video="-vo png ";
		break;
	case 9:
		s_video="-vo null ";
		break;
	}

 	switch(i_size){
	case 0:
		s_size="-zoom -x 1920 -y 1080 ";
		break;
	case 1:
		s_size="-zoom -x 1365 -y 768 ";
		break;
	case 2:
		s_size="-zoom -x 1280 -y 752 ";
		break;
	case 3:
		s_size="-zoom -x 1280 -y 720 ";
		break;
	case 4:
		s_size="-zoom -x 1080 -y 720 ";
		break;
	case 5:
		s_size="-zoom -x 1080 -y 576 ";
		break;
	case 6:
		s_size="-zoom -x 960 -y 540 ";
		break;
	case 7:
		s_size="-zoom -x 720 -y 576 ";
		break;
	case 8:
		s_size="-zoom -x 640 -y 480 ";
		break;
	case 9:
		s_size="-zoom -x 640 -y 384 ";
		break;
	case 10:
		s_size="-zoom -x 540 -y 360 ";
		break;
	case 11:
		s_size="-zoom -x 480 -y 576 ";
		break;
	case 12:
		s_size="-zoom -x 480 -y 480 ";
		break;
	case 13:
		s_size="-zoom -xy 3.4 ";
		break;
	case 14:
		s_size="-zoom -xy 3.1 ";
		break;
	case 15:
		s_size="-zoom -xy 2.8 ";
		break;
	case 16:
		s_size="-zoom -xy 2.5 ";
		break;
	case 17:
		s_size="-zoom -xy 2.2 ";
		break;
	case 18:
		s_size="-zoom -xy 1.9 ";
		break;
	case 19:
		s_size="-zoom -xy 1.6 ";
		break;
	case 20:
		s_size="-zoom -xy 1.3 ";
		break;
	case 21:
		s_size="";
		break;
	case 22:
		s_size="-zoom -xy 0.9 ";
		break;
	case 23:
		s_size="-zoom -xy 0.8 ";
		break;
	case 24:
		s_size="-zoom -xy 0.6 ";
		break;
	case 25:
		s_size="-zoom -x "+s_xsize+" -y "+s_ysize+" ";
		break;
	}

  }
  else if(defaultplayer=="ffplay"){	
	// ffplay related commands
	s_command = "ffplay ";

  	switch(i_size){
	case 0:
		s_size="-x 1920 -y 1080 ";
		break;
	case 1:
		s_size="-x 1365 -y 768 ";
		break;
	case 2:
		s_size="-x 1280 -y 752 ";
		break;
	case 3:
		s_size="-x 1280 -y 720 ";
		break;
	case 4:
		s_size="-x 1080 -y 720 ";
		break;
	case 5:
		s_size="-x 1080 -y 576 ";
		break;
	case 6:
		s_size="-x 960 -y 540 ";
		break;
	case 7:
		s_size="-x 720 -y 576 ";
		break;
	case 8:
		s_size="-x 640 -y 480 ";
		break;
	case 9:
		s_size="-x 640 -y 384 ";
		break;
	case 10:
		s_size="-x 540 -y 360 ";
		break;
	case 11:
		s_size="-x 480 -y 576 ";
		break;
	case 12:
		s_size="-x 480 -y 480 ";
		break;
	case 13:
		//s_size="-s -xy 3.4 ";
		break;
	case 14:
		//s_size="-s -xy 3.1 ";
		break;
	case 15:
		//s_size="-s -xy 2.8 ";
		break;
	case 16:
		//s_size="-s -xy 2.5 ";
		break;
	case 17:
		//s_size="-s -xy 2.2 ";
		break;
	case 18:
		//s_size="-s -xy 1.9 ";
		break;
	case 19:
		//s_size="-s -xy 1.6 ";
		break;
	case 20:
		//s_size="-s -xy 1.3 ";
		break;
	case 21:
		s_size="";
		break;
	case 22:
		//s_size="-s -xy 0.9 ";
		break;
	case 23:
		//s_size="-s -xy 0.8 ";
		break;
	case 24:
		//s_size="-s -xy 0.6 ";
		break;
	case 25:
		s_size="-x "+s_xsize+" -y "+s_ysize+" ";
		break;
	}
  }
  else if(defaultplayer=="fxplayer"){

  	switch(i_video){
	case 0:
	case 1:
	case 2:
	case 3:
	case 4:
	case 5:
	case 6:
	case 7:
	case 8:
		disable_video = 0;
		break;
	case 9:
		disable_video = 1;
		break;
	}

  	switch(i_size){
	case 0:
		size_x = 1920; size_y = 1080; 
		break;
	case 1:
		size_x = 1365; size_y = 768;
		break;
	case 2:
		size_x = 1280; size_y = 752;
		break;
	case 3:
		size_x = 1280; size_y = 720;
		break;
	case 4:
		size_x = 1080; size_y = 720;
		break;
	case 5:
		size_x = 1080; size_y = 576;
		break;
	case 6:
		size_x = 960; size_y = 540;
		break;
	case 7:
		size_x = 720; size_y = 576;
		break;
	case 8:
		size_x = 640; size_y = 480;
		break;
	case 9:
		size_x = 640; size_y = 384;
		break;
	case 10:
		size_x = 540; size_y = 360;
		break;
	case 11:
		size_x = 480; size_y = 576;
		break;
	case 12:
		size_x = 480; size_y = 480;
		break;
	case 13:
		//s_size="-s -xy 3.4 ";
		break;
	case 14:
		//s_size="-s -xy 3.1 ";
		break;
	case 15:
		//s_size="-s -xy 2.8 ";
		break;
	case 16:
		//s_size="-s -xy 2.5 ";
		break;
	case 17:
		//s_size="-s -xy 2.2 ";
		break;
	case 18:
		//s_size="-s -xy 1.9 ";
		break;
	case 19:
		//s_size="-s -xy 1.6 ";
		break;
	case 20:
		//s_size="-s -xy 1.3 ";
		break;
	case 21:
		size_x = 0; size_y = 0;
		break;
	case 22:
		//s_size="-s -xy 0.9 ";
		break;
	case 23:
		//s_size="-s -xy 0.8 ";
		break;
	case 24:
		//s_size="-s -xy 0.6 ";
		break;
	case 25:
		s_size="-x "+s_xsize+" -y "+s_ysize+" ";
		break;
	}
  }


  filelist_lp->setImageSize(imagethumbnailSize);
  filelist_rp->setImageSize(imagethumbnailSize);

  getApp()->addTimeout(this,ID_CLOCKTIME,CLOCKTIMER);

  // Register standard uri-list type
  urilistType=getApp()->registerDragType("text/uri-list");
  actionType=getApp()->registerDragType("text/cliprd-action");

  FXMainWindow::create();
  FXMainWindow::show(PLACEMENT_SCREEN);

  showFilelistThumbnails_lp();
  showFilelistThumbnails_rp();

  return;
}


// quit application
long FXMovieManager::onCmdQuit(FXObject *,FXSelector,void *) {
  quitAppFxmm();
  return 1;
}


void FXMovieManager::quitAppFxmm(){

  // Write new window size and position back to registry
  getApp()->reg().writeIntEntry("WINDOW","xpos",getX());
  getApp()->reg().writeIntEntry("WINDOW","ypos",getY());
  getApp()->reg().writeIntEntry("WINDOW","width",getWidth());
  getApp()->reg().writeIntEntry("WINDOW","height",getHeight());

  getApp()->reg().writeIntEntry("SETTINGS","firstcolwidth",table->getColumnWidth(0));

  // Write mencoder options
  getApp()->reg().writeIntEntry("MENU","i_video",i_video);
  getApp()->reg().writeIntEntry("MENU","i_size",i_size);

  getApp()->reg().writeStringEntry("MENU","s_full",s_full.text());
  getApp()->reg().writeStringEntry("MENU","s_loop",s_loop.text());
  getApp()->reg().writeStringEntry("MENU","s_frame",s_frame.text());
  getApp()->reg().writeStringEntry("MENU","s_audio",s_audio.text());

  currentdir_lp = dirlist_lp->getDirectory();
  getApp()->reg().writeStringEntry("FileList","currentdir_lp",currentdir_lp.text());
  currentdir_rp = dirlist_rp->getDirectory();
  getApp()->reg().writeStringEntry("FileList","currentdir_rp",currentdir_rp.text());

  getApp()->reg().writeIntEntry("FileList","dirwidth",splitter2->getSplit(0));
  getApp()->reg().writeIntEntry("FileList","dirheigth",splitter1->getSplit(1));

  getApp()->reg().writeBoolEntry("SETTINGS","listshow",listshow);
  getApp()->reg().writeBoolEntry("SETTINGS","widescreen",widescreen);

  // Write registry settings
  getApp()->reg().write();

  system (removeTempFifo.text());

  // Quit
  getApp()->exit(0);
  return;
}


/**************************PLAYER LIST BUTTONS****************************/


// Change video output for mplayer
long FXMovieManager::onCmdVideoSwitch(FXObject* sender,FXSelector sel,void* ptr){
  FXint n_video=FXSELID(sel)-ID_VIDEO_1+1;
  if(0<=n_video && n_video<10){
    switch(FXSELID(sel)){
	case ID_VIDEO_0:
		i_video=0;
		s_video="-vo x11 -fixed-vo ";
		disable_video=0;
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output [x11] Enabled\nVideo on Top Enabled");
		break;
	case ID_VIDEO_1:
		i_video=1;
		s_video="-vo xv -fixed-vo ";
		disable_video=0;
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output [xv] Enabled\nVideo on Top Disabled");
		break;
	case ID_VIDEO_2:
		i_video=2;
		s_video="-vo gl -fixed-vo ";
		disable_video=0;
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output [gl] Enabled\nVideo on Top Disabled");
		break;
	case ID_VIDEO_3:
		i_video=3;
		s_video="-vo gl2 -fixed-vo ";
		disable_video=0;
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output [gl2] Enabled\nVideo on Top Disabled");
		break;
	case ID_VIDEO_4:
		i_video=4;
		s_video="-vo sdl -fixed-vo ";
		disable_video=0;
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output [sdl] Enabled\nVideo on Top Disabled");
		break;
	case ID_VIDEO_5:
		i_video=5;
		s_video="-vo dga -fixed-vo ";
		disable_video=0;
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output [dga] Enabled");
		break;
	case ID_VIDEO_6:
		i_video=6;
		s_video="-vo xvidix -fixed-vo ";
		disable_video=0;
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output [xvidix] Enabled");
		break;
	case ID_VIDEO_7:
		i_video=7;
		s_video="-vo jpeg ";
		disable_video=0;
		FXMessageBox::information(this,MBOX_OK,"Option selected","Output >>> jpeg files enabled");
		break;
	case ID_VIDEO_8:
		i_video=8;
		s_video="-vo png ";
		disable_video=0;
		FXMessageBox::information(this,MBOX_OK,"Option selected","Output >>> png files enabled");
		break;
	case ID_VIDEO_9:
		i_video=9;
		s_video="-vo null ";
		disable_video=1;
		FXMessageBox::information(this,MBOX_OK,"Option selected","Video Output Disabled");
		break;
      }
    }
  return 1;
  }


// Update video output for mplayer
long FXMovieManager::onUpdVideoSwitch(FXObject* sender,FXSelector sel,void* ptr){
  FXint n_video=FXSELID(sel)-ID_VIDEO_1+1;
  sender->handle(this,i_video==n_video?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
  return 1;
  }


// Change video size for both mplayer and ffplay
long FXMovieManager::onCmdSizeSwitch(FXObject* sender,FXSelector sel,void* ptr){
  FXint n_size=FXSELID(sel)-ID_SIZE_1+1;
  if(0<=n_size && n_size<26){
    switch(FXSELID(sel)){
	case ID_SIZE_0:
		i_size=0;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -x 1920 -y 1080 ";
		}
		else if(defaultplayer=="ffplay"){
			s_size="-x 1920 -y 1080 ";
		}
		else if(defaultplayer=="fxplayer"){
			size_x = 1920; size_y = 1080;
		}
		break;	
	case ID_SIZE_1:
		i_size=1;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -x 1365 -y 768 ";
		}
		else if(defaultplayer=="ffplay"){
			s_size="-x 1365 -y 768 ";
		}
		else if(defaultplayer=="fxplayer"){
			size_x = 1365; size_y = 768; 
		}
		break;	
	case ID_SIZE_2:
		i_size=2;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -x 1280 -y 752 ";
		}
		else if(defaultplayer=="ffplay"){
			s_size="-x 1280 -y 752 ";
		}
		else if(defaultplayer=="fxplayer"){
			size_x = 1280; size_y = 752;
		}
		break;	
	case ID_SIZE_3:
		i_size=3;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -x 1280 -y 720 ";
		}
		else if(defaultplayer=="ffplay"){
			s_size="-x 1280 -y 720 ";
		}
		else if(defaultplayer=="fxplayer"){
			size_x = 1280; size_y = 720;
		}
		break;
	case ID_SIZE_4:
		i_size=4;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -x 1080 -y 720 ";
		}
		else if(defaultplayer=="ffplay"){
			s_size="-x 1080 -y 720 ";
		}
		else if(defaultplayer=="fxplayer"){
			size_x = 1080; size_y = 720;
		}
		break;
	case ID_SIZE_5:
		i_size=5;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -x 1080 -y 576 ";
		}
		else if(defaultplayer=="ffplay"){
			s_size="-x 1080 -y 576 ";
		}
		else if(defaultplayer=="fxplayer"){
			size_x = 1080; size_y = 576;
		}
		break;

	case ID_SIZE_6:
		i_size=6;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -x 960 -y 540 ";
		}
		else if(defaultplayer=="ffplay"){
			s_size="-x 960 -y 540 ";
		}
		else if(defaultplayer=="fxplayer"){
			size_x = 960; size_y = 540;
		}
		break;
	case ID_SIZE_7:
		i_size=7;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -x 720 -y 576 ";
		}
		else if(defaultplayer=="ffplay"){
			s_size="-x 720 -y 576 ";
		}
		else if(defaultplayer=="fxplayer"){
			size_x = 720; size_y = 576;
		}
		break;
	case ID_SIZE_8:
		i_size=8;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -x 640 -y 480 ";
		}
		else if(defaultplayer=="ffplay"){
			s_size="-x 640 -y 480 ";
		}
		else if(defaultplayer=="fxplayer"){
			size_x = 640; size_y = 480;
		}
		break;
	case ID_SIZE_9:
		i_size=9;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -x 640 -y 384 ";
		}
		else if(defaultplayer=="ffplay"){
			s_size="-x 640 -y 384 ";
		}
		else if(defaultplayer=="fxplayer"){
			size_x = 640; size_y = 384;
		}
		break;
	case ID_SIZE_10:
		i_size=10;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -x 540 -y 360 ";
		}
		else if(defaultplayer=="ffplay"){
			s_size="-x 540 -y 360 ";
		}
		else if(defaultplayer=="fxplayer"){
			size_x = 540; size_y = 360;
		}
		break;
	case ID_SIZE_11:
		i_size=11;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -x 480 -y 576 ";
		}
		else if(defaultplayer=="ffplay"){
			s_size="-x 480 -y 576 ";
		}
		else if(defaultplayer=="fxplayer"){
			size_x = 480; size_y = 576;
		}
		break;
	case ID_SIZE_12:
		i_size=12;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -x 480 -y 480 ";
		}
		else if(defaultplayer=="ffplay"){
			s_size="-x 480 -y 480 ";
		}
		else if(defaultplayer=="fxplayer"){
			size_x = 480; size_y = 480;
		}
		break;
	case ID_SIZE_13:
		i_size=13;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -xy 3.4 ";
		}
		break;
	case ID_SIZE_14:
		i_size=14;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -xy 3.1 ";
		}
		break;
	case ID_SIZE_15:
		i_size=15;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -xy 2.8 ";
		}
		break;
	case ID_SIZE_16:
		i_size=16;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -xy 2.5 ";
		}
		break;
	case ID_SIZE_17:
		i_size=17;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -xy 2.2 ";
		}
		break;
	case ID_SIZE_18:
		i_size=18;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -xy 1.9 ";
		}
		break;
	case ID_SIZE_19:
		i_size=19;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -xy 1.6 ";
		}
		break;
	case ID_SIZE_20:
		i_size=20;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -xy 1.3 ";
		}
		break;
	case ID_SIZE_21:
		i_size=21;
    		if(defaultplayer=="mplayer"){
			s_size="";
		}
		else if(defaultplayer=="ffplay"){
			s_size="";
		}
		else if(defaultplayer=="fxplayer"){
		size_x = 0; size_y = 0;
		}
		break;
	case ID_SIZE_22:
		i_size=22;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -xy 0.9 ";
		}
		break;
	case ID_SIZE_23:
		i_size=23;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -xy 0.8 ";
		}
		break;
	case ID_SIZE_24:
		i_size=24;
    		if(defaultplayer=="mplayer"){
			s_size="-zoom -xy 0.6 ";
		}
		break;
   case ID_SIZE_25:
		i_size=25;
		if(FXInputDialog::getString(s_xsize,this,"CUSTOM","X Size:")){
			if(FXInputDialog::getString(s_ysize,this,"CUSTOM","Y Size:")){
    				if(defaultplayer=="mplayer"){
					s_size="-zoom -x "+s_xsize+" -y "+s_ysize+" ";
				}
				else if(defaultplayer=="ffplay"){
					s_size="-x "+s_xsize+" -y "+s_ysize+" ";
				}
				getApp()->reg().writeStringEntry("MENU","s_xsize",s_xsize.text());
				getApp()->reg().writeStringEntry("MENU","s_ysize",s_ysize.text());
			}
		}
	}
    }
  return 1;
  }


// Update video size
long FXMovieManager::onUpdSizeSwitch(FXObject* sender,FXSelector sel,void* ptr){
  FXint n_size=FXSELID(sel)-ID_SIZE_1+1;
  sender->handle(this,i_size==n_size?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
  return 1;
  }


// prepare the playlist
FXString FXMovieManager::returnPlaylist() {
	int64_t time_b = 0;   
	int64_t time_d = 24 * 3600;
	FXString s_begin, s_duration;
	int selected = 0;

	if(numtableitems >= 0){
		// Return the text of all items
		for(int r=0; r<numtableitems; ++r){
			if(table->isItemSelected(r,0)){
				selected++;
				//get the position where to start playing of the movie	
				s_begin = "-ss " + table->getItemText(r,1) + ":" + table->getItemText(r,2) + ":" + table->getItemText(r,3)+ "." + table->getItemText(r,4) + " ";
				s_duration = table->getItemText(r,5) + ":" + table->getItemText(r,6) + ":" + table->getItemText(r,7) + "." + table->getItemText(r,8) + " ";

				if(defaultplayer=="mplayer"){
					s_duration.prepend("-endpos ");
					// enquote to play files with name containing spaces
					s_list.append("'");
                    s_list.append(table->getItemText(r,0));
                    s_list.append("' ");
                    s_list.append(s_begin);
                    s_list.append(s_duration);
	      			}
				else if(defaultplayer=="ffplay"){
					if(selected>1){
						s_list.append(" && ");
					}
					s_duration.prepend("-t ");
					s_list.append(s_command);
					s_list.append("-autoexit ");
					s_list.append(s_loop);
					s_list.append(s_size);
					s_list.append(s_full);
					s_list.append(f_audio);
					s_list.append(s_frame);
					// enquote to play files with name containing spaces
					s_list.append("'");
					s_list.append(table->getItemText(r,0));
					s_list.append("' ");
					s_list.append(s_begin);
					s_list.append(s_duration);
				}
				else if(defaultplayer=="fxplayer"){
					// item name
					if(!s_list.empty()){
						s_list.clear();
					}
					s_list.append(table->getItemText(r,0));
					// start time
#ifdef HAVE_LIBFOX_1_7
					int beg_h = table->getItemText(r,1).toInt();
					int beg_m = table->getItemText(r,2).toInt();
					int beg_s = table->getItemText(r,3).toInt();
					// duration
					int dur_h = table->getItemText(r,5).toInt();
					int dur_m = table->getItemText(r,6).toInt();
					int dur_s = table->getItemText(r,7).toInt();
#elif HAVE_LIBFOX_1_6
					int beg_h = FXIntVal(table->getItemText(r,1));
					int beg_m = FXIntVal(table->getItemText(r,2));
					int beg_s = FXIntVal(table->getItemText(r,3));
					// duration
					int dur_h = FXIntVal(table->getItemText(r,5));
					int dur_m = FXIntVal(table->getItemText(r,6));
					int dur_s = FXIntVal(table->getItemText(r,7));
#endif
					if (beg_h || beg_m || beg_s) {
						time_b = beg_h * 3600 + beg_m * 60 + beg_s;
					} else {
        				time_b = 0;
					}

					if (dur_h || dur_m || dur_s) {
						time_d = dur_h * 3600 + dur_m * 60 + dur_s;
					} else {
        				time_d = 0;
					}
       				//printf("GUI_start=%d, GUI_duration=%d\n", time_b, time_d);
	   				char c_list[1024];
	   				stpncpy(c_list, s_list.text(), sizeof(c_list));
	   				playerdialog->setCmd(c_list, time_b, time_d, size_x, size_y, loop, full, drop, disable_audio, disable_video, time_a);
      				FXMovieManager::hide();
       				playerdialog->execute(PLACEMENT_OWNER);	
	   				//FXMovieManager::show();
				}
			}
		}
	}
	return s_list;
}


// playlist play command
long FXMovieManager::onCmdPlay(FXObject *,FXSelector,void *) {

	// reset the fifo every time we play
	system (removeTempFifo.text());
	system (createTempFifo.text());

	//get the speed
	FXfloat i_speed = spe_knob->getValue();
	if(i_speed==0){
		i_speed=1;
	}
	FXfloat f_speed = (i_speed/100);
	//get the volume
	FXint i_volume = vol_knob->getValue();

	FXString s_speed = "-speed " + (VALUE_TO_STRING(f_speed,2)) + " ";
	FXString s_volume = "-volume " + (VALUE_TO_STRING(i_volume)) + " ";
	FXfloat f_delay = delayspinner->getValue();
	FXString s_delay = "-delay " + (VALUE_TO_STRING(f_delay)) + " ";

	returnPlaylist();
	if(s_list.empty()) {
		return 1;
    }

    FXString s_play;

    if(defaultplayer=="fxplayer"){
		FXMovieManager::show();
/*
       printf("fxplayer filename: %s\n", s_list.text());
       //printf("GUI_start=%d, GUI_duration=%d\n", time_b, time_d);
	   char c_list[1024];
	   stpncpy(c_list, s_list.text(), sizeof(c_list));
	   playerdialog->setCmd(c_list, time_b, time_d, size_x, size_y, loop, full, drop, disable_audio, disable_video);
       hide();
       playerdialog->execute(PLACEMENT_OWNER);	
	   show();
*/
		return 1;
    }

    else if(defaultplayer=="mplayer"){
		// mplayer correct command list sequence....
		s_play = s_command + s_loop + s_video + s_size + s_full + s_speed + s_audio + s_volume + s_frame + s_delay + s_list + " &";
    	printf("mplayer command: %s\n", s_play.text());
    }
    else if(defaultplayer=="ffplay"){
		s_play = s_list + " &";
    	printf("ffplay command: %s\n", s_play.text());
    }


	int ret;

    while (isrunning == TRUE){
      if(defaultplayer=="mplayer"){
        ret=system("killall mplayer");
      }
      else if(defaultplayer=="ffplay"){
        ret=system("killall ffplay");
      }

      if (WIFSIGNALED(ret) && (WTERMSIG(ret) == SIGINT || WTERMSIG(ret) == SIGQUIT)){
         break;
	  }
	  isrunning = FALSE;
	}

    if(defaultplayer=="mplayer" || defaultplayer=="ffplay"){
        while (isrunning == FALSE){
            int ret=system(s_play.text());
            if (WIFSIGNALED(ret) && (WTERMSIG(ret) == SIGINT || WTERMSIG(ret) == SIGQUIT)){
                break;
	        }
	        isrunning = TRUE;
	    }
    }

  	// clear liststr
   	s_play.clear();
   	s_list.clear();

	return 1;
}

// playlist pause command
long FXMovieManager::onCmdPause(FXObject *,FXSelector,void *) {
 	if (isrunning==TRUE){
		FILE *f;
		f=fopen(currentFifo.text(), "r+");
		fprintf(f, "%s", "pause\n");
		fclose(f);
	} else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","MPlayer is NOT running");
	}
	return 1;
}

// playlist stop command
long FXMovieManager::onCmdStop(FXObject *,FXSelector,void *) {
 if(defaultplayer=="mplayer"){
	if (isrunning==TRUE){
		FILE *f;
		f=fopen(currentFifo.text(), "r+");
		fprintf(f, "%s", "quit 1\n");
		fclose(f);
		isrunning=FALSE;
	} else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","MPlayer is NOT running");
	}
  }
  else if(defaultplayer=="ffplay"){
	if (isrunning==TRUE){
      system("killall ffplay");
	  isrunning=FALSE;
  	} else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","ffplay is NOT running");
    }
  }

  return 1;
}

// playlist speed command
long FXMovieManager::onCmdSpeed(FXObject *,FXSelector,void *) {
 	if (isrunning==TRUE){
		FILE *f;
		f=fopen(currentFifo.text(), "r+");

		//get the speed
		FXfloat i_speed = spe_knob->getValue();
		if(i_speed==0){
			i_speed=1;
		}
		FXfloat f_speed = (i_speed/100);
		FXString s_speed = "speed_set " + (VALUE_TO_STRING(f_speed,2)) + " 1 \n";
		fprintf(f, "%s", s_speed.text());
		fclose(f);
	}
	return 1;
}

// playlist volume command
long FXMovieManager::onCmdVolume(FXObject *,FXSelector,void *) {
 	if (isrunning==TRUE){
		FILE *f;
		f=fopen(currentFifo.text(), "r+");
		// get volume
		FXint i_volume = vol_knob->getValue();
		FXString s_volume = "volume " + (VALUE_TO_STRING(i_volume)) + " 1 \n";
		fprintf(f, "%s", s_volume.text());
		fclose(f);
	}
	return 1;
}


// playlist audio command
long FXMovieManager::onCmdAudio(FXObject *,FXSelector,void *) {
   	if(isrunning==TRUE){
		if(s_audio==""){
			FILE *f;
			f=fopen(currentFifo.text(), "r+");
			fprintf(f, "%s", "mute 1\n");
			fclose(f);
			s_audio="-nosound ";
			audiobutton->setState(TRUE);
		} else if(s_audio=="-nosound "){
			FILE *f;
			f=fopen(currentFifo.text(), "r+");
			fprintf(f, "%s", "mute 0\n");
			fclose(f);
			s_audio= "";
			audiobutton->setState(FALSE);
		}
   	} else if (isrunning==FALSE){
		if(s_audio==""){
			s_audio = "-nosound ";
			f_audio = "-an ";  // ffplay
			disable_audio = 1;  // fxpalyer
			audiobutton->setState(TRUE);
			FXMessageBox::information(this,MBOX_OK,"Audio Management","Audio Management is Disabled");
		} else if(s_audio=="-nosound "){
			s_audio = "";
			f_audio = "";  // ffplay
			disable_audio = 0;  // fxplayer
			audiobutton->setState(FALSE);
			FXMessageBox::information(this,MBOX_OK,"Audio Management","Audio Management is Enabled");
		}
   	}
   	return 1;
}

// playlist frame drop command
long FXMovieManager::onCmdDrop(FXObject *,FXSelector,void *) {
   	if(isrunning==TRUE){
		if(s_frame==""){
			FILE *f;
			f=fopen(currentFifo.text(), "r+");
			fprintf(f, "%s", "frame_drop 1\n");
			fclose(f);
			s_frame = "-framedrop ";
			dropbutton->setState(TRUE);
		} else if(s_frame=="-framedrop "){
			FILE *f;
			f=fopen(currentFifo.text(), "r+");
			fprintf(f, "%s", "frame_drop 0\n");
			fclose(f);
			s_frame = "";
			dropbutton->setState(FALSE);
		}
    } else if (isrunning==FALSE){
		if(s_frame==""){
			s_frame = "-framedrop ";
			drop = 1; // fxplayer
			dropbutton->setState(TRUE);
			FXMessageBox::information(this,MBOX_OK,"Framedrop Management","Framadrop is Enabled");
		} else if(s_frame=="-framedrop "){
			s_frame = "";
			drop = 0; // fxplayer
			dropbutton->setState(FALSE);
			FXMessageBox::information(this,MBOX_OK,"Framedrop Management","Framadrop is Disabled");
		}
    }
    return 1;
}

// playlist video zoom command
long FXMovieManager::onCmdFull(FXObject *,FXSelector,void *) {
   	if(isrunning==TRUE){
		if(s_full==""){
			FILE *f;
			f=fopen(currentFifo.text(), "r+");
			fprintf(f, "%s", "vo_fullscreen 1\n");
			fclose(f);
			s_full = "-fs ";
			zoombutton->setState(TRUE);
		} else if(s_full=="-fs "){
			FILE *f;
			f=fopen(currentFifo.text(), "r+");
			fprintf(f, "%s", "vo_fullscreen 0\n");
			fclose(f);
			s_full = "";
			zoombutton->setState(FALSE);
		}
    } else if (isrunning==FALSE){
		if(s_full==""){
			s_full = "-fs ";
			full = 1;  // fxplayer
			zoombutton->setState(TRUE);
			FXMessageBox::information(this,MBOX_OK,"Fullscreen Management","Fullscreen is Enabled");
		} else if(s_full=="-fs "){
			s_full = "";
			full = 0;  // fxplayer
			zoombutton->setState(FALSE);
			FXMessageBox::information(this,MBOX_OK,"Fullscreen Management","Fullscreen is Disabled");
		}
    }
	return 1;
}

// playlist loop command
long FXMovieManager::onCmdLoop(FXObject *,FXSelector,void *) {
   	if(isrunning==TRUE){
		if(s_loop==""){
			FILE *f;
			f=fopen(currentFifo.text(), "r+");
			fprintf(f, "%s", "loop 0 1\n");
			fclose(f);
			s_loop = "-loop 0 ";
			loopbutton->setState(TRUE);
		} else if(s_loop=="-loop 0 "){
			FILE *f;
			f=fopen(currentFifo.text(), "r+");
			fprintf(f, "%s", "loop -1 1\n");
			fclose(f);
			s_loop = "";
			loopbutton->setState(FALSE);
		}
    } else if (isrunning==FALSE){
		if(s_loop==""){
			s_loop = "-loop 0 ";
			loopbutton->setState(TRUE);
			loop = 1;  // fxplayer
			FXMessageBox::information(this,MBOX_OK,"Loop Management","Loop is Enabled");
		} else if(s_loop=="-loop 0 "){
			s_loop = "";
			loopbutton->setState(FALSE);
			loop = 0;  // fxplayer
			FXMessageBox::information(this,MBOX_OK,"Loop Management","Loop is Disabled");
		}
	}
	return 1;
}

// playlist audio delay command
long FXMovieManager::onCmdAudiodelay(FXObject *,FXSelector,void *) {
	FXfloat f_delay = delayspinner->getValue();
	time_a = f_delay;
	
 	if (isrunning==TRUE){
		FILE *f;
		f=fopen(currentFifo.text(), "r+");
		FXString s_audiodelay = "audio_delay " + (VALUE_TO_STRING(f_delay)) + " 1 \n";
		fprintf(f, "%s", s_audiodelay.text());
		fclose(f);
	} 
	return 1;
}

// more player controls
long FXMovieManager::onCmdBrightness(FXObject *,FXSelector,void *) {
 	if (isrunning==TRUE){
		FILE *f;
		f=fopen(currentFifo.text(), "r+");
		// get value
		FXint f_val = bri_knob->getValue();
		FXString s_val = "brightness " + (VALUE_TO_STRING(f_val)) + " 1 \n";
		fprintf(f, "%s", s_val.text());
		fclose(f);
	} 
	return 1;
}

long FXMovieManager::onCmdContrast(FXObject *,FXSelector,void *) {
 	if (isrunning==TRUE){
		FILE *f;
		f=fopen(currentFifo.text(), "r+");
		// get value
		FXint f_val = con_knob->getValue();
		FXString s_val = "contrast " + (VALUE_TO_STRING(f_val)) + " 1\n";
		fprintf(f, "%s", s_val.text());
		fclose(f);
	} 
	return 1;
}
/*
long FXMovieManager::onCmdGamma(FXObject *,FXSelector,void *) {
 	if (isrunning==TRUE){
		FILE *f;
		f=fopen(currentFifo.text(), "r+");
		// get value
		FXint f_val = gam_knob->getValue();
		FXString s_val = "gamma " + (VALUE_TO_STRING(f_val)) + " 1 \n";
		fprintf(f, "%s", s_val.text());
		fclose(f);
	} 
	return 1;
}
*/
long FXMovieManager::onCmdHue(FXObject *,FXSelector,void *) {
 	if (isrunning==TRUE){
		FILE *f;
		f=fopen(currentFifo.text(), "r+");
		// get value
		FXint f_val = hue_knob->getValue();
		FXString s_val = "hue " + (VALUE_TO_STRING(f_val)) + " 1 \n";
		fprintf(f, "%s", s_val.text());
		fclose(f);
	} 
	return 1;
}

long FXMovieManager::onCmdSaturation(FXObject *,FXSelector,void *) {
 	if (isrunning==TRUE){
		FILE *f;
		f=fopen(currentFifo.text(), "r+");
		// get value
		FXint f_val = sat_knob->getValue();
		FXString s_val = "saturation " + (VALUE_TO_STRING(f_val)) + " 1 \n";
		fprintf(f, "%s", s_val.text());
		fclose(f);
	} 
	return 1;
}


/**************************TABLE COMMANDS****************************/

// load playlist
FXbool FXMovieManager::loadPlaylistTable(const FXString& filename) {
	// the file stream
	FXFileStream stream;	
	FXString tabpic;

	// open the file stream for reading
	if(stream.open(filename, FXStreamLoad)){ 
	//FXbool endianness;
	//stream >> endianness;
	//stream.setBigEndian(endianness);
	FXString totrootname,rootname,imagename,fullpath;
	FXint c,r;
	while(!stream.eof()){
		// Write the text of all items
	  	for (r=0; r<100; r++){
			for (c=0; c<9; c++){
				stream >> tabpic;
				FXStreamStatus sta=stream.status();
				if(sta!=FXStreamEnd){
		    		table->setItemText(r,c,tabpic);
					if(c==0){
						numtableitems++;
						fullpath=tabpic.rbefore('/',1);
    						//printf("fullpath is: %s\n", fullpath.text());
						totrootname=tabpic.rbefore('.',1);
    						//printf("totrootname is: %s\n", totrootname.text());
  						rootname=totrootname.rafter('/',1);
    						//printf("rootname is: %s\n", rootname.text());
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
						imagename=fullpath+"/."+rootname+"_thumbnail.jpg";
#else
						imagename=fullpath+"/."+rootname+"00000001/00000001.jpg";
#endif
    					//printf("imagename is: %s\n", imagename.text());
  						if(!previewListMovie(imagename, numtableitems-1)){
							FXMessageBox::error(this,MBOX_OK,"Thumbnail Loading Failure","Error on loading thumbnail: %s",imagename.text());
						}
        				//printf("itemnumbers is: %d\n", numtableitems-1);
					}
	  			}
			}
		}
	}
	// close the file stream
	stream.close();
	return TRUE;
	}
return FALSE;
}

FXbool FXMovieManager::savePlaylistTable(const FXString& filename) {

	// the file stream
	FXFileStream stream;	
	// open the file stream for writing
	if(stream.open(filename, FXStreamSave)){
		//FXbool endianness=FXStream::isBigEndian();
		//stream << endianness;

		if(numtableitems >= 0){
			// Return the text of all items
			for(int r=0; r<numtableitems; ++r){
				if(table->isItemSelected(r,0)){
				stream << table->getItemText(r,0); 
				stream << table->getItemText(r,1);
				stream << table->getItemText(r,2); 
				stream << table->getItemText(r,3);
				stream << table->getItemText(r,4); 
				stream << table->getItemText(r,5);
				stream << table->getItemText(r,6); 
				stream << table->getItemText(r,7);
				stream << table->getItemText(r,8); 
				}
			}
		}
		// close the file stream
		stream.close();
	return TRUE;
	}
return FALSE;
}


// Move Up Command
long FXMovieManager::onCmdMoveSelUp(FXObject*,FXSelector,void*){
    FXString rowtext;
    FXIcon *tempicon=NULL;
    tempicon=new FXIcon(getApp(),NULL,IMAGE_OPAQUE|IMAGE_KEEP);
	// Return current row index, if any
	FXint r = table->getCurrentRow();
	if(numtableitems > r){
	printf("num table items: %i\n", numtableitems);
		if(table->isItemSelected(r,0)){
			if(r >= 0){ // with FOX 1.7.30 take away this line to fix a recursion bug 
			FXint nr = r-1;
				if(nr>=0){
					// Move Up the current item
					table->extractText(rowtext,r,r,0,8);
    				if (tempicon){
						tempicon=table->getRowIcon(r);				
					}
					table->removeRows(r);
					printf("removed row: %i\n", r);
					table->insertRows(nr);
					printf("inserted row: %i\n", nr);
	  				table->setRowHeight(nr,68);
					// with FOX > 1.7.26 and < 1.7.31 we have to pass rowtext.text()
					table->overlayText(nr,nr,0,8,rowtext);
					table->setRowIcon(nr,tempicon);
					table->selectRange(nr,nr,0,0);
					table->setCurrentItem(nr,0); 
				}
			}
		}
	}
	return 1;
}


// Move Down Command
long FXMovieManager::onCmdMoveSelDown(FXObject*,FXSelector,void*){
    FXString rowtext;
    FXIcon *tempicon=NULL;
    tempicon=new FXIcon(getApp(),NULL,IMAGE_OPAQUE|IMAGE_KEEP);
	// Return current row index, if any
	FXint r = table->getCurrentRow();
	if(numtableitems > r){
		printf("num table items: %i\n", numtableitems);
		if(table->isItemSelected(r,0)){
			if(r >= 0){  // with FOX 1.7.30 take away this line to fix a recursion bug 
				FXint nr = r+1;
				if(nr<numtableitems){
					// Move Down the current item
					table->extractText(rowtext,r,r,0,8);
   						if (tempicon){
						tempicon=table->getRowIcon(r);				
					}
					table->removeRows(r);
					printf("removed row: %i\n", r);
					table->insertRows(nr);
					printf("inserted row: %i\n", nr);
  					table->setRowHeight(nr,68);
					// with FOX > 1.7.26 and < 1.7.31 we have to pass rowtext.text()
					table->overlayText(nr,nr,0,8,rowtext);
					table->setRowIcon(nr,tempicon);
					table->selectRange(nr,nr,0,0);
					table->setCurrentItem(nr,0);
				}
			}
		}
	}
	return 1;
}


// Append command
long FXMovieManager::onCmdAppend(FXObject *,FXSelector,void *) {
	appendFiledialogSelection();
	return 1;
}


// Insert Command
long FXMovieManager::onCmdInsert(FXObject*,FXSelector,void*){
	insertFiledialogSelection();
	return 1;
}


// Select All Command
long FXMovieManager::onCmdSelectAll(FXObject*,FXSelector,void*){
	selectAll();
	return 1;
}


// Delete Command
long FXMovieManager::onCmdDelete(FXObject*,FXSelector,void*){

	if(numtableitems >= 0){
		// Remove all selected items
		for(int r=numtableitems; r>=0; --r){
			if(table->isItemSelected(r,0)){
				//printf("The item index selected was %d\n", i);
				table->removeRows(r);
				numtableitems=numtableitems-1;
 				table->insertRows(99);
				table->setRowHeight(99,68);
				for (int c=1; c<9; c++){
	    			table->setItemText(99,c,"00");
	  			}
	  			table->setItemText(99,5,"10");
			}
		}
	}
	return 1;
}


// Save Playlist Command
long FXMovieManager::onCmdSavePlaylist(FXObject*,FXSelector,void*){
	FXString file = "playlist_.pls";
	FXFileDialog savedialog(this,"Save Playlist");
	savedialog.setFilename(file);
	if(savedialog.execute()){
		selectAll();
		file=savedialog.getFilename();
		if(FXStat::exists(file)){
      		if(MBOX_CLICKED_NO==FXMessageBox::question(this,MBOX_YES_NO,"Overwrite Playlist","Overwrite existing Playlist: %s?",file.text()))
			return 1;
		}
		if(savePlaylistTable(file)){
			FXMessageBox::information(this,MBOX_OK,"Saving Playlist","The playlist have been saved");	
		}
	}
	return 1;
}


// Open Playlist Command
long FXMovieManager::onCmdOpenPlaylist(FXObject*,FXSelector,void*){
	FXString file;
	FXFileDialog opendialog(this,"Load Playlist");
	if(opendialog.execute()){
		resetTable();
		file=opendialog.getFilename();
		if(loadPlaylistTable(file)){
			FXMessageBox::information(this,MBOX_OK,"Loading Playlist","The playlist have been loaded");	
		}
	}
	return 1;
}



// Clear Command
long FXMovieManager::onCmdClear(FXObject*,FXSelector,void*){
	resetTable();
	return 1;
}


// Released right button
long FXMovieManager::onListRightMouse(FXObject*,FXSelector,void* ptr){
  FXEvent* event=(FXEvent*)ptr;
  if(!event->moved){
    popupmenu->popup(NULL,event->root_x,event->root_y);
    getApp()->runModalWhileShown(popupmenu);
    }
  return 1;
}


// Select All Command
void FXMovieManager::selectAll(){
	FXint r;
	if(numtableitems >= 0){
		table->selectRange(0,numtableitems-1,0,0);
	}
  }


// Enable sender when items have been selected 
long FXMovieManager::onUpdSelectedTable(FXObject* sender,FXSelector,void*){
  if(numtableitems<0){
	return 1;
  }	
  sender->handle(this,getTableNums()?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
  return 1;
  }


// Get number of selected filenames, in the play table 
FXint FXMovieManager::getTableNums() const {
  register FXint tablenum=0;
  register FXint e;
  if(numtableitems>=0){
    for(e=0; e<numtableitems; e++){
      if(table->isItemSelected(e,0)) tablenum++;
      }
    }
  return tablenum;
  }




/****************************DIRECTORY LIST**********************************/


// Create new directory
long FXMovieManager::onCmdNewDir_lp(FXObject*,FXSelector,void*){
  FXFileList::ID_REFRESH;
  FXDialogBox dialog(this,"Create New Directory",DECOR_TITLE|DECOR_BORDER);
  const FXchar suggestedname[]="DirectoryName";
  FXVerticalFrame* content=new FXVerticalFrame(&dialog,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,10,10,10,10,10,10);
  new FXLabel(content,"Create new directory in: "+filelist_lp->getDirectory(),NULL,LAYOUT_FILL_X|JUSTIFY_LEFT);
  FXTextField *text=new FXTextField(content,40,&dialog,FXDialogBox::ID_ACCEPT,TEXTFIELD_ENTER_ONLY|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X);
  new FXHorizontalSeparator(content,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame* buttons=new FXHorizontalFrame(content,LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
  new FXButton(buttons,"&YES",m_accepticon,&dialog,FXDialogBox::ID_ACCEPT,BUTTON_INITIAL|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT);
  new FXButton(buttons,"&Cancel",m_cancelicon,&dialog,FXDialogBox::ID_CANCEL,ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
  dialog.create();

  text->setText(suggestedname);
  text->setFocus();
  text->setSelection(0,sizeof(suggestedname));

  if(dialog.execute()){
    FXString dirname=FXPath::absolute(filelist_lp->getDirectory(),text->getText());
    if(FXStat::exists(dirname)){
      FXMessageBox::error(this,MBOX_OK,"Already Exists","File or directory %s already exists.\n",dirname.text());
      }
    else if(!FXDir::create(dirname)){
      FXMessageBox::error(this,MBOX_OK,"Cannot Create","Cannot create directory %s.\n",dirname.text());
      }
    else {
      currentdir_lp=dirname;
      synchronize_lp(currentdir_lp);
    }
  }
  return 1;
}

// Create new directory
long FXMovieManager::onCmdNewDir_rp(FXObject*,FXSelector,void*){
  FXFileList::ID_REFRESH;
  FXDialogBox dialog(this,"Create New Directory",DECOR_TITLE|DECOR_BORDER);
  const FXchar suggestedname[]="DirectoryName";
  FXVerticalFrame* content=new FXVerticalFrame(&dialog,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,10,10,10,10,10,10);
  new FXLabel(content,"Create new directory in: "+filelist_rp->getDirectory(),NULL,LAYOUT_FILL_X|JUSTIFY_LEFT);
  FXTextField *text=new FXTextField(content,40,&dialog,FXDialogBox::ID_ACCEPT,TEXTFIELD_ENTER_ONLY|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X);
  new FXHorizontalSeparator(content,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame* buttons=new FXHorizontalFrame(content,LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
  new FXButton(buttons,"&YES",m_accepticon,&dialog,FXDialogBox::ID_ACCEPT,BUTTON_INITIAL|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT);
  new FXButton(buttons,"&Cancel",m_cancelicon,&dialog,FXDialogBox::ID_CANCEL,ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
  dialog.create();

  text->setText(suggestedname);
  text->setFocus();
  text->setSelection(0,sizeof(suggestedname));

  if(dialog.execute()){
    FXString dirname=FXPath::absolute(filelist_rp->getDirectory(),text->getText());
    if(FXStat::exists(dirname)){
      FXMessageBox::error(this,MBOX_OK,"Already Exists","File or directory %s already exists.\n",dirname.text());
      }
    else if(!FXDir::create(dirname)){
      FXMessageBox::error(this,MBOX_OK,"Cannot Create","Cannot create directory %s.\n",dirname.text());
      }
    else {
      currentdir_rp=dirname;
      synchronize_rp(currentdir_rp);
    }
  }
  return 1;
}




// Delete directory the directory list
long FXMovieManager::onCmdDirDelete_lp(FXObject*,FXSelector,void*){
  FXuint answer=FXMessageBox::warning(this,MBOX_YES_NO,"Deleting Directory if empty","Are you sure you want to delete this directory?");
  if(answer==MBOX_CLICKED_YES){

    FXString dropdir=dirlist_lp->getDirectory();
    FXTRACE((100,"dropdir=%s\n",dropdir.text()));
        if(!FXDir::remove(dropdir)){
          if(MBOX_CLICKED_NO==FXMessageBox::error(this,MBOX_YES_NO,"Error Deleting Directory","Unable to delete directory: %s\nContinue with operation?",dropdir.text())){
            return 1;
            }
        } else {
	  	    currentdir_lp=FXPath::absolute(dirlist_lp->getDirectory());
            synchronize_lp(currentdir_lp);
		}
    }
  return 1;
  }

// Delete directory the directory list
long FXMovieManager::onCmdDirDelete_rp(FXObject*,FXSelector,void*){
  FXuint answer=FXMessageBox::warning(this,MBOX_YES_NO,"Deleting Directory if empty","Are you sure you want to delete this directory?");
  if(answer==MBOX_CLICKED_YES){

    FXString dropdir=dirlist_rp->getDirectory();
    FXTRACE((100,"dropdir=%s\n",dropdir.text()));
        if(!FXDir::remove(dropdir)){
          if(MBOX_CLICKED_NO==FXMessageBox::error(this,MBOX_YES_NO,"Error Deleting Directory","Unable to delete directory: %s\nContinue with operation?",dropdir.text())){
            return 1;
            }
        } else {
	  		currentdir_lp=FXPath::absolute(dirlist_rp->getDirectory());
            synchronize_rp(currentdir_rp);
		}
    }
  return 1;
  }


// Rename directory in the directory list
long FXMovieManager::onCmdDirRename_lp(FXObject*,FXSelector,void*){

  FXString dirname=dirlist_lp->getDirectory();

  FXDialogBox dialog(this,"Rename Directory",DECOR_TITLE|DECOR_BORDER);
  FXVerticalFrame* content=new FXVerticalFrame(&dialog,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,10,10,10,10,10,10);
  new FXLabel(content,"Old Directory Name: "+dirname,NULL,LAYOUT_FILL_X|JUSTIFY_LEFT);
  FXTextField *text=new FXTextField(content,40,&dialog,FXDialogBox::ID_ACCEPT,TEXTFIELD_ENTER_ONLY|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X);
  new FXHorizontalSeparator(content,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame* buttons=new FXHorizontalFrame(content,LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
  new FXButton(buttons,"&YES",m_accepticon,&dialog,FXDialogBox::ID_ACCEPT,BUTTON_INITIAL|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT);
  new FXButton(buttons,"&Cancel",m_cancelicon,&dialog,FXDialogBox::ID_CANCEL,ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
  dialog.create();

  text->setText(dirname);
  text->setFocus();

  if(dialog.execute()){

      //FXString suggestedname=FXPath::absolute(dirlist_lp->getDirectory(),text->getText());
      FXString suggestedname=FXPath::absolute(text->getText());

      if(!FXDir::rename(dirname,suggestedname)){
        FXMessageBox::error(this,MBOX_OK,"Cannot Rename","Cannot Rename directory %s.\n",dirname.text());
      }
      else{
		//currentdir_lp=FXPath::absolute(dirlist_lp->getDirectory(),text->getText());
		currentdir_lp=FXPath::absolute(text->getText());
        synchronize_lp(currentdir_lp);
      }	
   } 
   return 1;
  }

// Rename directory in the directory list
long FXMovieManager::onCmdDirRename_rp(FXObject*,FXSelector,void*){

  FXString dirname=dirlist_rp->getDirectory();

  FXDialogBox dialog(this,"Rename Directory",DECOR_TITLE|DECOR_BORDER);
  FXVerticalFrame* content=new FXVerticalFrame(&dialog,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,10,10,10,10,10,10);
  new FXLabel(content,"Old Directory Name: "+dirname,NULL,LAYOUT_FILL_X|JUSTIFY_LEFT);
  FXTextField *text=new FXTextField(content,40,&dialog,FXDialogBox::ID_ACCEPT,TEXTFIELD_ENTER_ONLY|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X);
  new FXHorizontalSeparator(content,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame* buttons=new FXHorizontalFrame(content,LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
  new FXButton(buttons,"&YES",m_accepticon,&dialog,FXDialogBox::ID_ACCEPT,BUTTON_INITIAL|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT);
  new FXButton(buttons,"&Cancel",m_cancelicon,&dialog,FXDialogBox::ID_CANCEL,ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
  dialog.create();

  text->setText(dirname);
  text->setFocus();

  if(dialog.execute()){

      //FXString suggestedname=FXPath::absolute(dirlist_rp->getDirectory(),text->getText());
      FXString suggestedname=FXPath::absolute(text->getText());

      if(!FXDir::rename(dirname,suggestedname)){
        FXMessageBox::error(this,MBOX_OK,"Cannot Rename","Cannot Rename directory %s.\n",dirname.text());
      }
      else{
		//currentdir_lp=FXPath::absolute(dirlist_lp->getDirectory(),text->getText());
		currentdir_rp=FXPath::absolute(text->getText());
        synchronize_rp(currentdir_rp);
      }	
   } 
   return 1;
  }


// Update create new directory
long FXMovieManager::onUpdNewDir_lp(FXObject* sender,FXSelector,void*){
  FXString path=filelist_lp->getDirectory();
  if(FXStat::isWritable(path))
    sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
  else
    sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
  return 1;
  }

// Update create new directory
long FXMovieManager::onUpdNewDir_rp(FXObject* sender,FXSelector,void*){
  FXString path=filelist_rp->getDirectory();
  if(FXStat::isWritable(path))
    sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
  else
    sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
  return 1;
  }


// Change the directory from the FXDirList
long FXMovieManager::onCmdDirectory_lp(FXObject*,FXSelector,void* ptr){
  FXTreeItem *item=(FXTreeItem*)ptr;
  FXString path=dirlist_lp->getItemPathname(item);
  synchronize_lp(path);
  showFilelistThumbnails_lp();
  return 1;
  }

// Change the directory from the FXDirList
long FXMovieManager::onCmdDirectory_rp(FXObject*,FXSelector,void* ptr){
  FXTreeItem *item=(FXTreeItem*)ptr;
  FXString path=dirlist_rp->getItemPathname(item);
  synchronize_rp(path);
  showFilelistThumbnails_rp();
  return 1;
  }


// Move up one directory
long FXMovieManager::onCmdUpDirectory_lp(FXObject*,FXSelector,void*){
  FXString path=FXPath::upLevel(filelist_lp->getDirectory());
  synchronize_lp(path);
  showFilelistThumbnails_lp();
  return 1;
  }

// Move up one directory
long FXMovieManager::onCmdUpDirectory_rp(FXObject*,FXSelector,void*){
  FXString path=FXPath::upLevel(filelist_rp->getDirectory());
  synchronize_rp(path);
  showFilelistThumbnails_rp();
  return 1;
  }


// Popup menu for item in dir list
long FXMovieManager::onDirListPopup_lp(FXObject*,FXSelector,void* ptr){
  FXEvent *event=(FXEvent*)ptr;
  if(event->moved) return 1;

  FXMenuPane pane(dirlist_lp);

    FXLabel *dirlist_lplabel = new FXLabel(&pane,"Directory Item");
    dirlist_lplabel->setTextColor(FXRGB(120,0,0));

    new FXMenuCommand(&pane,menu_ma,m_mapicon,this,ID_MAPHOST_LP);
    new FXMenuCommand(&pane,menu_um,m_unmapicon,this,ID_UNMAPHOST_LP);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,menu_nd,m_appendicon,this,ID_NEWDIR_LP);
    new FXMenuCommand(&pane,menu_rd,m_renamediricon,this,ID_DIRRENAME_LP);
    new FXMenuCommand(&pane,menu_sh,m_showhiddenicon,dirlist_lp,FXDirList::ID_TOGGLE_HIDDEN);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,menu_dd,m_deleteicon,this,ID_DIRDELETE_LP);


  pane.create();
  pane.popup(NULL,event->root_x,event->root_y);
  getApp()->runModalWhileShown(&pane);
  return 1;
  }

// Popup menu for item in dir list
long FXMovieManager::onDirListPopup_rp(FXObject*,FXSelector,void* ptr){
  FXEvent *event=(FXEvent*)ptr;
  if(event->moved) return 1;

  FXMenuPane pane(dirlist_rp);

    FXLabel *dirlist_lplabel = new FXLabel(&pane,"Directory Item");
    dirlist_lplabel->setTextColor(FXRGB(120,0,0));

    new FXMenuCommand(&pane,menu_ma,m_mapicon,this,ID_MAPHOST_RP);
    new FXMenuCommand(&pane,menu_um,m_unmapicon,this,ID_UNMAPHOST_RP);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,menu_nd,m_appendicon,this,ID_NEWDIR_RP);
    new FXMenuCommand(&pane,menu_rd,m_renamediricon,this,ID_DIRRENAME_RP);
    new FXMenuCommand(&pane,menu_sh,m_showhiddenicon,dirlist_rp,FXDirList::ID_TOGGLE_HIDDEN);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,menu_dd,m_deleteicon,this,ID_DIRDELETE_RP);

  pane.create();
  pane.popup(NULL,event->root_x,event->root_y);
  getApp()->runModalWhileShown(&pane);
  return 1;
  }



/***************** BASIC CLIPBOARD MANAGEMENT *****************/

// The selection has been lost (Paste after Copy/Cut or Copy/Cut after Copy/Cut)
long FXMovieManager::onClipboardLost(FXObject* sender,FXSelector sel,void* ptr) {
	// BaseClassWidget received SEL_CLIPBOARD_LOST msg
	FXMainWindow::onClipboardLost(sender,sel,ptr);
	return 1;
}


// The selection has been gained 
long FXMovieManager::onClipboardGained(FXObject* sender,FXSelector sel,void* ptr) {
	// BaseClassWidget received SEL_CLIPBOARD_GAINED msg
	FXMainWindow::onClipboardGained(sender,sel,ptr);
	return 1;
}


// The selection has been request 
long FXMovieManager::onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr) {
    // See if the base class knows how to deal with the requested clipboard uri list type
    if(FXMainWindow::onClipboardRequest(sender,sel,ptr)){
		return 1;
	}
	FXEvent *event=(FXEvent*)ptr;
	// See if we can deal with this uri list type ourselves
	if (event->target==urilistType) {
		// Return the clipboard content
		if(!clipboard.empty()){
#ifdef HAVE_LIBFOX_1_6
			FXuchar *data;
			FXMEMDUP(&data, clipboard.text(), FXuchar, clipboard.length());
			setDNDData(FROM_CLIPBOARD, event->target, data, clipboard.length());
#elif HAVE_LIBFOX_1_7
			setDNDData(FROM_CLIPBOARD, urilistType, clipboard);
#endif
		}
		// Return 1 because it was handled herere
		return 1;
	}
	// Return 0 to signify we haven't dealt with it yet;
	// a derived class of FXMainWindow may yet give another try....
	return 0;
}


// COPY or CUT to the clipboard 
long FXMovieManager::onCmdCopyCut_lp(FXObject*,FXSelector sel,void*){
	cmdCopyCut(filelist_lp, sel);
  return 1;
  }

long FXMovieManager::onCmdCopyCut_rp(FXObject*,FXSelector sel,void*){
	cmdCopyCut(filelist_rp, sel);
  return 1;
  }

// COPY or CUT to the clipboard 
long FXMovieManager::cmdCopyCut(FXFileList* panel, FXSelector sel){		

	clipboard.clear();

	// Define the DragType: urilistType and actionType for every CUT/COPY cmd
	FXDragType dragtp[2]={urilistType,actionType};

	// Acquires the clipboard and send msg SEL_CLIPBOARD_LOST to the previous widget which owned the clipboard
	if (acquireClipboard(dragtp,2)){
    	// set the action type
		if (FXSELID(sel)==ID_CLIPBOARD_CUT_LP or FXSELID(sel)==ID_CLIPBOARD_CUT_RP){
			actionType=1;
		}else{
			actionType=0;
		}
		// If we have some files selected, go ahead
    	FXint n=getNumFilenames(panel);
    	if (n==0){ 	return 0; }  // error we don't have any file selected
		else if (n>=1){
		// Construct the uri LIST of files and fill the clipboard with it
			for(int i=0; i<panel->getNumItems(); i++){
#ifdef HAVE_LIBFOX_1_6
				if(panel->isItemSelected(i) && panel->getItemFilename(i)!=".." && panel->getItemFilename(i)!="."){
					clipboard.append(FXURL::encode(FXURL::fileToURL(panel->getItemPathname(i))));
#elif HAVE_LIBFOX_1_7
				if(panel->isItemSelected(i) && !panel->isItemNavigational(i)){
					clipboard.append(FXURL::fileToURL(panel->getItemPathname(i)));
#endif
				}
			}
		}
	}
	return 1;
}


// PASTE from the clipboard
long FXMovieManager::onCmdPaste_lp(FXObject*,FXSelector sel,void*){
	cmdPaste(filelist_lp, sel);
  return 1;
  }

long FXMovieManager::onCmdPaste_rp(FXObject*,FXSelector sel,void*){
	cmdPaste(filelist_rp, sel);
  return 1;
  }


// PASTE from the clipboard
long FXMovieManager::cmdPaste(FXFileList* panel, FXSelector sel){
    FXFileList::ID_REFRESH;
    FXint n=0;
    FXString string, s_dst, s_beg, s_end;	

	progressbar->setProgress(0);
    progressbar->setTextColor(getApp()->getForeColor());
    progressbar->setBarColor(getApp()->getSelbackColor());
    progressbar->setTextAltColor(getApp()->getBackColor());

    //printf("actionType: %i\n", actionType);
#ifdef HAVE_LIBFOX_1_6
    FXuchar *data;
    FXuint len;
	// Check if the source has a drag type urilistType and get DND data; 
    if(getDNDData(FROM_CLIPBOARD,urilistType,data,len)){
		// resize memory
		FXRESIZE(&data,FXuchar,len+1);
		data[len]='\0';

		clipboard=(FXchar*)data;
		string.append(FXURL::decode(FXURL::fileFromURL(clipboard)));
		//printf("Pre Formatted: %s\n", string.text());

		n=string.contains("file:/")+1;
    	progressbar->setTotal(n);
		string.substitute("file:", "\n", true);
		//printf("Post Formatted: %s\n", string.text());
		for(FXint i=1; i<n+1; i++){
			progressbar->setProgress(i);
#elif HAVE_LIBFOX_1_7
	// Check if the source has a drag type urilistType and get DND data; 
	if(getDNDData(FROM_CLIPBOARD,urilistType,string)){
		//printf("Pre Formatted: %s\n", string.text());

		n=string.contains("file://")+1;
    	progressbar->setTotal(n-1);
		string.substitute("file://", "\n", true);
		//printf("Post Formatted: %s\n", string.text());
		for(FXint i=2; i<n+1; i++){
			progressbar->setProgress(i-1);
#endif
			s_beg = string.before('\n',i);
			s_end = s_beg.after('\n',i-1);
			s_dst = panel->getDirectory()+"/"+FXPath::name(s_end);

			if (!FXMainWindow::hasClipboard()){
				if(actionType!=1 && actionType!=0){
					actionType=0;
				}
			}

			if(actionType==1){
				if(!FXFile::moveFiles(s_end,s_dst,false)){
					if(FXMessageBox::question(this,MBOX_YES_NO,"Overwrite File","Overwrite existing file or directory: %s?",s_dst.text())==MBOX_CLICKED_NO){
						break;
					}
					FXFile::moveFiles(s_end,s_dst,true);
				}
			}else if(actionType==0){
				if(!FXFile::copyFiles(s_end,s_dst,false)){
					if(FXMessageBox::question(this,MBOX_YES_NO,"Overwrite File","Overwrite existing file or directory: %s?",s_dst.text())==MBOX_CLICKED_NO){
							break;
					}
					FXFile::copyFiles(s_end,s_dst,true);
				}
			}
		}
		// Clear the clipboard so that onUpdPaste() function gray out the Paste button
		clipboard.clear();
	}

	return 1;
}


// Update the PASTE button
long FXMovieManager::onUpdPaste(FXObject* o,FXSelector sel,void*){
    FXbool clipempty=TRUE;
	FXString string;
    FXuchar *data;
    FXuint len;	

	// Check if the source has a drag type urilistType and get DND data; 
#ifdef HAVE_LIBFOX_1_6
	if(getDNDData(FROM_CLIPBOARD,urilistType,data,len)){
		// resize memory
		FXRESIZE(&data,FXuchar,len+1);
		data[len]='\0';

		string=(FXchar*)data;
		// Check if clipboard has a valid string content
		if (string.find("file:/")>=0)
			clipempty=FALSE;
		// Free data pointer
		FXFREE(&data);
	}
#elif HAVE_LIBFOX_1_7
	if(getDNDData(FROM_CLIPBOARD,urilistType,string)){
		// Check if clipboard has a valid string content
		if (string.contains("file://")>=0){
			clipempty=FALSE;
		}
	}
#endif
	// Now we know if the clipboard is empty: if so gray out the paste button
	if (clipempty){
		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
	}else{
		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
	}
    return 1;
}


/****************************FILE LIST**********************************/

// Popup menu for item in file list
long FXMovieManager::onFileListPopup_lp(FXObject*,FXSelector,void* ptr){
  FXEvent *event=(FXEvent*)ptr;
  if(event->moved) return 1;
  FXint index=filelist_lp->getItemAt(event->win_x,event->win_y);
  FXMenuPane pane(filelist_lp);
  FXMenuPane *backgroundmenu;

  // We clicked in the background
  if(index<0){
    FXLabel *filebacklabel = new FXLabel(&pane,"Background");
    filebacklabel->setTextColor(FXRGB(120,0,0));
    // Background menu
    new FXMenuCommand(&pane,menu_te,m_terminalicon,this,ID_TERMINAL_LP);
    new FXMenuCommand(&pane,menu_he,m_consoleicon,this,ID_COMMAND_LP);
#ifdef HAVE_LIBCLAMAV
    new FXMenuCommand(&pane,menu_vi,m_bugicon,this,ID_SCANVIRUS_LP);
#endif
    new FXMenuCommand(&pane,menu_ar,m_archiveicon,this,ID_ARCHIVE_LP);
    new FXMenuCommand(&pane,menu_sr,m_searchicon,this,ID_FILESEARCH_LP);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,menu_nd,m_appendicon,this,ID_NEWDIR_LP);
    new FXMenuCommand(&pane,menu_sh,m_showhiddenicon,filelist_lp,FXFileList::ID_TOGGLE_HIDDEN);
    new FXMenuCommand(&pane,menu_rf,m_refreshicon,filelist_lp,FXFileList::ID_REFRESH);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,"[ ] "+menu_pa,m_pasteicon,this,ID_CLIPBOARD_PASTE_LP);
  }

  // We clicked on an item file or directory
  else{
    FXLabel *filelistlabel = new FXLabel(&pane,"File Item");
    filelistlabel->setTextColor(FXRGB(120,0,0));
    // Background menu
    backgroundmenu=new FXMenuPane(&pane);
    new FXMenuCommand(backgroundmenu,menu_te,m_terminalicon,this,ID_TERMINAL_LP);
    new FXMenuCommand(backgroundmenu,menu_he,m_consoleicon,this,ID_COMMAND_LP);
#ifdef HAVE_LIBCLAMAV
    new FXMenuCommand(backgroundmenu,menu_vi,m_bugicon,this,ID_SCANVIRUS_LP);
#endif
    new FXMenuCommand(backgroundmenu,menu_ar,m_archiveicon,this,ID_ARCHIVE_LP);
    new FXMenuCommand(backgroundmenu,menu_sr,m_searchicon,this,ID_FILESEARCH_LP);
    new FXMenuSeparator(backgroundmenu);
    new FXMenuCommand(backgroundmenu,menu_nd,m_appendicon,this,ID_NEWDIR_LP);
    new FXMenuCommand(backgroundmenu,menu_sh,m_showhiddenicon,filelist_lp,FXFileList::ID_TOGGLE_HIDDEN);
    new FXMenuCommand(backgroundmenu,menu_rf,m_refreshicon,filelist_lp,FXFileList::ID_REFRESH);
    new FXMenuSeparator(backgroundmenu);
    new FXMenuCommand(backgroundmenu,"[ ] "+menu_pa,m_pasteicon,this,ID_CLIPBOARD_PASTE_LP);
    new FXMenuCascade(&pane," Background",NULL,backgroundmenu);
    new FXMenuSeparator(&pane);

    new FXMenuCommand(&pane,menu_op,m_inserticon,this,ID_OPEN_LP);
    new FXMenuCommand(&pane,menu_ow,m_editicon,this,ID_OPENWITH_LP);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,menu_pr,m_propicon,this,ID_PROPERTIES_LP);
    new FXMenuCommand(&pane,menu_mi,m_infoicon,this,ID_MOVIEINFO_LP);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,menu_re,m_renameicon,this,ID_FILERENAME_LP);
    new FXMenuCommand(&pane,menu_mo+"--->",m_moveicon,this,ID_FILEMOVE_LP);
    new FXMenuCommand(&pane,menu_sy+"--->",m_linkicon,this,ID_FILESYMLINK_LP);
    new FXMenuCommand(&pane,menu_co+"--->",m_copyicon,this,ID_FILECOPY_LP);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,"[ ] "+menu_co,m_copyicon,this,ID_CLIPBOARD_COPY_LP);
    new FXMenuCommand(&pane,"[ ] "+menu_cu,m_cuticon,this,ID_CLIPBOARD_CUT_LP);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,menu_de,m_deleteicon,this,ID_FILEDELETE_LP);
    }
  pane.create();
  pane.popup(NULL,event->root_x,event->root_y);
  getApp()->runModalWhileShown(&pane);
  return 1;
  }

// Popup menu for item in file list
long FXMovieManager::onFileListPopup_rp(FXObject*,FXSelector,void* ptr){
  FXEvent *event=(FXEvent*)ptr;
  if(event->moved) return 1;
  FXint index=filelist_rp->getItemAt(event->win_x,event->win_y);
  FXMenuPane pane(filelist_rp);
  FXMenuPane *backgroundmenu;

  // We clicked in the background
  if(index<0){
    FXLabel *filebacklabel = new FXLabel(&pane,"Background");
    filebacklabel->setTextColor(FXRGB(120,0,0));
    // Background menu
    new FXMenuCommand(&pane,menu_te,m_terminalicon,this,ID_TERMINAL_RP);
    new FXMenuCommand(&pane,menu_he,m_consoleicon,this,ID_COMMAND_RP);
#ifdef HAVE_LIBCLAMAV
    new FXMenuCommand(&pane,menu_vi,m_bugicon,this,ID_SCANVIRUS_RP);
#endif
    new FXMenuCommand(&pane,menu_ar,m_archiveicon,this,ID_ARCHIVE_RP);
    new FXMenuCommand(&pane,menu_sr,m_searchicon,this,ID_FILESEARCH_RP);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,menu_nd,m_appendicon,this,ID_NEWDIR_RP);
    new FXMenuCommand(&pane,menu_sh,m_showhiddenicon,filelist_rp,FXFileList::ID_TOGGLE_HIDDEN);
    new FXMenuCommand(&pane,menu_rf,m_refreshicon,filelist_rp,FXFileList::ID_REFRESH);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,"[ ] "+menu_pa,m_pasteicon,this,ID_CLIPBOARD_PASTE_RP);
  }

  // We clicked on an item file or directory
  else{
    FXLabel *filelistlabel = new FXLabel(&pane,"File Item");
    filelistlabel->setTextColor(FXRGB(120,0,0));
    // Background menu
    backgroundmenu=new FXMenuPane(&pane);
    new FXMenuCommand(backgroundmenu,menu_te,m_terminalicon,this,ID_TERMINAL_RP);
    new FXMenuCommand(backgroundmenu,menu_he,m_consoleicon,this,ID_COMMAND_RP);
#ifdef HAVE_LIBCLAMAV
    new FXMenuCommand(backgroundmenu,menu_vi,m_bugicon,this,ID_SCANVIRUS_RP);
#endif
    new FXMenuCommand(backgroundmenu,menu_ar,m_archiveicon,this,ID_ARCHIVE_RP);
    new FXMenuCommand(backgroundmenu,menu_sr,m_searchicon,this,ID_FILESEARCH_RP);
    new FXMenuSeparator(backgroundmenu);
    new FXMenuCommand(backgroundmenu,menu_nd,m_appendicon,this,ID_NEWDIR_RP);
    new FXMenuCommand(backgroundmenu,menu_sh,m_showhiddenicon,filelist_rp,FXFileList::ID_TOGGLE_HIDDEN);
    new FXMenuCommand(backgroundmenu,menu_rf,m_refreshicon,filelist_rp,FXFileList::ID_REFRESH);
    new FXMenuSeparator(backgroundmenu);
    new FXMenuCommand(backgroundmenu,"[ ] "+menu_pa,m_pasteicon,this,ID_CLIPBOARD_PASTE_RP);
    new FXMenuCascade(&pane," Background",NULL,backgroundmenu);
    new FXMenuSeparator(&pane);

    new FXMenuCommand(&pane,menu_op,m_inserticon,this,ID_OPEN_RP);
    new FXMenuCommand(&pane,menu_ow,m_editicon,this,ID_OPENWITH_RP);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,menu_pr,m_propicon,this,ID_PROPERTIES_RP);
    new FXMenuCommand(&pane,menu_mi,m_infoicon,this,ID_MOVIEINFO_RP);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,menu_re,m_renameicon,this,ID_FILERENAME_RP);
    new FXMenuCommand(&pane,"<---"+menu_mo,m_moveicon,this,ID_FILEMOVE_RP);
    new FXMenuCommand(&pane,"<---"+menu_sy,m_linkicon,this,ID_FILESYMLINK_RP);
    new FXMenuCommand(&pane,"<---"+menu_co,m_copyicon,this,ID_FILECOPY_RP);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,"[ ] "+menu_co,m_copyicon,this,ID_CLIPBOARD_COPY_RP);
    new FXMenuCommand(&pane,"[ ] "+menu_cu,m_cuticon,this,ID_CLIPBOARD_CUT_RP);
    new FXMenuSeparator(&pane);
    new FXMenuCommand(&pane,menu_de,m_deleteicon,this,ID_FILEDELETE_RP);
  }
  pane.create();
  pane.popup(NULL,event->root_x,event->root_y);
  getApp()->runModalWhileShown(&pane);
  return 1;
  }



// Command from the tree list: double click
long FXMovieManager::onCmdFileListDC_lp(FXObject*,FXSelector,void* ptr){
  FXint index=(FXint)(FXival)ptr;

  if(0<=index){
    if(filelist_lp->isItemDirectory(index)){
      currentdir_lp = filelist_lp->getItemPathname(index);
      synchronize_lp(currentdir_lp);
      showFilelistThumbnails_lp();
      }
    else if(filelist_lp->isItemFile(index)
#ifdef HAVE_LIBFOX_1_7
           || filelist_lp->isItemSymlink(index)
#endif
           ){
      filename=filelist_lp->getItemPathname(index);
      FXString ext=FXPath::extension(filename);
	  if(loadfilevideo(filename)==TRUE){
	    table->setItemText(numtableitems,0,filename);
	    numtableitems=numtableitems+1;
        getFilelistSelection_lp();
	  }
	  else if(loadfilevideo(filename)==FALSE){
	    FXMessageBox::error(this,MBOX_OK,"Error on loading Movie","Unsupported Type: %s",ext.text());
	  }
    }
  }
  return 1;
}

// Command from the tree list: double click
long FXMovieManager::onCmdFileListDC_rp(FXObject*,FXSelector,void* ptr){
  FXint index=(FXint)(FXival)ptr;

  if(0<=index){
    if(filelist_rp->isItemDirectory(index)){
      currentdir_rp = filelist_rp->getItemPathname(index);
      synchronize_rp(currentdir_rp);
      showFilelistThumbnails_rp();
      }
    else if(filelist_rp->isItemFile(index)
#ifdef HAVE_LIBFOX_1_7
           || filelist_rp->isItemSymlink(index)
#endif
           ){
      filename=filelist_rp->getItemPathname(index);
      FXString ext=FXPath::extension(filename);
	  if(loadfilevideo(filename)==TRUE){
	    table->setItemText(numtableitems,0,filename);
	    numtableitems=numtableitems+1;
        getFilelistSelection_rp();
	  }
	  else if(loadfilevideo(filename)==FALSE){
	    FXMessageBox::error(this,MBOX_OK,"Error on loading Movie","Unsupported Type: %s",ext.text());
	  }
    }
  }
  return 1;
}



// Command from the tree list: single click
long FXMovieManager::onCmdFileListC_lp(FXObject*,FXSelector,void* ptr){
  double seekval = relatspinner->getValue();
  if (seekval==0) {
    return 1;
  }
  FXint index=(FXint)(FXival)ptr;
  FXString file, filetoplay, rootname, imagename;
  if(0<=index){
    if(filelist_lp->isItemFile(index)
#ifdef HAVE_LIBFOX_1_7
           || filelist_lp->isItemSymlink(index)
#endif
           ){
      file=filelist_lp->getItemFilename(index);
      filetoplay=FXPath::absolute(filelist_lp->getDirectory(),file);
      //filetoplay=filelist_lp->getItemPathname(index);
      FXString ext=FXPath::extension(filetoplay);
	  if(loadfilevideo(filetoplay)==TRUE){
		seekspinner->incrementByAmount(seekval);
        rootname="."+FXPath::stripExtension(file);
		if(!createImageMovie(filetoplay,rootname)){
			return 1;
		}
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
    	system("sleep 2s");
    	imagename=(filelist_lp->getDirectory()+"/"+rootname+"_thumbnail.jpg");
#else
    	imagename=FXPath::enquote(filelist_lp->getDirectory())+"/"+rootname+"00000001/00000001.jpg";
#endif
		if(!previewMovie(filelist_lp, imagename, index, imgw, imgh)){
			return 1;
		}
	  }
    }
  }
  return 1;
}

// Command from the tree list: single click
long FXMovieManager::onCmdFileListC_rp(FXObject*,FXSelector,void* ptr){
  double seekval = relatspinner->getValue();
  if (seekval==0) {
    return 1;
  }
  FXint index=(FXint)(FXival)ptr;
  FXString file, filetoplay, rootname, imagename;
  if(0<=index){
    if(filelist_rp->isItemFile(index)
#ifdef HAVE_LIBFOX_1_7
           || filelist_rp->isItemSymlink(index)
#endif
           ){
      file=filelist_rp->getItemFilename(index);
      filetoplay=FXPath::absolute(filelist_rp->getDirectory(),file);
      //filetoplay=filelist_rp->getItemPathname(index);  
      FXString ext=FXPath::extension(filetoplay);
	  if(loadfilevideo(filetoplay)==TRUE){
		seekspinner->incrementByAmount(seekval);
        rootname="."+FXPath::stripExtension(file);
		if(!createImageMovie(filetoplay,rootname)){
			return 1;
		}
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
		system("sleep 2s");
    	imagename=(filelist_rp->getDirectory()+"/"+rootname+"_thumbnail.jpg");
#else
    	imagename=FXPath::enquote(filelist_rp->getDirectory())+"/"+rootname+"00000001/00000001.jpg";
#endif
		if(!previewMovie(filelist_rp, imagename, index, imgw, imgh)){
			return 1;
		}
	  }
    }
  }
  return 1;
}



// MOVIE INFO DIALOG ****************************************************************
// load new image
void FXMovieManager::newImageInfo(FXString& imagename, MovieInfoDialog* infodialog) {
			// upgrade image if renamed more than one movie file
  			FXImage *img=NULL;
  			FXImage *old=NULL;

			img=new FXJPGImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);

			// Perhaps failed
  			if(img){
    			FXFileStream stream;
    			// Load image
    			if(stream.open(imagename,FXStreamLoad)){
    				getApp()->beginWaitCursor();
    				img->loadPixels(stream);
    				stream.close();
					img->scale(dlgw,dlgh,FXCLAMP(0,1,1));
   					// Create new image
   					img->create();
   					// Set new image
   					old=infodialog->getNewImage();
   					infodialog->setNewImage(img);	
					// Delete old image
   					delete old;
   					getApp()->endWaitCursor();
				}
    		}
	return;
}


// MOVIE INFO DIALOG ****************************************************************
// dump movie info
long FXMovieManager::onCmdMovieInfo_lp(FXObject*,FXSelector,void*){
  MovieInfoDialog *movieinfo_lp = new MovieInfoDialog(this,"Movie Info Left Panel",dlgw,dlgh);
  cmdMovieInfo(filelist_lp, movieinfo_lp);
  return 1;
  }

long FXMovieManager::onCmdMovieInfo_rp(FXObject*,FXSelector,void*){
  MovieInfoDialog *movieinfo_rp = new MovieInfoDialog(this,"Movie Info Right Panel",dlgw,dlgh);
  cmdMovieInfo(filelist_rp, movieinfo_rp);
  return 1;
  }

void FXMovieManager::cmdMovieInfo(FXFileList* panel, MovieInfoDialog* info){
	deselectMainDir(panel);
	FXString imagename, newname;
	FXString filename=panel->getCurrentFile();

    if(comparecase(filename,"")!=0) {
		oldImageOperation(filename,imagename,panel);
		newImageInfo(imagename,info);
		newname=FXPath::absolute(FXPath::directory(filename),FXPath::name(filename));
		info->processFileName(newname);
		info->execute();
	}

  return;
  }


// load old image on either file operations dialog or movie info dialog
FXString FXMovieManager::oldImageOperation(FXString& filename, FXString& imagename, FXFileList* panel){
	FXString rootname;
		if(loadfilevideo(filename)==TRUE) {
			rootname="."+FXPath::stripExtension(FXPath::name(filename));
			// printf("rootname: %s\n",rootname.text());
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
        	//imagename=FXPath::enquote(panel->getDirectory()+"/"+rootname+"_thumbnail.jpg");
        	imagename=(panel->getDirectory()+"/"+rootname+"_thumbnail.jpg");
#else
        	imagename=FXPath::enquote(panel->getDirectory())+"/"+rootname+"00000001/00000001.jpg";
#endif
			// printf("imagename: %s\n",imagename.text());

		} else if (loadfilevideo(filename)==FALSE && loadfileaudio(filename)==TRUE){
			imagename="/usr/local/share/pixmaps/unknow_audio.jpg";

		} else if (loadfilevideo(filename)==FALSE && loadfileaudio(filename)==FALSE){

  			if(FXStat::isDirectory(filename)){
				imagename="/usr/local/share/pixmaps/unknow_dir.jpg";
    		}
  			else if(FXStat::isExecutable(filename)){
				imagename="/usr/local/share/pixmaps/unknow_exe.jpg";
    		}
			else{
				FXString ext=FXPath::extension(FXPath::name(filename));
			    // printf("extension: %s\n",ext.text());
				if(comparecase(ext,"gz")==0||
					comparecase(ext,"xz")==0||
					comparecase(ext,"lzma")==0||
					comparecase(ext,"bz2")==0||
					comparecase(ext,"zip")==0||
					comparecase(ext,"tgz")==0||
					comparecase(ext,"7z")==0||
					comparecase(ext,"tar")==0||
					comparecase(ext,"rar")==0){
					imagename="/usr/local/share/pixmaps/unknow_arch.jpg";
				}
				else if(comparecase(ext,"gif")==0||
					comparecase(ext,"tiff")==0||
					comparecase(ext,"png")==0||
					comparecase(ext,"jpg")==0||
					comparecase(ext,"xpm")==0||
					comparecase(ext,"bmp")==0){
					imagename="/usr/local/share/pixmaps/unknow_img.jpg";
				}
  				else{
					imagename="/usr/local/share/pixmaps/unknow_file.jpg";
    			}
			}
		}
			printf("imagename: %s\n",imagename.text());

	return imagename;
}


// load new image on the file operations dialog
void FXMovieManager::newImageOperation(FXString& imagename, OperationsDialog* operationsdialog){

			// upgrade image if renamed more than one movie file
  			FXImage *img=NULL;
  			FXImage *old=NULL;

  			img=new FXJPGImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
			// Perhaps failed
  			if(img){
    			FXFileStream stream;
    			// Load image
    			if(stream.open(imagename,FXStreamLoad)){
    				getApp()->beginWaitCursor();
    				img->loadPixels(stream);
    				stream.close();
   					img->scale(dlgw,dlgh,FXCLAMP(0,1,1));
   					// Create image
   					img->create();
   					// Set new image, deleting old
   					old=operationsdialog->getNewImage();
   					operationsdialog->setNewImage(img);	
   					delete old;
   					getApp()->endWaitCursor();
				}
    		}
	return;
}



// Symlink file or directory
long FXMovieManager::onCmdFileSymlink_lp(FXObject*,FXSelector,void*){
	cmdFileSymlink(filelist_lp, filelist_rp);
  return 1;
  }

long FXMovieManager::onCmdFileSymlink_rp(FXObject*,FXSelector,void*){
	cmdFileSymlink(filelist_rp, filelist_lp);
  return 1;
  }

// Symlink file or directory
void FXMovieManager::cmdFileSymlink(FXFileList* panel, FXFileList* out_panel){
	deselectMainDir(panel);
	FXString rootname,imagename,prename,newname;
  	FXString *filenamelist=getFilenames(panel);

  	if(filenamelist){
    	OperationsDialog operationsdialog(this,"FileOperation: Symlink",dlgw,dlgh);
    	for(FXint i=0; !filenamelist[i].empty(); i++){

			oldImageOperation(filenamelist[i],imagename,panel);
			newImageOperation(imagename,&operationsdialog);

      		operationsdialog.setOldName(FXPath::absolute(FXPath::directory(filenamelist[i]),FXPath::name(filenamelist[i])));
      		//	operationsdialog.setNewName(FXPath::absolute(FXPath::directory(filenamelist[i]),FXPath::name(filenamelist[i])));
	  		FXString destinationdir=out_panel->getDirectory();
      	    //operationsdialog.setNewName(FXPath::absolute(destinationdir)+"/"+FXPath::name(filenamelist[i]));
      		operationsdialog.setNewName(FXPath::name(filenamelist[i]));
      		operationsdialog.setPreName(FXPath::absolute(destinationdir)+"/");
      		if(!operationsdialog.execute()) break;
      		newname=operationsdialog.getNewName();
      		prename=operationsdialog.getPreName();
    		if(FXStat::exists(prename+newname)){
		    	if(FXMessageBox::error(this,MBOX_OK,"Error this Link already Exists","Unable to Link:\n\n%s  to:  %s",filenamelist[i].text(),(prename+newname).text())==MBOX_CLICKED_OK) break;
      		}
			if(!FXFile::symlink(filenamelist[i],FXPath::absolute(FXPath::directory(filenamelist[i]),prename+newname))){
		    	if(FXMessageBox::error(this,MBOX_YES_NO,"Error Linking","Unable to Link:\n\n%s  to:  %s\n\nContinue with operation?",filenamelist[i].text(),(prename+newname).text())==MBOX_CLICKED_NO) break;
			}else{
				FXFile::symlink(filenamelist[i],FXPath::absolute(FXPath::directory(filenamelist[i]),prename+newname));
       			// recreate imageicon
				if(loadfilevideo(prename+newname)==TRUE){
        			rootname="."+FXPath::name(FXPath::stripExtension(prename+newname));
					if(!createImageMovie(prename+newname,rootname)){
						FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Creation Failure","Error on creating thumbnail: %s",imagename.text());
    					if(answer==MBOX_CLICKED_CANCEL){
      						return;
    					}
					}
					if(autoThumbnailUpdate==TRUE){
						out_panel->update();
						out_panel->repaint();
						showThumbnails(out_panel);
						//printf("updating thumbnails\n");
					}
				}
			}
   	  	}
    	delete [] filenamelist;
  	}
  return;
  }



// Copy file or directory
long FXMovieManager::onCmdFileCopy_lp(FXObject*,FXSelector,void*){
	cmdFileCopy(filelist_lp, filelist_rp);
  return 1;
  }

long FXMovieManager::onCmdFileCopy_rp(FXObject*,FXSelector,void*){
	cmdFileCopy(filelist_rp, filelist_lp);
  return 1;
  }

void FXMovieManager::cmdFileCopy(FXFileList* panel, FXFileList* out_panel){
	deselectMainDir(panel);
	FXString rootname,imagename,prename,newname;
  	FXString *filenamelist=getFilenames(panel);
	FXbool overwrite_file=TRUE;

  	if(filenamelist){
    	OperationsDialog operationsdialog(this,"FileOperation: Copy",dlgw,dlgh);
    	for(FXint i=0; !filenamelist[i].empty(); i++){

			oldImageOperation(filenamelist[i],imagename,panel);
			newImageOperation(imagename,&operationsdialog);

      		operationsdialog.setOldName(FXPath::absolute(FXPath::directory(filenamelist[i]),FXPath::name(filenamelist[i])));
	  		FXString destinationdir=out_panel->getDirectory();
      		operationsdialog.setNewName(FXPath::name(filenamelist[i]));
      		operationsdialog.setPreName(FXPath::absolute(destinationdir)+"/");
      		if(!operationsdialog.execute()) break;
			newname=operationsdialog.getNewName();
			prename=operationsdialog.getPreName();
    		if(FXStat::exists(prename+newname)){
      		    if(MBOX_CLICKED_NO==FXMessageBox::question(this,MBOX_YES_NO,"This Copy Already Exists","Overwrite Existing Copy: %s?",filenamelist[i].text())) {
		    		overwrite_file=FALSE;
		    		break;
		    	}
      		}
			if(!FXFile::copyFiles(filenamelist[i],FXPath::absolute(FXPath::directory(filenamelist[i]),prename+newname),overwrite_file)){
		    	if(FXMessageBox::error(this,MBOX_YES_NO,"Error Copying","Unable to Copy:\n\n%s  to:  %s\n\nContinue with operation?",filenamelist[i].text(),(prename+newname).text())==MBOX_CLICKED_NO) break;
			}else{
				FXFile::copyFiles(filenamelist[i],FXPath::absolute(FXPath::directory(filenamelist[i]),prename+newname),overwrite_file);
       			// recreate imageicon
				if(loadfilevideo(prename+newname)==TRUE){
					//printf("newname=%s\n",newname.text());
        			rootname="."+FXPath::name(FXPath::stripExtension(prename+newname));
					//printf("rootname=%s\n",rootname.text());
					if(!createImageMovie(prename+newname,rootname)){
						FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Creation Failure","Error on creating thumbnail: %s",imagename.text());
    					if(answer==MBOX_CLICKED_CANCEL){
      						return;
    					}
					}
					if(autoThumbnailUpdate==TRUE){
						out_panel->update();
						out_panel->repaint();
						showThumbnails(out_panel);
						//printf("updating thumbnails\n");
					}
				}
			}
   	    }
    	delete [] filenamelist;
  	}
  return;
  }



// Move movie file or directory
long FXMovieManager::onCmdFileMove_lp(FXObject*,FXSelector,void*){
	cmdFileRename(filelist_lp, filelist_rp);
  return 1;
  }

long FXMovieManager::onCmdFileMove_rp(FXObject*,FXSelector,void*){
	cmdFileRename(filelist_rp, filelist_lp);
  return 1;
  }

// Rename movie file or directory
long FXMovieManager::onCmdFileRename_lp(FXObject*,FXSelector,void*){
	cmdFileRename(filelist_lp, filelist_lp);
  return 1;
  }

long FXMovieManager::onCmdFileRename_rp(FXObject*,FXSelector,void*){
	cmdFileRename(filelist_rp, filelist_rp);
  return 1;
  }

void FXMovieManager::cmdFileRename(FXFileList* panel, FXFileList* out_panel){
	deselectMainDir(panel);
	FXString rootname,imagename,prename,newname;
  	FXString *filenamelist=getFilenames(panel);
	FXbool overwrite_file=TRUE;

  	if(filenamelist){
    	OperationsDialog operationsdialog(this,"FileOperation: Rename-Move",dlgw,dlgh);
    	for(FXint i=0; !filenamelist[i].empty(); i++){

		oldImageOperation(filenamelist[i],imagename,panel);
		newImageOperation(imagename,&operationsdialog);

   		operationsdialog.setOldName(FXPath::absolute(FXPath::directory(filenamelist[i]),FXPath::name(filenamelist[i])));
	  	FXString destinationdir=out_panel->getDirectory();
   		operationsdialog.setNewName(FXPath::name(filenamelist[i]));
   		operationsdialog.setPreName(FXPath::absolute(destinationdir)+"/");
   		if(!operationsdialog.execute()) break;
		newname=operationsdialog.getNewName();
		prename=operationsdialog.getPreName();
			
   		if(FXStat::exists(prename+newname)){
   	  		if(MBOX_CLICKED_NO==FXMessageBox::question(this,MBOX_YES_NO,"Already Exists","Overwrite Existing: %s?",filenamelist[i].text())) {
		   		overwrite_file=FALSE;
		   		break;
	  		}
      	}

			if(!FXFile::moveFiles(filenamelist[i],FXPath::absolute(FXPath::directory(filenamelist[i]),prename+newname),overwrite_file)){
		   		if(FXMessageBox::error(this,MBOX_YES_NO,"Error Renaming/Moving","Unable to Rename/Move:\n\n%s  to:  %s\n\nContinue with operation?",filenamelist[i].text(),(prename+newname).text())==MBOX_CLICKED_NO) break;
			}else{
				FXFile::moveFiles(filenamelist[i],FXPath::absolute(FXPath::directory(filenamelist[i]),prename+newname),overwrite_file);
       			// recreate imageicon
				if(loadfilevideo(prename+newname)==TRUE){
					//printf("newname=%s\n",newname.text());
        			rootname="."+FXPath::name(FXPath::stripExtension(prename+newname));
					//printf("rootname=%s\n",rootname.text());
					if(!createImageMovie(prename+newname,rootname)){
						FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Creation Failure","Error on creating thumbnail: %s",imagename.text());
    						if(answer==MBOX_CLICKED_CANCEL){
      							return;
    						}
					}
					if(autoThumbnailUpdate==TRUE){
						out_panel->update();
						out_panel->repaint();
						showThumbnails(out_panel);
						//printf("updating thumbnails\n");
					}
				}
			}
   		}
    	delete [] filenamelist;
  	}
  return;
  }


// Delete file or directory in the file list 
long FXMovieManager::onCmdFileDelete_lp(FXObject*,FXSelector,void*){
	cmdFileDelete(filelist_lp);
  return 1;
  }

long FXMovieManager::onCmdFileDelete_rp(FXObject*,FXSelector,void*){
	cmdFileDelete(filelist_rp);
  return 1;
  }

void FXMovieManager::cmdFileDelete(FXFileList* panel){
  FXint count=0;
  FXString logfiles,filetoremove,file;

  for(FXint i=0; i<panel->getNumItems(); i++){
    if(panel->isItemSelected(i)){
        file=panel->getItemFilename(i);
        if(file=="..") continue;
	if(count>20) {logfiles+=".........................\n\nDelete more than 20 files?\n"; break;}
	logfiles+=file+"\n";
        count=count+1;
    }
  }
	
  FXuint answer=FXMessageBox::warning(this,MBOX_YES_NO,"Deleting Movie Files",logfiles.text());
  if(answer==MBOX_CLICKED_YES){

    for(FXint i=0; i<panel->getNumItems(); i++){
      if(panel->isItemSelected(i)){
        file=panel->getItemFilename(i);
        if(file=="..") continue;
        filetoremove=FXPath::absolute(panel->getDirectory(),file);
        FXTRACE((100,"filetoremove=%s\n",filetoremove.text()));
        if(!FXFile::removeFiles(filetoremove,TRUE)){
          if(MBOX_CLICKED_NO==FXMessageBox::error(this,MBOX_YES_NO,"Error Deleting Movie","Unable to delete movie: %s\nContinue with operation?",filetoremove.text())){
            break;
            }
          }
        }
      }
    }
  return;
  }


/********************************UPDATING********************************/

long FXMovieManager::onUpdSeekIncrement(FXObject* sender,FXSelector,void*){
	double incval=relatspinner->getValue();
    FXString sincval = VALUE_TO_STRING(incval);

	if(incval!=0) {
		seekspinner->setIncrement(relatspinner->getValue());
		relatspinner->setTipText("Thumbnail auto increment "+sincval+" sec.");
		relatspinner->setHelpText("Thumbnail auto increment "+sincval+" sec.");
	} else {
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
		seekspinner->setIncrement(1);
#else
		seekspinner->setIncrement(0.1);
#endif
		relatspinner->setTipText("Disabled auto thumbnail");
		relatspinner->setHelpText("Disabled auto thumbnail");
	}
/*
	sender->handle(this,
					relatspinner->getValue()?
    				FXSEL(SEL_COMMAND,ID_ENABLE):
					FXSEL(SEL_COMMAND,ID_DISABLE),
					NULL);
*/
    return 1;
  }


// Enable sender when Items have been selected
long FXMovieManager::onUpdSelected_lp(FXObject* sender,FXSelector,void*){
    sender->handle(this,
					getNumFilenames(filelist_lp)?
					FXSEL(SEL_COMMAND,ID_ENABLE):
					FXSEL(SEL_COMMAND,ID_DISABLE),
					NULL);
    return 1;
  }


// Enable sender when Items have been selected
long FXMovieManager::onUpdSelected_rp(FXObject* sender,FXSelector,void*){
    sender->handle(this,
					getNumFilenames(filelist_rp)?
					FXSEL(SEL_COMMAND,ID_ENABLE):
					FXSEL(SEL_COMMAND,ID_DISABLE),
					NULL);
    return 1;
  }


// Enable sender when Video Files have been selected
long FXMovieManager::onUpdSelectedVideoFile_lp(FXObject* sender,FXSelector,void*){
    FXString file;

    for(FXint i=0; i<filelist_lp->getNumItems(); i++){
    	if(filelist_lp->isItemSelected(i)){
       		file=filelist_lp->getItemFilename(i);
        	if(file=="..") continue;
			if(filelist_lp->isItemDirectory(i)) return 1;
    		if(loadfilevideo(file)==FALSE)return 1;
		}
    }

    sender->handle(this,
					getNumFilenames(filelist_lp)?
					FXSEL(SEL_COMMAND,ID_ENABLE):
					FXSEL(SEL_COMMAND,ID_DISABLE),
					NULL);
    return 1;
}

long FXMovieManager::onUpdSelectedVideoFile_rp(FXObject* sender,FXSelector,void*){
    FXString file;

    for(FXint i=0; i<filelist_rp->getNumItems(); i++){
    	if(filelist_rp->isItemSelected(i)){
       		file=filelist_rp->getItemFilename(i);
        	if(file=="..") continue;
			if(filelist_rp->isItemDirectory(i)) return 1;
    		if(loadfilevideo(file)==FALSE)return 1;
		}
    }

    sender->handle(this,
					getNumFilenames(filelist_rp)?
					FXSEL(SEL_COMMAND,ID_ENABLE):
					FXSEL(SEL_COMMAND,ID_DISABLE),
					NULL);
    return 1;
}



// Enable sender when Audio Files have been selected
long FXMovieManager::onUpdSelectedVideoAudioFile_lp(FXObject* sender,FXSelector,void*){
    FXString file;

    for(FXint i=0; i<filelist_lp->getNumItems(); i++){
    	if(filelist_lp->isItemSelected(i)){
       		file=filelist_lp->getItemFilename(i);
        	if(file=="..") continue;
			if(filelist_lp->isItemDirectory(i)) return 1;
    		if(loadfilevideo(file)==FALSE && loadfileaudio(file)==FALSE)return 1;
		}
    }

    sender->handle(this,
					getNumFilenames(filelist_lp)?
					FXSEL(SEL_COMMAND,ID_ENABLE):
					FXSEL(SEL_COMMAND,ID_DISABLE),
					NULL);
    return 1;
}

long FXMovieManager::onUpdSelectedVideoAudioFile_rp(FXObject* sender,FXSelector,void*){
    FXString file;

    for(FXint i=0; i<filelist_rp->getNumItems(); i++){
    	if(filelist_rp->isItemSelected(i)){
       		file=filelist_rp->getItemFilename(i);
        	if(file=="..") continue;
			if(filelist_rp->isItemDirectory(i)) return 1;
    		if(loadfilevideo(file)==FALSE && loadfileaudio(file)==FALSE)return 1;
		}
    }

    sender->handle(this,
					getNumFilenames(filelist_rp)?
					FXSEL(SEL_COMMAND,ID_ENABLE):
					FXSEL(SEL_COMMAND,ID_DISABLE),
					NULL);
    return 1;
}



// Enable sender when Audio Files have been selected
long FXMovieManager::onUpdSelectedVideoAudioImageFile_lp(FXObject* sender,FXSelector,void*){
    FXString file;

    for(FXint i=0; i<filelist_lp->getNumItems(); i++){
    	if(filelist_lp->isItemSelected(i)){
       		file=filelist_lp->getItemFilename(i);
        	if(file=="..") continue;
			if(filelist_lp->isItemDirectory(i)) return 1;
    		if(loadfilevideo(file)==FALSE && loadfileaudio(file)==FALSE && loadfileimage(file)==FALSE)return 1;
		}
    }

    sender->handle(this,
					getNumFilenames(filelist_lp)?
					FXSEL(SEL_COMMAND,ID_ENABLE):
					FXSEL(SEL_COMMAND,ID_DISABLE),
					NULL);
    return 1;
}

long FXMovieManager::onUpdSelectedVideoAudioImageFile_rp(FXObject* sender,FXSelector,void*){
    FXString file;

    for(FXint i=0; i<filelist_rp->getNumItems(); i++){
    	if(filelist_rp->isItemSelected(i)){
       		file=filelist_rp->getItemFilename(i);
        	if(file=="..") continue;
			if(filelist_rp->isItemDirectory(i)) return 1;
    		if(loadfilevideo(file)==FALSE && loadfileaudio(file)==FALSE && loadfileimage(file)==FALSE)return 1;
		}
    }

    sender->handle(this,
					getNumFilenames(filelist_rp)?
					FXSEL(SEL_COMMAND,ID_ENABLE):
					FXSEL(SEL_COMMAND,ID_DISABLE),
					NULL);
    return 1;
}



// Enable sender when Image Files have been selected
long FXMovieManager::onUpdSelectedImageFile_lp(FXObject* sender,FXSelector,void*){
    FXString file;

    for(FXint i=0; i<filelist_lp->getNumItems(); i++){
    	if(filelist_lp->isItemSelected(i)){
       		file=filelist_lp->getItemFilename(i);
        	if(file=="..") continue;
			if(filelist_lp->isItemDirectory(i)) return 1;
    		if(loadfileimage(file)==FALSE)return 1;
		}
    }

    sender->handle(this,
					getNumFilenames(filelist_lp)?
					FXSEL(SEL_COMMAND,ID_ENABLE):
					FXSEL(SEL_COMMAND,ID_DISABLE),
					NULL);
    return 1;
}

long FXMovieManager::onUpdSelectedImageFile_rp(FXObject* sender,FXSelector,void*){
    FXString file;

    for(FXint i=0; i<filelist_rp->getNumItems(); i++){
    	if(filelist_rp->isItemSelected(i)){
       		file=filelist_rp->getItemFilename(i);
        	if(file=="..") continue;
			if(filelist_rp->isItemDirectory(i)) return 1;
    		if(loadfileimage(file)==FALSE)return 1;
		}
    }

    sender->handle(this,
					getNumFilenames(filelist_rp)?
					FXSEL(SEL_COMMAND,ID_ENABLE):
					FXSEL(SEL_COMMAND,ID_DISABLE),
					NULL);
    return 1;
}



/*********************************ROUTINES**********************************/


// Get number of selected filenames, not including "." and ".."
FXint FXMovieManager::getNumFilenames(FXFileList* panel) const {
  register FXint num=0;
  register FXint i;
  if(panel->getNumItems()){
    for(i=0; i<panel->getNumItems(); i++){
#ifdef HAVE_LIBFOX_1_6
      if(panel->isItemSelected(i) && panel->getItemFilename(i)!=".." && panel->getItemFilename(i)!=".") num++;
#endif
#ifdef HAVE_LIBFOX_1_7
      if(panel->isItemSelected(i) && !panel->isItemNavigational(i)) num++;
#endif
      }
    }
  return num;
  }


// Return selected filenames, not including "." and ".."
FXString* FXMovieManager::getFilenames(FXFileList* panel) const {
  register FXint num=getNumFilenames(panel);
  register FXString *files=NULL;
  register FXint i,n;
  if(0<num){
    files=new FXString [num+1];
    for(i=n=0; i<panel->getNumItems(); i++){
#ifdef HAVE_LIBFOX_1_6
      if(panel->isItemSelected(i) && panel->getItemFilename(i)!=".." && panel->getItemFilename(i)!="."){
#endif
#ifdef HAVE_LIBFOX_1_7
      if(panel->isItemSelected(i) && !panel->isItemNavigational(i)){
#endif
	files[n++]=panel->getItemPathname(i);
	}
      }
    files[n]=FXString::null;
    }
  return files;
  }



// deselect (..) directory
void FXMovieManager::deselectMainDir(FXFileList* panel){

  	for(FXint i=0; i<panel->getNumItems(); i++){
    	if(panel->isItemSelected(i)){
        	FXString file=panel->getItemFilename(i);
		// prevent crash when renaming directory (..)
        	if(file=="..") {
				panel->deselectItem(i);
				continue;
			}
		}
	}
	return;
}


/*****************************************************************/


// Pop up terminal
long FXMovieManager::onCmdTerminal_lp(FXObject*,FXSelector,void*){
  FXFileList::ID_REFRESH;
  FXString executable="cd "+FXPath::enquote(filelist_lp->getDirectory())+"; "+terminal+" &";
  system(executable.text());
  return 1;
  }

long FXMovieManager::onCmdTerminal_rp(FXObject*,FXSelector,void*){
  FXFileList::ID_REFRESH;
  FXString executable="cd "+FXPath::enquote(filelist_rp->getDirectory())+"; "+terminal+" &";
  system(executable.text());
  return 1;
  }


// call command
long FXMovieManager::onCmdCommand_lp(FXObject*,FXSelector,void*){
  cmdRunCommand(filelist_lp);
  return 1;
  }

long FXMovieManager::onCmdCommand_rp(FXObject*,FXSelector,void*){
  cmdRunCommand(filelist_rp);
  return 1;
  }

void FXMovieManager::cmdRunCommand(FXFileList* filepanel){
  FXFileList::ID_REFRESH;
  FXString runcommand=getApp()->reg().readStringEntry("SETTINGS","runcommand","chmod 666 *");

  if(FXInputDialog::getString(runcommand,this,"Run Command","Command:")){
    getApp()->reg().writeStringEntry("SETTINGS","runcommand",runcommand.text());
    runcommand="cd "+FXPath::enquote(filepanel->getDirectory())+"; "+runcommand+" &";
    // printf("runcommand: %s\n", runcommand.text()); 
    system(runcommand.text());
    }
  return;
}


/****************************MIYME TYPES*********************************/

// Pop up mimetype dialog
long FXMovieManager::onCmdMimeType(FXObject*,FXSelector,void*){
    mimetype->show(PLACEMENT_OWNER);
  return 1;
  }


// associated Command
long FXMovieManager::onCmdOpen_lp(FXObject*,FXSelector,void*){
  cmdOpen(filelist_lp, dirlist_lp);
  return 1;
  }

long FXMovieManager::onCmdOpen_rp(FXObject*,FXSelector,void*){
  cmdOpen(filelist_rp, dirlist_rp);
  return 1;
  }

// associated Command
void FXMovieManager::cmdOpen(FXFileList* filepanel, FXDirList* dirpanel){
  FXint index=filepanel->getCurrentItem();
  if(index>=0){

    // If directory, open the directory
    if(filepanel->isItemDirectory(index)){
      FXString directory=filepanel->getItemPathname(index);
      FXTRACE((100,"directory=%s\n",directory.text()));
      filepanel->setDirectory(directory);
      dirpanel->setDirectory(directory);
      }

    // If regular file return as the selected file
    else if(filepanel->isItemFile(index)){

      FXFileAssoc *fileassoc=filepanel->getItemAssoc(index);
      if(fileassoc){
        if(fileassoc->command.text()){

         // FXString command=VALUE_TO_STRING(fileassoc->command.text());
          FXString command=FX::FXString(fileassoc->command.text());

          FXString runcommand = "cd "+FXPath::enquote(filepanel->getDirectory())+"; "+command+" "+filepanel->getItemFilename(index)+" &";
          FXTRACE((100,"system(%s)\n",command.text()));
	      // printf("runcommand: %s\n", runcommand.text()); 
          system(runcommand.text());
          }
        else{
          FXMessageBox::information(this,MBOX_OK,"Unknown Command","No command has been defined for this file: %s",filepanel->getItemFilename(index).text());
          }
        }
      else{
        FXMessageBox::information(this,MBOX_OK,"Unknown Mime Type","No Association has been set for this file: %s",filepanel->getItemFilename(index).text());
        }
      }
  }
  return;
}



// Open with program
long FXMovieManager::onCmdOpenWith_lp(FXObject*,FXSelector,void*){
  cmdOpenWith(filelist_lp);
  return 1;
  }

long FXMovieManager::onCmdOpenWith_rp(FXObject*,FXSelector,void*){
  cmdOpenWith(filelist_rp);
  return 1;
  }

void FXMovieManager::cmdOpenWith(FXFileList* filepanel){
  FXString command=getApp()->reg().readStringEntry("SETTINGS","command","mplayer");
  FXString filename=filepanel->getCurrentFile();

  if(FXInputDialog::getString(command,this,"Open Movie File","Open " + FXPath::name(filename) + " with:")){
    getApp()->reg().writeStringEntry("SETTINGS","command",command.text());
    command=command+" "+filename+" &";
    // printf("command: %s\n", command.text()); 
    system(command.text());
    }
  return;
}


long FXMovieManager::onUpdItemFound_lp(FXObject* sender,FXSelector,void*){
  sender->handle(this,filelist_lp->getCurrentFile().empty()?FXSEL(SEL_COMMAND,ID_DISABLE):FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
  return 1;
}

long FXMovieManager::onUpdItemFound_rp(FXObject* sender,FXSelector,void*){
  sender->handle(this,filelist_rp->getCurrentFile().empty()?FXSEL(SEL_COMMAND,ID_DISABLE):FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
  return 1;
}




/****************************PROPERTIES**********************************/


// Pop up properties dialog
long FXMovieManager::onCmdProperties_lp(FXObject*,FXSelector,void*){
  cmdProperties(filelist_lp, properties_lp, currentInfo_lp, grepvideo_lp, grepaudio_lp);
  return 1;
  }

long FXMovieManager::onCmdProperties_rp(FXObject*,FXSelector,void*){
  cmdProperties(filelist_rp, properties_rp, currentInfo_rp, grepvideo_rp, grepaudio_rp);
  return 1;
  }

void FXMovieManager::cmdProperties(FXFileList* panel, FXDialogBox* properties, const FXString& currentInfo, FXString& grepvideo, FXString& grepaudio){
  FXString removeInfo="test -e "+currentInfo+" && rm "+currentInfo;
  system (removeInfo.text());

  FXString filename=panel->getCurrentFile();
  if(!createInfoMovie(filename,currentInfo)){
	FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Information Creation Failure","Error on creating information for: %s",filename.text());
  	if(answer==MBOX_CLICKED_CANCEL){
		return;
	}
  }	

  system("sleep 0.5s");

  FXchar *text;
  FXint size;

  FXFile fvideo(currentInfo,FXFile::Reading);
  size=fvideo.size();

#ifdef HAVE_LIBFOX_1_6
  if(FXMALLOC(&text,FXchar,size)){
#endif
#ifdef HAVE_LIBFOX_1_7
  if(allocElms(text,size)){
#endif

    fvideo.readBlock(text,size);
    FXString block = text;
    FXint begv1,endv1;
    FXint begv2,endv2;
    FXint bega1,enda1;
    FXint bega2,enda2;

#ifndef DISABLE_MPLAYER
    if(comparecase(defaultplayer,"mplayer")==0){
        FXRex rexvideo1("VIDEO:",0);
        FXRex rexvideo2("kbyte",0);
    	if(rexvideo1.match(text,&begv1,&endv1)){
	    if(rexvideo2.match(text,&begv2,&endv2)){
	        FXint lenv=endv2-endv1+3;
    	        FXString seltextv=block.mid(endv1,lenv);
    	        grepvideo=seltextv;
            }
        }
        else {grepvideo="NOT DETECTED by mplayer";}
    }
#endif
#ifndef DISABLE_FFPLAY
    if(comparecase(defaultplayer,"ffplay")==0){
        FXRex rexvideo1("Video:",0);
        FXRex rexvideo2("Video:",0);
    	if(rexvideo1.match(text,&begv1,&endv1)){
	    if(rexvideo2.match(text,&begv2,&endv2)){
	        FXint lenv=endv2-endv1+60;
    	        FXString seltextv=block.mid(endv1,lenv);
    	        grepvideo=seltextv;
            }
        }
        else {grepvideo="NOT DETECTED by ffplay";}
    }
#endif

#ifndef DISABLE_MPLAYER
    if(comparecase(defaultplayer,"mplayer")==0){
        FXRex rexaudio1("AUDIO:",0);
        FXRex rexaudio2("->",0);
        if(rexaudio1.match(text,&bega1,&enda1)){
	    if(rexaudio2.match(text,&bega2,&enda2)){
	        FXint lena=enda2-enda1+7;
    	        FXString seltexta=block.mid(enda1,lena);
    	        grepaudio=seltexta;
            }
        }
        else {grepaudio="NOT DETECTED by mplayer";}
    }
#endif
#ifndef DISABLE_FFPLAY
    if(comparecase(defaultplayer,"ffplay")==0){
        FXRex rexaudio1("Audio:",0);
        FXRex rexaudio2("Audio:",0);
        if(rexaudio1.match(text,&bega1,&enda1)){
	    if(rexaudio2.match(text,&bega2,&enda2)){
	        FXint lena=enda2-enda1+42;
    	        FXString seltexta=block.mid(enda1,lena);
    	        grepaudio=seltexta;
            }
        }
        else {grepaudio="NOT DETECTED by ffplay";}
    }
#endif

  }
  fvideo.close();

#ifdef HAVE_LIBFOX_1_6
  FXFREE(&text);
#endif
#ifdef HAVE_LIBFOX_1_7
  freeElms(text);
#endif

  properties->show(PLACEMENT_OWNER);

  return;
  }


// Update create time
long FXMovieManager::onUpdCreatedTime_lp(FXObject* sender,FXSelector,void*){
#ifdef HAVE_LIBFOX_1_6
  FXString time=FXSystem::time(FXStat::created(filelist_lp->getCurrentFile()));
#endif
#ifdef HAVE_LIBFOX_1_7
  FXString time=FXSystem::localTime(FXStat::created(filelist_lp->getCurrentFile()));
#endif
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&time);
  return 1;
  }

long FXMovieManager::onUpdCreatedTime_rp(FXObject* sender,FXSelector,void*){
#ifdef HAVE_LIBFOX_1_6
  FXString time=FXSystem::time(FXStat::created(filelist_rp->getCurrentFile()));
#endif
#ifdef HAVE_LIBFOX_1_7
  FXString time=FXSystem::localTime(FXStat::created(filelist_rp->getCurrentFile()));
#endif
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&time);
  return 1;
  }


// Update modified time
long FXMovieManager::onUpdModifiedTime_lp(FXObject* sender,FXSelector,void*){
#ifdef HAVE_LIBFOX_1_6
  FXString time=FXSystem::time(FXStat::modified(filelist_lp->getCurrentFile()));
#endif
#ifdef HAVE_LIBFOX_1_7
  FXString time=FXSystem::localTime(FXStat::modified(filelist_lp->getCurrentFile()));
#endif
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&time);
  return 1;
  }

long FXMovieManager::onUpdModifiedTime_rp(FXObject* sender,FXSelector,void*){
#ifdef HAVE_LIBFOX_1_6
  FXString time=FXSystem::time(FXStat::modified(filelist_rp->getCurrentFile()));
#endif
#ifdef HAVE_LIBFOX_1_7
  FXString time=FXSystem::localTime(FXStat::modified(filelist_rp->getCurrentFile()));
#endif
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&time);
  return 1;
  }


// Update file location
long FXMovieManager::onUpdFileLocation_lp(FXObject* sender,FXSelector,void*){
  FXString string=filelist_lp->getCurrentFile();
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&string);
  return 1;
  }

long FXMovieManager::onUpdFileLocation_rp(FXObject* sender,FXSelector,void*){
  FXString string=filelist_rp->getCurrentFile();
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&string);
  return 1;
  }


// Update file size
long FXMovieManager::onUpdFileSize_lp(FXObject* sender,FXSelector,void*){
  FXString size=VALUE_TO_STRING(FXStat::size(filelist_lp->getCurrentFile()));
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&size);
  return 1;
  }

long FXMovieManager::onUpdFileSize_rp(FXObject* sender,FXSelector,void*){
  FXString size=VALUE_TO_STRING(FXStat::size(filelist_rp->getCurrentFile()));
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&size);
  return 1;
  }


// Update file type
long FXMovieManager::onUpdFileType_lp(FXObject* sender,FXSelector,void*){

  FXString filename=filelist_lp->getCurrentFile();
  FXFileAssoc *fileassoc=NULL;
  FXString type;

  if(FXStat::isDirectory(filename)){
    fileassoc=associations->findDirBinding(filename.text());
    type="Directory";
    }
  else if(FXStat::isExecutable(filename)){
    fileassoc=associations->findExecBinding(filename.text());
    type="Executable";
    }
  else if(FXStat::isLink(filename)){
    fileassoc=associations->findFileBinding(filename.text());
    type="File Link";
		if(loadfilevideo(filename)==TRUE){
			type+=" (Video)";
		}
		else if(loadfileaudio(filename)==TRUE){
			type+=" (Audio)";
		}
    }   
  else if(FXStat::isFile(filename)){
    fileassoc=associations->findFileBinding(filename.text());
	FXString ext=FXPath::extension(FXPath::name(filename));
	    // printf("extension: %s\n",ext.text());
		if(loadfilevideo(filename)==TRUE){
			type="Video";
		}
		else if(loadfileaudio(filename)==TRUE){
			type="Audio";
		}
		else if(comparecase(ext,"gz")==0||comparecase(ext,"bz2")==0||comparecase(ext,"xz")==0||comparecase(ext,"zip")==0||comparecase(ext,"tar")==0||comparecase(ext,"tgz")==0||comparecase(ext,"7z")==0||comparecase(ext,"rar")==0){
			type="Archive";
		}
		else if(comparecase(ext,"gif")==0||comparecase(ext,"tiff")==0||comparecase(ext,"png")==0||comparecase(ext,"jpg")==0||comparecase(ext,"xpm")==0||comparecase(ext,"bmp")==0){
			type="Picture";
		}
		else{
			type="File";
		}
    }  
  else{
	type="Unknow";
	}
  
    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&type);
	
  return 1;
  }

long FXMovieManager::onUpdFileType_rp(FXObject* sender,FXSelector,void*){

  FXString filename=filelist_rp->getCurrentFile();
  FXFileAssoc *fileassoc=NULL;
  FXString type;

  if(FXStat::isDirectory(filename)){
    fileassoc=associations->findDirBinding(filename.text());
    type="Directory";
    }
  else if(FXStat::isExecutable(filename)){
    fileassoc=associations->findExecBinding(filename.text());
    type="Executable";
    }
  else if(FXStat::isLink(filename)){
    fileassoc=associations->findFileBinding(filename.text());
    type="File Link";
		if(loadfilevideo(filename)==TRUE){
			type+=" (Video)";
		}
		else if(loadfileaudio(filename)==TRUE){
			type+=" (Audio)";
		}
    }    
  else if(FXStat::isFile(filename)){
    fileassoc=associations->findFileBinding(filename.text());
	FXString ext=FXPath::extension(FXPath::name(filename));
	    // printf("extension: %s\n",ext.text());
		if(loadfilevideo(filename)==TRUE){
			type="Video";
		}
		else if(loadfileaudio(filename)==TRUE){
			type="Audio";
		}
		else if(comparecase(ext,"gz")==0||comparecase(ext,"bz2")==0||comparecase(ext,"xz")==0||comparecase(ext,"zip")==0||comparecase(ext,"tar")==0||comparecase(ext,"tgz")==0||comparecase(ext,"7z")==0||comparecase(ext,"rar")==0){
			type="Archive";
		}
		else if(comparecase(ext,"gif")==0||comparecase(ext,"tiff")==0||comparecase(ext,"png")==0||comparecase(ext,"jpg")==0||comparecase(ext,"xpm")==0||comparecase(ext,"bmp")==0){
			type="Picture";
		}
		else{
			type="File";
		}
    }
  else{
	type="Unknow";
	}
      
    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&type);
	
  return 1;
  }  


// Update file mimetype
long FXMovieManager::onUpdFileMimeType_lp(FXObject* sender,FXSelector,void*){

  FXString filename=filelist_lp->getCurrentFile();
  FXFileAssoc *fileassoc=NULL;
  FXString mimetype;

  if(FXStat::isFile(filename)){
    fileassoc=associations->findFileBinding(filename.text());
    }
  if(fileassoc){    
  	if(fileassoc->mimetype.text()){
#ifdef HAVE_LIBFOX_1_7
      mimetype=FXString::value(fileassoc->mimetype.text());
#elif HAVE_LIBFOX_1_6
      mimetype=FXStringFormat(fileassoc->mimetype.text());
#endif
  	}
  }
    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&mimetype);
	
  return 1;
  }

long FXMovieManager::onUpdFileMimeType_rp(FXObject* sender,FXSelector,void*){

  FXString filename=filelist_rp->getCurrentFile();
  FXFileAssoc *fileassoc=NULL;
  FXString mimetype;

  if(FXStat::isFile(filename)){
    fileassoc=associations->findFileBinding(filename.text());
    }
  if(fileassoc){    
  	if(fileassoc->mimetype.text()){
#ifdef HAVE_LIBFOX_1_7
      mimetype=FXString::value(fileassoc->mimetype.text());
#elif HAVE_LIBFOX_1_6
      mimetype=FXStringFormat(fileassoc->mimetype.text());
#endif
  	}
  }
    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&mimetype);
	
  return 1;
  }


  // Update file command
long FXMovieManager::onUpdFileCommand_lp(FXObject* sender,FXSelector,void*){

  FXString filename=filelist_lp->getCurrentFile();
  FXFileAssoc *fileassoc=NULL;
  FXString command;

  if(FXStat::isFile(filename)){
    fileassoc=associations->findFileBinding(filename.text());
    }
  if(fileassoc){    
  	if(fileassoc->command.text()){
#ifdef HAVE_LIBFOX_1_7
      command=FXString::value(fileassoc->command.text());
#elif HAVE_LIBFOX_1_6
      command=FXStringFormat(fileassoc->command.text());
#endif
  	}
  }
    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&command);
	
  return 1;
  }

long FXMovieManager::onUpdFileCommand_rp(FXObject* sender,FXSelector,void*){

  FXString filename=filelist_rp->getCurrentFile();
  FXFileAssoc *fileassoc=NULL;
  FXString command;

  if(FXStat::isFile(filename)){
    fileassoc=associations->findFileBinding(filename.text());
    }
  if(fileassoc){    
  	if(fileassoc->command.text()){
#ifdef HAVE_LIBFOX_1_7
      command=FXString::value(fileassoc->command.text());
#elif HAVE_LIBFOX_1_6
      command=FXStringFormat(fileassoc->command.text());
#endif
  	}
  }
    sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&command);
	
  return 1;
  }

  
// Update file description
long FXMovieManager::onUpdFileDesc_lp(FXObject* sender,FXSelector,void*){

  FXString filename=filelist_lp->getCurrentFile();
  FXLabel *label=(FXLabel*)sender;
  FXFileAssoc *fileassoc=NULL;

  if(FXStat::isDirectory(filename)){
    fileassoc=associations->findDirBinding(filename.text());
    }
  else if(FXStat::isExecutable(filename)){
    fileassoc=associations->findExecBinding(filename.text());
    }
  else{
    fileassoc=associations->findFileBinding(filename.text());
    }

  label->setText(FXPath::name(filename));
  if(fileassoc){
    if(fileassoc->bigicon) fileassoc->bigicon->create();
    label->setIcon(fileassoc->bigicon);
    }
  else{
    label->setIcon(NULL); 
    }
  return 1;
  }

long FXMovieManager::onUpdFileDesc_rp(FXObject* sender,FXSelector,void*){

  FXString filename=filelist_rp->getCurrentFile();
  FXLabel *label=(FXLabel*)sender;
  FXFileAssoc *fileassoc=NULL;

  if(FXStat::isDirectory(filename)){
    fileassoc=associations->findDirBinding(filename.text());
    }
  else if(FXStat::isExecutable(filename)){
    fileassoc=associations->findExecBinding(filename.text());
    }
  else{
    fileassoc=associations->findFileBinding(filename.text());
    }

  label->setText(FXPath::name(filename));
  if(fileassoc){
    if(fileassoc->bigicon) fileassoc->bigicon->create();
    label->setIcon(fileassoc->bigicon);
    }
  else{
    label->setIcon(NULL); 
    }
  return 1;
  }


// find video aspect
long FXMovieManager::onUpdMovieAspect_lp(FXObject* sender,FXSelector,void*){
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&grepvideo_lp);
  return 1;
  }

long FXMovieManager::onUpdMovieAspect_rp(FXObject* sender,FXSelector,void*){
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&grepvideo_rp);
  return 1;
  }

// find audio format
long FXMovieManager::onUpdAudioFormat_lp(FXObject* sender,FXSelector,void*){
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&grepaudio_lp);
  return 1;
  }

long FXMovieManager::onUpdAudioFormat_rp(FXObject* sender,FXSelector,void*){
  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&grepaudio_rp);
  return 1;
  }

/****************************PERMISSIONS**********************************/
/***************see FXIO.h and FXStat.h for more information**************/

// filemode modification
long FXMovieManager::onCmdFilemode_lp(FXObject*,FXSelector sel,void*){
  FXString filename=filelist_lp->getCurrentFile();
  FXuint fmode=FXStat::mode(filename);
#ifndef WIN32
  switch(FXSELID(sel)) {
    case ID_READOWNER_LP: 
	fmode^=FXIO::OwnerRead; 
	break;
    case ID_WRITEOWNER_LP: 
	fmode^=FXIO::OwnerWrite; 
	break;
    case ID_EXECUTEOWNER_LP: 
	fmode^=FXIO::OwnerExec; 
	break;
    case ID_READGROUP_LP: 
	fmode^=FXIO::GroupRead; 
	break;
    case ID_WRITEGROUP_LP: 
	fmode^=FXIO::GroupWrite; 
	break;
    case ID_EXECUTEGROUP_LP: 
	fmode^=FXIO::GroupExec; 
	break;
    case ID_READOTHER_LP: 
	fmode^=FXIO::OtherRead; 
	break;
    case ID_WRITEOTHER_LP: 
	fmode^=FXIO::OtherWrite; 
	break;
    case ID_EXECUTEOTHER_LP: 
	fmode^=FXIO::OtherExec; 
	break;
    case ID_SETUID_LP: 
	fmode^=FXIO::SetUser; 
	break;
    case ID_SETGID_LP: 
	fmode^=FXIO::SetGroup; 
	break;
    case ID_STICKY_LP: 
	fmode^=FXIO::Sticky; 
	break;
    }
#endif
  if(!FXStat::mode(filename,fmode)){
    FXMessageBox::error(this,MBOX_OK,"Changing Permissions","Unable to Change Permissions on file: %s",filename.text());
    }
  return 1;
  }

long FXMovieManager::onCmdFilemode_rp(FXObject*,FXSelector sel,void*){
  FXString filename=filelist_rp->getCurrentFile();
  FXuint fmode=FXStat::mode(filename);
#ifndef WIN32
  switch(FXSELID(sel)) {
    case ID_READOWNER_RP: 
	fmode^=FXIO::OwnerRead; 
	break;
    case ID_WRITEOWNER_RP: 
	fmode^=FXIO::OwnerWrite; 
	break;
    case ID_EXECUTEOWNER_RP: 
	fmode^=FXIO::OwnerExec; 
	break;
    case ID_READGROUP_RP: 
	fmode^=FXIO::GroupRead; 
	break;
    case ID_WRITEGROUP_RP: 
	fmode^=FXIO::GroupWrite; 
	break;
    case ID_EXECUTEGROUP_RP: 
	fmode^=FXIO::GroupExec; 
	break;
    case ID_READOTHER_RP: 
	fmode^=FXIO::OtherRead; 
	break;
    case ID_WRITEOTHER_RP: 
	fmode^=FXIO::OtherWrite; 
	break;
    case ID_EXECUTEOTHER_RP: 
	fmode^=FXIO::OtherExec; 
	break;
    case ID_SETUID_RP: 
	fmode^=FXIO::SetUser; 
	break;
    case ID_SETGID_RP: 
	fmode^=FXIO::SetGroup; 
	break;
    case ID_STICKY_RP: 
	fmode^=FXIO::Sticky; 
	break;
    }
#endif
  if(!FXStat::mode(filename,fmode)){
    FXMessageBox::error(this,MBOX_OK,"Changing Permissions","Unable to Change Permissions on file: %s",filename.text());
    }
  return 1;
  }



// update filemode
long FXMovieManager::onUpdFilemode_lp(FXObject* sender,FXSelector sel,void*){
  FXString filename=filelist_lp->getCurrentFile();
  FXuint fmode=FXStat::mode(filename);
  FXuint find=0;
#ifndef WIN32
  switch(FXSELID(sel)) {
    case ID_READOWNER_LP: 
	find=(fmode&FXIO::OwnerRead); 
	break;
    case ID_WRITEOWNER_LP: 
	find=(fmode&FXIO::OwnerWrite); 
	break;
    case ID_EXECUTEOWNER_LP: 
	find=(fmode&FXIO::OwnerExec); 
	break;
    case ID_READGROUP_LP: 
	find=(fmode&FXIO::GroupRead); 
	break;
    case ID_WRITEGROUP_LP: 
	find=(fmode&FXIO::GroupWrite); 
	break;
    case ID_EXECUTEGROUP_LP: 
	find=(fmode&FXIO::GroupExec); 
	break;
    case ID_READOTHER_LP: 
	find=(fmode&FXIO::OtherRead); 
	break;
    case ID_WRITEOTHER_LP: 
	find=(fmode&FXIO::OtherWrite); 
	break;
    case ID_EXECUTEOTHER_LP: 
	find=(fmode&FXIO::OtherExec); 
	break;
    case ID_SETUID_LP: 
	find=(fmode&FXIO::SetUser); 
	break;
    case ID_SETGID_LP: 
	find=(fmode&FXIO::SetGroup); 
	break;
    case ID_STICKY_LP: 
	find=(fmode&FXIO::Sticky); 
	break;
    }
#endif
  sender->handle(this,find ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
  return 1;
  }

long FXMovieManager::onUpdFilemode_rp(FXObject* sender,FXSelector sel,void*){
  FXString filename=filelist_rp->getCurrentFile();
  FXuint fmode=FXStat::mode(filename);
  FXuint find=0;
#ifndef WIN32
  switch(FXSELID(sel)) {
    case ID_READOWNER_RP: 
	find=(fmode&FXIO::OwnerRead); 
	break;
    case ID_WRITEOWNER_RP: 
	find=(fmode&FXIO::OwnerWrite); 
	break;
    case ID_EXECUTEOWNER_RP: 
	find=(fmode&FXIO::OwnerExec); 
	break;
    case ID_READGROUP_RP: 
	find=(fmode&FXIO::GroupRead); 
	break;
    case ID_WRITEGROUP_RP: 
	find=(fmode&FXIO::GroupWrite); 
	break;
    case ID_EXECUTEGROUP_RP: 
	find=(fmode&FXIO::GroupExec); 
	break;
    case ID_READOTHER_RP: 
	find=(fmode&FXIO::OtherRead); 
	break;
    case ID_WRITEOTHER_RP: 
	find=(fmode&FXIO::OtherWrite); 
	break;
    case ID_EXECUTEOTHER_RP: 
	find=(fmode&FXIO::OtherExec); 
	break;
    case ID_SETUID_RP: 
	find=(fmode&FXIO::SetUser); 
	break;
    case ID_SETGID_RP: 
	find=(fmode&FXIO::SetGroup); 
	break;
    case ID_STICKY_RP: 
	find=(fmode&FXIO::Sticky); 
	break;
    }
#endif
  sender->handle(this,find ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
  return 1;
  }

// show only functions
// Update owner
long FXMovieManager::onUpdOwner_lp(FXObject* sender,FXSelector,void*){
  FXStat showonly;
  FXStat::statFile(filelist_lp->getCurrentFile(),showonly);
  FXString oname=FXSystem::userName(showonly.user());

  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&oname);
  return 1;
  }

long FXMovieManager::onUpdOwner_rp(FXObject* sender,FXSelector,void*){
  FXStat showonly;
  FXStat::statFile(filelist_rp->getCurrentFile(),showonly);
  FXString oname=FXSystem::userName(showonly.user());

  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&oname);
  return 1;
  }


// Update group
long FXMovieManager::onUpdGroup_lp(FXObject* sender,FXSelector,void*){
  FXStat showonly;
  FXStat::statFile(filelist_lp->getCurrentFile(),showonly);
  FXString gname=FXSystem::groupName(showonly.group());

  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&gname);
  return 1;
  }

long FXMovieManager::onUpdGroup_rp(FXObject* sender,FXSelector,void*){
  FXStat showonly;
  FXStat::statFile(filelist_rp->getCurrentFile(),showonly);
  FXString gname=FXSystem::groupName(showonly.group());

  sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&gname);
  return 1;
  }



/****************************FILE LIST BUTTONS**********************************/
// Play the images from the file list with MPLAYER
long FXMovieManager::onCmdImagePlay_lp(FXObject*,FXSelector,void*){
     cmdImagePlay(filelist_lp);
  return 1;
  }

long FXMovieManager::onCmdImagePlay_rp(FXObject*,FXSelector,void*){
     cmdImagePlay(filelist_rp);
  return 1;
  }


void FXMovieManager::cmdImagePlay(FXFileList* panel){
   // reset the fifo every time we play
   system (removeTempFifo.text());
   system (createTempFifo.text());

   FXString filetoplay, file, playlist;

    for(FXint i=0; i<panel->getNumItems(); i++){
      if(panel->isItemSelected(i)){
        file=panel->getItemFilename(i);
        if(file=="..") continue;
		if(panel->isItemDirectory(i)) continue;
		if(panel->isItemFile(i)){
          // need to enquote files with name containing spaces for mplayer
          filetoplay=FXPath::enquote(FXPath::absolute(panel->getDirectory(),file));
          //filetoplay=FXPath::absolute(panel->getDirectory(),file);
		  if(playlist.empty()){
			playlist=filetoplay;
		  }else{		
		    playlist=playlist+","+filetoplay;
		  }
		}
      }
    }
    //get the speed
    FXfloat i_speed = spe_knob->getValue();
	if(i_speed==0){
		i_speed=1;
	}
    FXfloat f_speed = (i_speed/10);
#ifdef HAVE_LIBFOX_1_7
    FXString s_speed = "fps=" + (FXString::value(f_speed,2));
#elif HAVE_LIBFOX_1_6
    FXString s_speed = "fps=" + (FXStringVal(f_speed,2));
#endif

    if(!playlist.empty()){
	   // image processing
       s_play=j1_command + playlist + j3_command + s_speed + j5_command + s_loop + s_video + s_size + s_full +" &";
       printf("playcmd %s\n", s_play.text());		

       if(defaultplayer=="mplayer"){
           while (isrunning == TRUE){
               int ret=system("killall mplayer");
               if (WIFSIGNALED(ret) && (WTERMSIG(ret) == SIGINT || WTERMSIG(ret) == SIGQUIT)){
                   break;
	           }
	           isrunning = FALSE;
	       }
           while (isrunning == FALSE){
               int ret=system(s_play.text());
               if (WIFSIGNALED(ret) && (WTERMSIG(ret) == SIGINT || WTERMSIG(ret) == SIGQUIT)){
                   break;
	           }
	           isrunning = TRUE;
		   }
        }

    }
    // clear liststr
    playlist.clear();
    s_play.clear();
    return;
  }


// Play the movies from the file list
long FXMovieManager::onCmdFilePlay_lp(FXObject *o,FXSelector,void*){
     cmdFilePlay(filelist_lp);
  return 1;
  }

long FXMovieManager::onCmdFilePlay_rp(FXObject *o,FXSelector,void*){
     cmdFilePlay(filelist_rp);
  return 1;
  }

void FXMovieManager::cmdFilePlay(FXFileList* panel){

    if(defaultplayer=="mplayer"){
      // reset the fifo every time we play
      system (removeTempFifo.text());
      system (createTempFifo.text());
    }
    //get options passes by fxmoviemanager
    //get the speed
    FXfloat i_speed = spe_knob->getValue();
	if(i_speed==0){
	  i_speed=1;
	}
    FXfloat f_speed = (i_speed/100);
    //get the volume
    FXint i_volume = vol_knob->getValue();
    //get delay
    FXfloat f_delay = delayspinner->getValue();
#ifdef HAVE_LIBFOX_1_7
    FXString s_speed = "-speed " + (FXString::value(f_speed,2)) + " ";
    FXString s_volume = "-volume " + (FXString::value(i_volume)) + " ";
    FXString s_delay = "-delay " + (FXString::value(f_delay)) + " ";
#elif HAVE_LIBFOX_1_6
    FXString s_speed = "-speed " + (FXStringVal(f_speed,2)) + " ";
    FXString s_volume = "-volume " + (FXStringVal(i_volume)) + " ";
    FXString s_delay = "-delay " + (FXStringVal(f_delay)) + " ";
#endif
    FXString i_command;

    if(defaultplayer=="mplayer"){
      // mplayer correct command list sequence....
      i_command = s_command + s_loop + s_video + s_size + s_full + s_speed + s_audio + s_volume + s_frame + s_delay;
    }
    else if(defaultplayer=="ffplay"){
      // ffplay correct command list sequence....
      i_command = s_command + s_loop + s_size + s_full + f_audio + s_frame + s_delay + "-autoexit ";
    }


    //get filenames to be played
    FXString filetoplay, filetopass, file, playlist;
    FXint selected=0;

    for(FXint i=0; i<panel->getNumItems(); i++){
      if(panel->isItemSelected(i)){
        file=panel->getItemFilename(i);
        if(file=="..") continue;
        if(panel->isItemDirectory(i)) continue;
        if(panel->isItemFile(i) 
#ifdef HAVE_LIBFOX_1_7
           || panel->isItemSymlink(i)
#endif
           ){
          selected++;
          // mplayer and ffplay need to enquote files with name containing spaces 
          filetoplay=FXPath::enquote(FXPath::absolute(panel->getDirectory(),file));

          if(defaultplayer=="mplayer"){
            playlist=playlist + " " + filetoplay;
          } else
          if(defaultplayer=="ffplay"){
            if (selected>1)
              playlist.append(" &&");
            else
              playlist.append(" ");
            playlist.append(i_command);
            playlist.append(filetoplay);
          }

          // fxplayer does not need to enquote files with name containing spaces 
          filetopass=FXPath::absolute(panel->getDirectory(),file);
        }
      }
    }

    // internal player command
    if(defaultplayer=="fxplayer"){
      printf("fxplayer: %s\n", filetopass.text());
      // check if file exist
      if(FXStat::exists(filetopass)){
	    char c_list[1024];
	    stpncpy(c_list, filetopass.text(), sizeof(c_list));
	    int64_t time_b = 0;   
	    int64_t time_d = 24 * 3600;
	    playerdialog->setCmd(c_list, time_b, time_d, size_x, size_y, loop, full, drop, disable_audio, disable_video, time_a);
        FXMovieManager::hide();
        playerdialog->execute(PLACEMENT_OWNER);	
	    FXMovieManager::show();
	    return;
      }else{
		FXMessageBox::information(this,MBOX_OK,"Command Failure","file not found");
		return;
      }
    }

    if(!playlist.empty()){
       if(defaultplayer=="mplayer"){
          s_play = i_command + playlist + " &";
       }
    else if(defaultplayer=="ffplay"){
          s_play = playlist + " &";
       }

      printf("Exec: %s\n", s_play.text());
      int ret;

       while (isrunning == TRUE){
          if(defaultplayer=="mplayer"){
             ret=system("killall mplayer");
          }
          else if(defaultplayer=="ffplay"){
             ret=system("killall ffplay");
          }
          if (WIFSIGNALED(ret) && (WTERMSIG(ret) == SIGINT || WTERMSIG(ret) == SIGQUIT)){
             break;
	      }
	      isrunning = FALSE;
	   }

       if(defaultplayer=="mplayer" || defaultplayer=="ffplay"){
          while (isrunning == FALSE){
             int ret=system(s_play.text());
             if (WIFSIGNALED(ret) && (WTERMSIG(ret) == SIGINT || WTERMSIG(ret) == SIGQUIT)){
                break;
	         }
	         isrunning = TRUE;
		  }
       }
       // clear liststr
       playlist.clear();
       s_play.clear();
    }
    i_command.clear();

    return;
  }


// Stop player
long FXMovieManager::onCmdFileStop_lp(FXObject *,FXSelector,void *) {
     cmdFileStop();	
  return 1;
  }

long FXMovieManager::onCmdFileStop_rp(FXObject *,FXSelector,void *) {
     cmdFileStop();	
  return 1;
  }

void FXMovieManager::cmdFileStop() {
  if(defaultplayer=="mplayer"){
	if (isrunning==TRUE){
		FILE *f;
		f=fopen(currentFifo.text(), "r+");
		fprintf(f, "%s", "quit 1\n");
		fclose(f);
		isrunning=FALSE;
	} else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","MPlayer is NOT running");
	}
  }
  else if(defaultplayer=="ffplay"){
	if (isrunning==TRUE){
        system("killall ffplay");
	    isrunning=FALSE;
  	} else if (isrunning==FALSE){
		FXMessageBox::information(this,MBOX_OK,"Command Failure","ffplay is NOT running");
    }
  }
  return;
}


// Pause playing the movie from the file list
long FXMovieManager::onCmdFilePause_lp(FXObject *,FXSelector,void *) {
     cmdFilePause();	
  return 1;
  }

long FXMovieManager::onCmdFilePause_rp(FXObject *,FXSelector,void *) {
     cmdFilePause();	
  return 1;
  }

void FXMovieManager::cmdFilePause(){
    if(defaultplayer=="mplayer" || defaultplayer=="ffplay"){
	    if (isrunning==TRUE){
		    FILE *f;
		    f=fopen(currentFifo.text(), "r+");
		    fprintf(f, "%s", "pause\n");
		    fclose(f);
	    } else if (isrunning==FALSE){
		    FXMessageBox::information(this,MBOX_OK,"Command Failure","MPlayer is NOT running");
	    }
     }
	return;
  }




/***************************MOVIE PREVIEW*******************************/

// Thumbnails creation
long FXMovieManager::onCmdFilePreview_lp(FXObject*,FXSelector,void*){
    cmdFilePreview(filelist_lp);
    return 1;
}

long FXMovieManager::onCmdFilePreview_rp(FXObject*,FXSelector,void*){
    cmdFilePreview(filelist_rp);
    return 1;
}

inline
void FXMovieManager::cmdFilePreview(FXFileList* panel){
    FXString filetoplay,file,rootname,imagename,infoname;

    progressbar->setProgress(0);
    progressbar->setTotal(panel->getNumItems());
    progressbar->setBarColor(FXRGB(0,0,150));

    for(FXint i=0; i<panel->getNumItems(); i++){
      progressbar->setProgress(i+1);

      if(panel->isItemSelected(i)){
      	file=panel->getItemFilename(i);
      	if(file=="..") continue;
		if(panel->isItemDirectory(i)) continue;

        filetoplay=FXPath::absolute(panel->getDirectory(),file);
        rootname="."+FXPath::stripExtension(file);

#ifdef HAVE_LIBFFMPEGTHUMBNAILER
        imagename=FXPath::enquote(panel->getDirectory()+"/"+rootname+"_thumbnail.jpg");
#else
        imagename=FXPath::enquote(panel->getDirectory())+"/"+rootname+"00000001/00000001.jpg";
#endif
    	FXFile truefile;
		FXbool istruefile = truefile.open(imagename);
		if(!istruefile){
			if(!createImageMovie(filetoplay,rootname)){
				FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Creation Failure","Error on creating thumbnail: %s",imagename.text());
    			if(answer==MBOX_CLICKED_CANCEL){
      				return;
    			}
			}
		}
		else{
			continue;
		}
      }
    }

#ifndef HAVE_LIBFFMPEGTHUMBNAILER
    system("sleep 2s");
#endif
    progressbar->setProgress(0);
    progressbar->setBarColor(FXRGB(150,0,0));

    for(FXint i=0; i<panel->getNumItems(); i++){
      progressbar->setProgress(i+1);

        if(panel->isItemSelected(i)){
            file=panel->getItemFilename(i);
            if(file=="..") continue;
            if(panel->isItemDirectory(i)) continue;

            rootname="."+FXPath::stripExtension(file);
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
            imagename=(panel->getDirectory()+"/"+rootname+"_thumbnail.jpg");
#else
            imagename=FXPath::enquote(panel->getDirectory())+"/"+rootname+"00000001/00000001.jpg";
#endif
            if(!previewMovie(panel, imagename, i, imgw, imgh)){
                FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Loading Failure","Error on loading thumbnail: %s",imagename.text());
                if(answer==MBOX_CLICKED_CANCEL){
                    return;
                }
            }
        }
    }	
    return;
}


// Force tumbnails recreation 
long FXMovieManager::onCmdForceFilePreview_lp(FXObject*,FXSelector,void*){
    cmdForceFilePreview(filelist_lp);
    return 1;
}

long FXMovieManager::onCmdForceFilePreview_rp(FXObject*,FXSelector,void*){
    cmdForceFilePreview(filelist_rp);
    return 1;
}

inline
void FXMovieManager::cmdForceFilePreview(FXFileList* panel){
    FXString filetoplay,file,rootname,imagename;

    progressbar->setProgress(0);
    progressbar->setTotal(panel->getNumItems());
    progressbar->setBarColor(FXRGB(0,0,150));

    for(FXint i=0; i<panel->getNumItems(); i++){
      progressbar->setProgress(i+1);

      if(panel->isItemSelected(i)){
        file=panel->getItemFilename(i);
        if(file=="..") continue;
		if(panel->isItemDirectory(i)) continue;
	      
        filetoplay=FXPath::absolute(panel->getDirectory(),file);
        rootname="."+FXPath::stripExtension(file);

    	FXFile truefile;
		FXbool istruefile = truefile.open(imagename);
		if(!istruefile){
			if(!createImageMovie(filetoplay,rootname)){
				FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Creation Failure","Error on creating thumbnail: %s",imagename.text());
    			if(answer==MBOX_CLICKED_CANCEL){
      				return;
    			}
			}
		}
		else if(istruefile){
			if(!createImageMovie(filetoplay,rootname)){
				FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Creation Failure","Error on creating thumbnail: %s",imagename.text());
  				if(answer==MBOX_CLICKED_CANCEL){
   					return;
   				}
			}
		}
		else{
			continue;
		}
      }
   }

#ifndef HAVE_LIBFFMPEGTHUMBNAILER
    system("sleep 2s");
#endif
    progressbar->setProgress(0);
    progressbar->setBarColor(FXRGB(150,0,0));


    for(FXint i=0; i<panel->getNumItems(); i++){
      progressbar->setProgress(i+1);

      if(panel->isItemSelected(i)){
        file=panel->getItemFilename(i);
        if(file=="..") continue;
		if(panel->isItemDirectory(i)) continue;

        rootname="."+FXPath::stripExtension(file);
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
        imagename=(panel->getDirectory()+"/"+rootname+"_thumbnail.jpg");
#else
        imagename=FXPath::enquote(panel->getDirectory())+"/"+rootname+"00000001/00000001.jpg";
#endif
		if(!previewMovie(panel, imagename, i, imgw, imgh)){
			FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Loading Failure","Error on loading thumbnail: %s",imagename.text());
   			if(answer==MBOX_CLICKED_CANCEL){
   				return;
   			}
		}
      }
   }
   return;
}


// Resize tumbnails preview 
inline
long FXMovieManager::onCmdWideScreen(FXObject*,FXSelector,void*){

	if(widescreen==TRUE){
		widescreen=FALSE;
		imgw=80; imgh=64;
		dlgw=480; dlgh=384;
	} 
	else if(widescreen==FALSE){
		widescreen=TRUE;
		imgw=100; imgh=64;
		dlgw=600; dlgh=384;
	}
	else {
		widescreen=FALSE;
		imgw=80; imgh=64;
		dlgw=480; dlgh=384;
	}	
   return 1;
}


// Resize tumbnails preview 
inline
long FXMovieManager::onCmdIncFilePreview_lp(FXObject*,FXSelector,void*){
    cmdIncFilePreview(filelist_lp);
    return 1;
}

inline
long FXMovieManager::onCmdIncFilePreview_rp(FXObject*,FXSelector,void*){
    cmdIncFilePreview(filelist_rp);
    return 1;
}
    
inline
void FXMovieManager::cmdIncFilePreview(FXFileList* panel){
    FXString file,rootname,imagename;

	if(widescreen==TRUE){
 		imgw=imgw+50;
    	imgh=imgh+32;
	} 
	else if(widescreen==FALSE){
 		imgw=imgw+40;
    	imgh=imgh+32;
	}
	else {
  		imgw=imgw+40;
    	imgh=imgh+32;
	}	

    for(FXint i=0; i<panel->getNumItems(); i++){

      if(panel->isItemSelected(i)){
        file=panel->getItemFilename(i);
        if(file=="..") continue;
		if(panel->isItemDirectory(i)) continue;

        rootname="."+FXPath::stripExtension(file);
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
        imagename=(panel->getDirectory()+"/"+rootname+"_thumbnail.jpg");
#else
        imagename=FXPath::enquote(panel->getDirectory())+"/"+rootname+"00000001/00000001.jpg";
#endif
		if(!previewMovie(panel, imagename, i, imgw, imgh)){
			FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Loading Failure","Error on loading thumbnail: %s",imagename.text());
   			if(answer==MBOX_CLICKED_CANCEL){
   				return;
   			}
		}
      }
    }	
   return;
}


// Resize tumbnails preview 
inline
long FXMovieManager::onCmdDecFilePreview_lp(FXObject*,FXSelector,void*){
    cmdDecFilePreview(filelist_lp);
    return 1;
}

inline
long FXMovieManager::onCmdDecFilePreview_rp(FXObject*,FXSelector,void*){
    cmdDecFilePreview(filelist_rp);
    return 1;
}

inline
void FXMovieManager::cmdDecFilePreview(FXFileList* panel){
    FXString file,rootname,imagename;

	if(widescreen==TRUE){
 		imgw=imgw-50;
    	imgh=imgh-32;
	} 
	else if(widescreen==FALSE){
 		imgw=imgw-40;
    	imgh=imgh-32;
	}
	else {
  		imgw=imgw-40;
    	imgh=imgh-32;
	}

    for(FXint i=0; i<panel->getNumItems(); i++){

      if(panel->isItemSelected(i)){
        file=panel->getItemFilename(i);
        if(file=="..") continue;
		if(panel->isItemDirectory(i)) continue;

        rootname="."+FXPath::stripExtension(file);
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
        imagename=(panel->getDirectory()+"/"+rootname+"_thumbnail.jpg");
#else
        imagename=FXPath::enquote(panel->getDirectory())+"/"+rootname+"00000001/00000001.jpg";
#endif
		if(!previewMovie(panel, imagename, i, imgw, imgh)){
			FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"Thumbnail Loading Failure","Error on loading thumbnail: %s",imagename.text());
   			if(answer==MBOX_CLICKED_CANCEL){
   				return;
   			}
		}
      }
    }	
   return;
}



// clear all preview and all hidden directories
inline
long FXMovieManager::onCmdClearPreview_lp(FXObject*,FXSelector,void*){
    cmdClearPreview(filelist_lp);
    return 1;
}

inline
long FXMovieManager::onCmdClearPreview_rp(FXObject*,FXSelector,void*){
    cmdClearPreview(filelist_rp);
    return 1;
}

inline
void FXMovieManager::cmdClearPreview(FXFileList* panel){
    FXString dirname,executable;
    progressbar->setProgress(0);
    progressbar->setBarColor(FXRGB(0,150,0));
    progressbar->setTotal(panel->getNumItems());

    FXbool state=panel->showHiddenFiles();
    if(state==FALSE){
		panel->showHiddenFiles(TRUE);
	}
    if(panel->showHiddenFiles()==TRUE){
    	for(FXint i=0; i<panel->getNumItems(); i++){
       		progressbar->setProgress(i+1);
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
       		if(panel->isItemFile(i)){
#else
       		if(panel->isItemDirectory(i)){
#endif
       	  		filename=panel->getItemFilename(i);
          		if(filename=="..") continue;
	  		// use of FXRex
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
    	  		FXRex rexfile("_thumbnail.jpg",0);
#else
    	  		FXRex rexfile("00000001",0);
#endif
          		FXint begd,endd;
          		if(rexfile.match(filename,&begd,&endd)){
             		executable="cd "+FXPath::enquote(panel->getDirectory())+"; rm -r "+FXPath::enquote(filename)+" &";
             		system(executable.text());
	  			}
			}
     	}
  	}
  panel->showHiddenFiles(state);
  return;
  }


// Create thumbnails of movies
inline
FXbool FXMovieManager::createImageMovie(const FXString& filetoplay,const FXString& rootname){
#ifdef HAVE_LIBFFMPEGTHUMBNAILER
    FXfloat seekvalue=seekspinner->getValue();
#ifdef HAVE_LIBFOX_1_7
    FXString seekstring = "00:00:"+(FXString::value(seekvalue,2));	
#elif HAVE_LIBFOX_1_6
    FXString seekstring = "00:00:"+(FXStringVal(seekvalue,2));	
#endif
    string seekTime = seekstring.text();

    int     seekPercentage = 10;

    string  inputFile = filetoplay.text();
    FXString imagename=FXPath::directory(filetoplay)+"/"+rootname+"_thumbnail.jpg";
    string outputFile;
	outputFile.append(imagename.text());

    try
    {
        VideoThumbnailer videoThumbnailer(thumbnailSize, workaroundIssues, maintainAspectRatio, imageQuality, smartFrameSelection);
        FilmStripFilter* filmStripFilter = NULL;

        if (filmStripOverlay)
        {
            filmStripFilter = new FilmStripFilter();
            videoThumbnailer.addFilter(filmStripFilter);
        }

        if (!seekTime.empty())
        {
            videoThumbnailer.setSeekTime(seekTime);
        }
        else
        {
            videoThumbnailer.setSeekPercentage(seekPercentage);
        }
        videoThumbnailer.generateThumbnail(inputFile, Jpeg, outputFile);
		// free memory
        delete filmStripFilter;
    }
    catch (exception& e)
    {
        cerr << "Error: " << e.what() << endl;
        return FALSE;
    }
    catch (...)
    {
        return FALSE;
    }
    outputFile.clear();
#else
	FXfloat seekvalue=seekspinner->getValue();
	FXString seekstring	= "-ss " + (FXString::value(seekvalue,2)) + " ";
	FXString imagename=FXPath::enquote(filetoplay);
	FXString command="mplayer "+seekstring+"-frames 1 -nocache -ao null -vo jpeg:subdirs="+rootname+" "+imagename+" &";
	FXString executable="cd "+FXPath::enquote(FXPath::directory(filetoplay))+"; "+command;

	// printf("executable: %s\n", executable.text());
    system(executable.text());
#endif
    //printf("done creating thumbnail\n");
    return TRUE;
 }


inline
FXbool FXMovieManager::createInfoMovie(const FXString& filename, const FXString& currentInfo){
	FXString propcommand;
#ifndef DISABLE_MPLAYER
	if(comparecase(defaultplayer,"mplayer")==0){
		propcommand="mplayer -frames 0 -nocache -ao null -vo null '"+filename+"' &> "+currentInfo+" &";
	}
#endif 
#ifndef DISABLE_FFPLAY
	if(comparecase(defaultplayer,"ffplay")==0){
		propcommand="ffplay -an -vn '"+filename+"' &> "+currentInfo+" &";
	}
#endif
	if(comparecase(defaultplayer,"fxplayer")==0){
		propcommand="ffplay -an -vn '"+filename+"' &> "+currentInfo+" &";
	}
	// printf("propcommand: %s\n", propcommand.text());
	system(propcommand.text());

    return TRUE;
 }


// Load imagemovie to icon for preview
inline
FXbool FXMovieManager::previewMovie(FXFileList* panel, const FXString& filename, FXint i, FXint w, FXint h){
    FXString imagename;
	imagename.append(filename);
//  printf("the imagename is: %s\n", imagename.text());
//  printf("the panel is: %i\n", panel);
    FXJPGIcon *tempicon=NULL;
    tempicon=new FXJPGIcon(getApp(),NULL,IMAGE_OPAQUE|IMAGE_KEEP|IMAGE_OWNED);
    if (tempicon){
   		FXFileStream stream;
   		if (stream.open(imagename,FXStreamLoad)){
			getApp()->beginWaitCursor();
			tempicon->loadPixels(stream);
			stream.close();
			tempicon->scale(w,h,75); 
			// create new icon
   	 		tempicon->create();
			freeImageMemory(panel,i);
			panel->setItemBigIcon(i,tempicon);
			getApp()->endWaitCursor();
			imagename.clear();
			return TRUE;
		}
    }
    return FALSE;
}

inline
FXbool FXMovieManager::freeImageMemory(FXFileList* panel, FXint i) {
    FXIcon *oldicon=NULL;
    FXString file;
    file=panel->getItemFilename(i);
    if(file=="..") return FALSE;
  	if(panel->getItemBigIcon(i)){
		oldicon=panel->getItemBigIcon(i);
		panel->setItemBigIcon(i,NULL);
  		if(oldicon != NULL){
			oldicon->release();  
			oldicon=NULL;
		}
   	}
	return TRUE;
}


// Map Host
FXbool FXMovieManager::executeMapping(FXFileList* panel, const FXString& map_cmd, const FXString& map_label){

  FXString location=FXPath::enquote(panel->getDirectory());
  FXString executable=map_cmd+location;

  	  FXDialogBox dialog(this,map_label,DECOR_TITLE|DECOR_BORDER);
	  FXVerticalFrame* content=new FXVerticalFrame(&dialog,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,10,10,10,10,10,10);
  	  new FXLabel(content,location,NULL,LAYOUT_FILL_X);
  	  FXHorizontalFrame* buttons=new FXHorizontalFrame(content,LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
  	  new FXButton(buttons,"&YES",m_accepticon,&dialog,FXDialogBox::ID_ACCEPT,BUTTON_INITIAL|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT);
  	  new FXButton(buttons,"&Cancel",m_cancelicon,&dialog,FXDialogBox::ID_CANCEL,ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
  	  dialog.create();

  	  if(dialog.execute()){

         int ret = system(executable.text());
         if (WIFSIGNALED(ret) && (WTERMSIG(ret) == SIGINT || WTERMSIG(ret) == SIGQUIT)){
            return FALSE;
	     }
      }
  return TRUE;
  }

// Map Host
long FXMovieManager::onCmdMapHost_lp(FXObject*,FXSelector,void*){
  FXString map_cmd="mount ";
  FXString map_label="MAPPING DEVICE";
  if(!executeMapping(filelist_lp, map_cmd, map_label)){
  	FXMessageBox::error(this,MBOX_OK,"MAPPING NOT EXECUTED","Operation Failed!");
  }
  return 1;
  }

// Unmap Host
long FXMovieManager::onCmdUnmapHost_lp(FXObject*,FXSelector,void*){
  FXString map_cmd="umount ";
  FXString map_label="UNMAPPING DEVICE";
  if(!executeMapping(filelist_lp, map_cmd, map_label)){
  	FXMessageBox::error(this,MBOX_OK,"UNMAPPING NOT EXECUTED","Operation Failed!");
  }
  return 1;
  }

// Map Host
long FXMovieManager::onCmdMapHost_rp(FXObject*,FXSelector,void*){
  FXString map_cmd="mount ";
  FXString map_label="MAPPING DEVICE";
  if(!executeMapping(filelist_rp, map_cmd, map_label)){
  	FXMessageBox::error(this,MBOX_OK,"MAPPING NOT EXECUTED","Operation Failed!");
  }
  return 1;
  }

// Unmap Host
long FXMovieManager::onCmdUnmapHost_rp(FXObject*,FXSelector,void*){
  FXString map_cmd="umount ";
  FXString map_label="UNMAPPING DEVICE";
  if(!executeMapping(filelist_rp, map_cmd, map_label)){
  	FXMessageBox::error(this,MBOX_OK,"UNMAPPING NOT EXECUTED","Operation Failed!");
  }
  return 1;
  }



// Extract files from archive
long FXMovieManager::onCmdArchive_lp(FXObject*,FXSelector,void*){
    FXString currentdir=FXPath::enquote(filelist_lp->getDirectory());
	cmdArchive(currentdir);
	return 1;
}

long FXMovieManager::onCmdArchive_rp(FXObject*,FXSelector,void*){
    FXString currentdir=FXPath::enquote(filelist_rp->getDirectory());
	cmdArchive(currentdir);
	return 1;
}

void FXMovieManager::cmdArchive(FXString & currentdir){
    FXFileList::ID_REFRESH;
	getApp()->beginWaitCursor();
	FXString command="fxarchive "+currentdir+" &";
    system(command.text());
	getApp()->endWaitCursor();
	return;
}


// Scan for Virus with libclamav
long FXMovieManager::onCmdScanVirus_lp(FXObject*,FXSelector,void*){
    FXString currentdir=FXPath::enquote(filelist_lp->getDirectory());
	cmdScanVirus(currentdir);
    return 1;
  }

long FXMovieManager::onCmdScanVirus_rp(FXObject*,FXSelector,void*){
    FXString currentdir=FXPath::enquote(filelist_rp->getDirectory());
	cmdScanVirus(currentdir);
    return 1;
  }

void FXMovieManager::cmdScanVirus(FXString & currentdir){
    FXFileList::ID_REFRESH;
	getApp()->beginWaitCursor();
	FXString command="fxscanvirus "+currentdir+" &";
    system(command.text());
	getApp()->endWaitCursor();
	return;
}



int main(int argc, char *argv[]) {
  // Make application
  FXApp application("Configuration","FXMM");
  // Open display
  application.init(argc,argv);
  // Make window: the new FXMovieManager(&application);
  FXMovieManager* window = new FXMovieManager(&application);
  // Handle interrupt to save stuff nicely
  application.addSignal(SIGINT,window,FXMovieManager::ID_QUIT);
  application.addSignal(SIGTERM,window,FXMovieManager::ID_QUIT);
  // Create it
  application.create();
  // Run
  return application.run();
}


// EOF
